@@ -7,7 +7,7 @@
  * Description : Qt Model for Items - drag and drop handling
  *
  * SPDX-FileCopyrightText: 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2009      by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
@@ -38,7 +38,6 @@
 #include "ddragobjects.h"
 #include "dio.h"
 #include "itemcategorizedview.h"
-#include "iteminfo.h"
 #include "iteminfolist.h"
 #include "tableview_treeview.h"
 #include "digikamitemview.h"
@@ -395,6 +394,7 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
         if      (m_readOnly)
         {
             Q_EMIT itemInfosDropped(ItemInfoList(imageIDs));
+
             return true;
         }
         else if (palbum)
@@ -403,11 +403,6 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
 
             QList<ItemInfo> extImages, intImages;
 
-            if (imageIDs.isEmpty())
-            {
-                return false;
-            }
-
             for (QList<qlonglong>::const_iterator it = imageIDs.constBegin() ;
                  it != imageIDs.constEnd() ; ++it)
             {
@@ -520,6 +515,7 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
             if (action == AssignTagAction)
             {
                 Q_EMIT assignTags(ItemInfoList(imageIDs), QList<int>() << talbum->id());
+
                 return true;
             }
         }
@@ -541,6 +537,7 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
             }
 
             Q_EMIT addToGroup(droppedOnInfo, ItemInfoList(imageIDs));
+
             return true;
         }
 
@@ -552,6 +549,7 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
             }
 
             Q_EMIT dragDropSort(droppedOnInfo, ItemInfoList(imageIDs));
+
             return true;
         }
 
@@ -563,7 +561,9 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
             }
 
             Q_EMIT addToGroup(droppedOnInfo, ItemInfoList(imageIDs));
+
             DIO::move(ItemInfoList(imageIDs), palbum);
+
             return true;
         }
 
@@ -583,6 +583,7 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
         if (m_readOnly)
         {
             Q_EMIT urlsDropped(srcURLs);
+
             return true;
         }
 
@@ -652,7 +653,6 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
             popFaceTagMenu.addAction(QIcon::fromTheme(QLatin1String("dialog-cancel")), i18n("&Cancel"));
             popFaceTagMenu.setMouseTracking(true);
 
-
 #if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 
             QAction* const res = popFaceTagMenu.exec(dview->mapToGlobal(e->position().toPoint()));
@@ -883,3 +883,5 @@ QMimeData* ItemDragDropHandler::createMimeData(const QList<QModelIndex>& indexes
 }
 
 } // namespace Digikam
+
+#include "moc_itemdragdrop.cpp"
