@@ -7,7 +7,7 @@
  * Description : Thumbnail bar for items
  *
  * SPDX-FileCopyrightText: 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -19,11 +19,13 @@
 // Local includes
 
 #include "itemcategorizedview.h"
+#include "groupingviewimplementation.h"
 
 namespace Digikam
 {
 
-class ItemThumbnailBar : public ItemCategorizedView
+class ItemThumbnailBar : public ItemCategorizedView,
+                         public GroupingViewImplementation
 {
     Q_OBJECT
 
@@ -56,8 +58,9 @@ public Q_SLOTS:
 
 protected:
 
-    void slotSetupChanged() override;
-    bool event(QEvent*)     override;
+    bool event(QEvent*)                                       override;
+    void slotSetupChanged()                                   override;
+    bool hasHiddenGroupedImages(const ItemInfo& info)   const override;
 
 private:
 
