@@ -6,18 +6,9 @@
  * Date        : 2002-16-10
  * Description : main digiKam interface implementation - Configure
  *
- * Copyright (C) 2002-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -98,20 +89,16 @@ void DigikamApp::slotThemeChanged()
     ApplicationSettings* const settings = ApplicationSettings::instance();
     QString theme                       = ThemeManager::instance()->currentThemeName();
 
-    if (qApp->activeWindow() && settings->getCurrentTheme() != theme)
+    if (qApp->activeWindow()                 &&
+        (settings->getCurrentTheme() != theme))
     {
         qApp->processEvents();
 
-        QColor color   = qApp->palette().color(qApp->activeWindow()->backgroundRole());
-        int colorValue = color.red();
-        colorValue    += color.blue();
-        colorValue    += color.green();
-        colorValue     = colorValue / 3;
-
+        QColor color = qApp->palette().color(qApp->activeWindow()->backgroundRole());
         QString iconTheme;
         QString msgText;
 
-        if (colorValue > 127)
+        if (color.lightness() > 127)
         {
             msgText   = i18n("You have chosen a bright color scheme. We switch "
                              "to a dark icon theme. The icon theme is "
