@@ -6,7 +6,7 @@
  * Date        : 2002-16-10
  * Description : main digiKam interface implementation - Import tools
  *
- * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -157,10 +157,14 @@ void DigikamApp::slotImportAddFolders()
         return;
     }
 
+    QString albumRootPath = pAlbum->albumRootPath() + QLatin1Char('/');
+
     Q_FOREACH (const QUrl& url, urls)
     {
-        if (pAlbum->albumRootPath().contains(url.toLocalFile()) ||
-            url.toLocalFile().contains(pAlbum->albumRootPath()))
+        QString destPath = url.toLocalFile() + QLatin1Char('/');
+
+        if (albumRootPath.contains(destPath) ||
+            destPath.contains(albumRootPath))
         {   // cppcheck-suppress useStlAlgorithm
             QMessageBox::warning(this, qApp->applicationName(),
                                  i18n("The folder %1 is part of the album "
