@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2014      by Laurent Montel <montel at kde dot org>
  * SPDX-FileCopyrightText: 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * SPDX-FileCopyrightText: 2014-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -30,7 +30,9 @@ Q_LOGGING_CATEGORY(DIGIKAM_IMPORTUI_LOG,                "digikam.import",
 Q_LOGGING_CATEGORY(DIGIKAM_METAENGINE_LOG,              "digikam.metaengine",               QtInfoMsg)
 Q_LOGGING_CATEGORY(DIGIKAM_RAWENGINE_LOG,               "digikam.rawengine",                QtInfoMsg)
 Q_LOGGING_CATEGORY(DIGIKAM_FACESENGINE_LOG,             "digikam.facesengine",              QtInfoMsg)
+Q_LOGGING_CATEGORY(DIGIKAM_AUTOTAGSENGINE_LOG,          "digikam.autotagsengine",           QtInfoMsg)
 Q_LOGGING_CATEGORY(DIGIKAM_GEOIFACE_LOG,                "digikam.geoiface",                 QtInfoMsg)
+Q_LOGGING_CATEGORY(DIGIKAM_MARBLE_LOG,                  "digikam.marble",                   QtInfoMsg)
 
 Q_LOGGING_CATEGORY(DIGIKAM_TESTS_LOG,                   "digikam.tests",                    QtInfoMsg)
 
@@ -67,18 +69,12 @@ Q_LOGGING_CATEGORY(DIGIKAM_MEDIASRV_LOG_WARN,           "digikam.mediaserver.war
 Q_LOGGING_CATEGORY(DIGIKAM_MEDIASRV_LOG_CRITICAL,       "digikam.mediaserver.critical",     QtWarningMsg)
 Q_LOGGING_CATEGORY(DIGIKAM_MEDIASRV_LOG_FATAL,          "digikam.mediaserver.fatal",        QtCriticalMsg)
 
-Q_LOGGING_CATEGORY(DIGIKAM_QTAV_LOG,                    "digikam.qtav",                     QtInfoMsg)
-Q_LOGGING_CATEGORY(DIGIKAM_QTAV_LOG_INFO,               "digikam.qtav.info",                QtInfoMsg)
-Q_LOGGING_CATEGORY(DIGIKAM_QTAV_LOG_WARN,               "digikam.qtav.warn",                QtWarningMsg)
-Q_LOGGING_CATEGORY(DIGIKAM_QTAV_LOG_CRITICAL,           "digikam.qtav.critical",            QtWarningMsg)
-
-Q_LOGGING_CATEGORY(DIGIKAM_AVPLAYER_LOG,                "digikam.avplayer",                 QtInfoMsg)
-
 void digikamSetDebugFilterRules(bool on)
 {
     if (on)
     {
         QLoggingCategory::setFilterRules(QLatin1String("digikam.*=true\n"
-                                                       "digikam.dimg.jpeg=false"));
+                                                       "digikam.dimg.jpeg=false\n"
+                                                       "digikam.marble=false"));        // to much verbose at the console
     }
 }
