@@ -6,18 +6,9 @@
  * Date        : 2009-09-08
  * Description : global macros, variables and flags - Bundle functions.
  *
- * Copyright (C) 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -233,7 +224,7 @@ void unloadQtTranslationFiles(QApplication& app)
 
     QList<QTranslator*> translators = app.findChildren<QTranslator*>(QString(), Qt::FindDirectChildrenOnly);
 
-    foreach (const auto& translator, translators)
+    Q_FOREACH (const auto& translator, translators)
     {
         app.removeTranslator(translator);
     }
@@ -243,7 +234,7 @@ void unloadQtTranslationFiles(QApplication& app)
 
 void loadStdQtTranslationFiles(QApplication& app)
 {
-    QString transPath = QStandardPaths::locate(QStandardPaths::DataLocation,
+    QString transPath = QStandardPaths::locate(QStandardPaths::AppLocalDataLocation,
                                                QLatin1String("translations"),
                                                QStandardPaths::LocateDirectory);
 
@@ -266,7 +257,11 @@ void loadStdQtTranslationFiles(QApplication& app)
 
             if (!language.isEmpty())
             {
-                locale = QLocale(language.split(QLatin1Char(':')).first());
+                QString languageName = language.split(QLatin1Char(':')).first();
+
+                qCDebug(DIGIKAM_GENERAL_LOG) << "Language set to:" << languageName;
+
+                locale = QLocale(languageName);
             }
         }
 
@@ -294,7 +289,7 @@ void loadStdQtTranslationFiles(QApplication& app)
 
         };
 
-        foreach (const QString& catalog, qtCatalogs)
+        Q_FOREACH (const QString& catalog, qtCatalogs)
         {
             QTranslator* const translator = new QTranslator(&app);
 
@@ -321,6 +316,26 @@ void loadEcmQtTranslationFiles(QApplication& app)
     // This function is based on the code in:
     // https://invent.kde.org/frameworks/extra-cmake-modules/-/blob/master/modules/ECMQmLoader.cpp.in
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+    const QStringList ecmCatalogs =
+    {
+//        QLatin1String("kauth6_qt"),               Do not exists.
+        QLatin1String("kbookmarks6_qt"),
+        QLatin1String("kcodecs6_qt"),
+        QLatin1String("kcompletion6_qt"),
+        QLatin1String("kconfig6_qt"),
+        QLatin1String("kcoreaddons6_qt"),
+        QLatin1String("kdbusaddons6_qt"),
+//        QLatin1String("kde6_xml_mimetypes"),      Do not exists.
+//        QLatin1String("kglobalaccel6_qt"),        Do not exists.
+        QLatin1String("kitemviews6_qt"),
+        QLatin1String("kwidgetsaddons6_qt"),
+        QLatin1String("kwindowsystem6_qt"),
+        QLatin1String("solid6_qt"),
+
+#else
+
     const QStringList ecmCatalogs =
     {
         QLatin1String("kauth5_qt"),
@@ -337,10 +352,6 @@ void loadEcmQtTranslationFiles(QApplication& app)
         QLatin1String("kwindowsystem5_qt"),
         QLatin1String("solid5_qt"),
 
-#ifdef HAVE_MARBLE
-
-        QLatin1String("marble_qt"),
-
 #endif
 
     };
@@ -385,16 +396,24 @@ void loadEcmQtTranslationFiles(QApplication& app)
     {
         const QString& localeDirName = it.previous();
 
-        foreach (const auto& catalog, ecmCatalogs)
+        Q_FOREACH (const auto& catalog, ecmCatalogs)
         {
-            QString subPath    = QLatin1String("locale/")       %
-                                 localeDirName                  %
-                                 QLatin1String("/LC_MESSAGES/") %
-                                 catalog                        %
+            QString subPath    = QLatin1String("locale/")       +
+                                 localeDirName                  +
+                                 QLatin1String("/LC_MESSAGES/") +
+                                 catalog                        +
                                  QLatin1String(".qm");
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+            const QString root = QLibraryInfo::path(QLibraryInfo::PrefixPath);
+
+#else
+
             const QString root = QLibraryInfo::location(QLibraryInfo::PrefixPath);
 
+#endif
+
             // For AppImage transalotion files uses AppDataLocation.
 
             QString fullPath   = QStandardPaths::locate(QStandardPaths::AppDataLocation, subPath);
@@ -459,41 +478,4 @@ void installQtTranslationFiles(QApplication& app)
     }
 }
 
-void setupKSycocaDatabaseFile()
-{
-    if (isRunningInAppImageBundle())
-    {
-        QString cachePath = QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation);
-
-        if (!cachePath.isEmpty())
-        {
-            QString ksycoca;
-            QDir dir(cachePath);
-            QFileInfoList infoList = dir.entryInfoList(QStringList() << QLatin1String("ksycoca5*"),
-                                                       QDir::Files, QDir::Time);
-
-            while (!infoList.isEmpty())
-            {
-                QFileInfo info = infoList.takeFirst();
-
-                if (info.fileName() != QLatin1String("ksycoca5_appimage"))
-                {
-                    ksycoca = info.absoluteFilePath();
-
-                    break;
-                }
-            }
-
-            if (ksycoca.isEmpty())
-            {
-                ksycoca = cachePath + QLatin1String("/ksycoca5_appimage");
-            }
-
-            qCDebug(DIGIKAM_GENERAL_LOG) << "Set KSycoca to file:" << ksycoca;
-
-            qputenv("KDESYCOCA", ksycoca.toUtf8());
-        }
-    }
-}
-
 } // namespace Digikam
