@@ -6,7 +6,7 @@
  * Date        : 2006-21-12
  * Description : a embedded view to show item preview widget.
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2010-2011 by Aditya Bhatt <adityabhatt1991 at gmail dot com>
  *
@@ -65,7 +65,6 @@
 #include "digikamapp.h"
 #include "dimg.h"
 #include "dimgpreviewitem.h"
-#include "iteminfo.h"
 #include "fileactionmngr.h"
 #include "metaenginesettings.h"
 #include "regionframeitem.h"
@@ -752,3 +751,5 @@ void ItemPreviewView::mousePressEvent(QMouseEvent* e)
 }
 
 } // namespace Digikam
+
+#include "moc_itempreviewview.cpp"
