@@ -7,7 +7,7 @@
  * Description : Item icon view interface - Album methods.
  *
  * SPDX-FileCopyrightText: 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2011 by Johannes Wienke <languitar at semipol dot de>
  * SPDX-FileCopyrightText: 2010-2011 by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2011-2013 by Michael G. Hansen <mike at mghansen dot de>
@@ -43,29 +43,10 @@ void ItemIconView::slotAllAlbumsLoaded()
 void ItemIconView::slotSortAlbums(int role)
 {
     ApplicationSettings* const settings = ApplicationSettings::instance();
-
-    if (!settings)
-    {
-        return;
-    }
-
     settings->setAlbumSortRole((ApplicationSettings::AlbumSortRole) role);
     settings->saveSettings();
 
-    // A dummy way to force the tree view to resort if the album sort role changed
-
-    PAlbum* const albumBeforeSorting = d->albumFolderSideBar->currentAlbum();
-    settings->setAlbumSortChanged(true);
-    d->albumFolderSideBar->doSaveState();
-    d->albumFolderSideBar->doLoadState();
-    d->albumFolderSideBar->doSaveState();
-    d->albumFolderSideBar->doLoadState();
-    settings->setAlbumSortChanged(false);
-
-    if (d->leftSideBar->getActiveTab() == d->albumFolderSideBar)
-    {
-        d->albumFolderSideBar->setCurrentAlbum(albumBeforeSorting);
-    }
+    d->albumFolderSideBar->applyResorting();
 }
 
 void ItemIconView::slotNewAlbum()
@@ -190,7 +171,7 @@ void ItemIconView::slotAlbumSelected(const QList<Album*>& albums)
 
     if      (album->isRoot())
     {
-        d->stackedview->setViewMode(StackedView::WelcomePageMode);
+        d->stackedView->setViewMode(StackedView::WelcomePageMode);
     }
     else if (album->isTrashAlbum())
     {
@@ -201,7 +182,7 @@ void ItemIconView::slotAlbumSelected(const QList<Album*>& albums)
             slotTogglePreviewMode(ItemInfo());
             QUrl url = palbum->fileUrl().adjusted(QUrl::StripTrailingSlash);
             d->trashView->model()->loadItemsForCollection(url.toLocalFile());
-            d->stackedview->setViewMode(StackedView::TrashViewMode);
+            d->stackedView->setViewMode(StackedView::TrashViewMode);
             d->filterWidget->setEnabled(false);
         }
     }
@@ -423,13 +404,13 @@ void ItemIconView::slotRefresh()
     switch (viewMode())
     {
         case StackedView::PreviewImageMode:
-            d->stackedview->imagePreviewView()->reload();
+            d->stackedView->imagePreviewView()->reload();
             break;
 
 #ifdef HAVE_MEDIAPLAYER
 
         case StackedView::MediaPlayerMode:
-            d->stackedview->mediaPlayerView()->reload();
+            d->stackedView->mediaPlayerView()->reload();
             break;
 
 #endif // HAVE_MEDIAPLAYER
