@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2010         by Gabriel Voicu <ping dot gabi at gmail dot com>
  * SPDX-FileCopyrightText: 2010         by Michael G. Hansen <mike at mghansen dot de>
- * SPDX-FileCopyrightText: 2014-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -18,7 +18,6 @@
 
 // Qt includes
 
-#include <QWidget>
 #include <QVBoxLayout>
 #include <QApplication>
 #include <QItemSelectionModel>
@@ -875,3 +874,5 @@ void MapViewModelHelper::slotImageChange(const ImageChangeset& changeset)
 }
 
 } // namespace Digikam
+
+#include "moc_mapwidgetview.cpp"
