@@ -7,7 +7,7 @@
  * Description : A widget stack to embedded album content view
  *               or the current image preview.
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -45,11 +45,11 @@ class MediaPlayerView;
 
 #endif //HAVE_MEDIAPLAYER
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
 class MapWidgetView;
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
 class StackedView : public QStackedWidget
 {
@@ -91,11 +91,11 @@ public:
 
 #endif //HAVE_MEDIAPLAYER
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     MapWidgetView*    mapWidgetView()    const;
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
     /**
      * Single-file mode is image preview or media player,
@@ -141,10 +141,6 @@ Q_SIGNALS:
     void signalGotoDateAndItem(const ItemInfo&);
     void signalGotoTagAndItem(int);
 
-public Q_SLOTS:
-
-    void slotEscapePreview();
-
 private Q_SLOTS:
 
     void slotPreviewLoaded(bool);
