@@ -6,7 +6,7 @@
  * Date        : 2013-03-02
  * Description : Table view: Column configuration dialog
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -27,7 +27,6 @@
 
 // Local includes
 
-#include "tableview_columnfactory.h"
 #include "tableview_model.h"
 #include "tableview_selection_model_syncer.h"
 #include "thumbnailloadthread.h"
@@ -113,3 +112,5 @@ TableViewColumnConfiguration TableViewConfigurationDialog::getNewConfiguration()
 }
 
 } // namespace Digikam
+
+#include "moc_tableview_column_configuration_dialog.cpp"
