@@ -6,7 +6,7 @@
  * Date        : 2013-02-12
  * Description : Table view column helpers
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -300,13 +300,14 @@ class TableViewColumnFactory : public QObject
 
 public:
 
-    explicit TableViewColumnFactory(TableViewShared* const tableViewShared, QObject* const parent = nullptr);
+    explicit TableViewColumnFactory(TableViewShared* const tableViewShared, QWidget* const parent);
 
     static QList<TableViewColumnDescription> getColumnDescriptionList();
     TableViewColumn* getColumn(const TableViewColumnConfiguration& columnConfiguration);
 
 private:
 
+    QWidget*         m_displayWidget;
     TableViewShared* const s;
 };
 
