@@ -6,18 +6,9 @@
  * Date        : 2010-02-19
  * Description : Channel Mixer batch tool.
  *
- * Copyright (C) 2010-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -41,15 +32,20 @@ namespace DigikamBqmChannelMixerPlugin
 {
 
 ChannelMixer::ChannelMixer(QObject* const parent)
-    : BatchTool(QLatin1String("ChannelMixer"), ColorTool, parent)
+    : BatchTool(QLatin1String("ChannelMixer"), ColorTool, parent),
+      m_settingsView(nullptr)
 {
-    m_settingsView = nullptr;
 }
 
 ChannelMixer::~ChannelMixer()
 {
 }
 
+BatchTool* ChannelMixer::clone(QObject* const parent) const
+{
+    return new ChannelMixer(parent);
+}
+
 void ChannelMixer::registerSettingsWidget()
 {
     DVBox* const vbox    = new DVBox;
@@ -181,3 +177,5 @@ bool ChannelMixer::toolOperations()
 }
 
 } // namespace DigikamBqmChannelMixerPlugin
+
+#include "moc_channelmixer.cpp"
