@@ -6,18 +6,9 @@
  * Date        : 2010-05-03
  * Description : blur image batch tool.
  *
- * Copyright (C) 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -61,7 +52,8 @@ BatchTool* Blur::clone(QObject* const parent) const
 
 void Blur::registerSettingsWidget()
 {
-    const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
 
     m_settingsWidget = new QWidget;
     QLabel* label    = new QLabel(i18n("Smoothness:"));
@@ -125,3 +117,5 @@ bool Blur::toolOperations()
 }
 
 } // namespace DigikamBqmBlurPlugin
+
+#include "moc_blur.cpp"
