@@ -6,17 +6,9 @@
  * Date        : 2019-09-21
  * Description : JPEG DImg plugin.
  *
- * Copyright (C) 2020-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -58,14 +50,20 @@ public:
     QString details()                                                                       const override;
     QString description()                                                                   const override;
     QList<DPluginAuthor> authors()                                                          const override;
+    QString handbookSection()                                                               const override;
+    QString handbookChapter()                                                               const override;
+    QString handbookReference()                                                             const override;
 
     void setup(QObject* const)                                                                    override;
+    QMap<QString, QStringList> extraAboutData()                                             const override;
 
     QString     loaderName()                                                                const override;
     QString     typeMimes()                                                                 const override;
     int         canRead(const QFileInfo& fileInfo, bool magic)                              const override;
     int         canWrite(const QString& format)                                             const override;
     DImgLoader* loader(DImg* const image, const DRawDecoding& rawSettings = DRawDecoding()) const override;
+
+    DImgLoaderSettings* exportWidget(const QString& format)                                 const override;
 };
 
 } // namespace DigikamJPEGDImgPlugin
