@@ -6,19 +6,10 @@
  * Date        : 2009-08-09
  * Description : a tool to enhance image with local contrasts (as human eye does).
  *
- * Copyright (C) 2009      by Julien Pontabry <julien dot pontabry at gmail dot com>
- * Copyright (C) 2009-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009      by Julien Pontabry <julien dot pontabry at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -60,9 +51,9 @@ class Q_DECL_HIDDEN LocalContrastTool::Private
 public:
 
     explicit Private()
-      : settingsView(nullptr),
+      : settingsView (nullptr),
         previewWidget(nullptr),
-        gboxSettings(nullptr)
+        gboxSettings (nullptr)
     {
     }
 
@@ -83,7 +74,7 @@ const QString LocalContrastTool::Private::configHistogramScaleEntry(QLatin1Strin
 
 LocalContrastTool::LocalContrastTool(QObject* const parent)
     : EditorToolThreaded(parent),
-      d(new Private)
+      d                 (new Private)
 {
     setObjectName(QLatin1String("localcontrast"));
 
@@ -182,3 +173,5 @@ void LocalContrastTool::slotSaveAsSettings()
 }
 
 } // namespace DigikamEditorLocalContrastToolPlugin
+
+#include "moc_localcontrasttool.cpp"
