@@ -6,7 +6,7 @@
  * Date        : 2006-05-16
  * Description : A tool to edit geolocation
  *
- * SPDX-FileCopyrightText: 2006-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2010-2014 by Michael G. Hansen <mike at mghansen dot de>
  * SPDX-FileCopyrightText: 2010      by Gabriel Voicu <ping dot gabi at gmail dot com>
  * SPDX-FileCopyrightText: 2014      by Justus Schwartz <justus at gmx dot li>
@@ -58,7 +58,6 @@
 #include "dlayoutbox.h"
 #include "digikam_config.h"
 #include "itemmarkertiler.h"
-#include "trackmanager.h"
 #include "gpscommon.h"
 #include "gpsitemmodel.h"
 #include "mapdragdrophandler.h"
@@ -71,7 +70,7 @@
 #include "rgwidget.h"
 #include "kmlwidget.h"
 #include "statusprogressbar.h"
-#include "searchwidget.h"
+#include "searchresultwidget.h"
 #include "backend-rg.h"
 #include "gpsitemdetails.h"
 #include "gpsgeoifacemodelhelper.h"
@@ -231,7 +230,7 @@ public:
     GPSItemDetails*                          detailsWidget;
     GPSCorrelatorWidget*                     correlatorWidget;
     RGWidget*                                rgWidget;
-    SearchWidget*                            searchWidget;
+    SearchResultWidget*                      searchWidget;
     KmlWidget*                               kmlWidget;
 
     // map: UI
@@ -280,7 +279,7 @@ GeolocationEdit::GeolocationEdit(QWidget* const parent, DInfoInterface* const if
     d->bookmarkOwner = new GPSBookmarkOwner(d->imageModel, this);
     d->undoStack     = new QUndoStack(this);
     d->stackedWidget = new QStackedWidget();
-    d->searchWidget  = new SearchWidget(d->bookmarkOwner,
+    d->searchWidget  = new SearchResultWidget(d->bookmarkOwner,
                                         d->imageModel,
                                         d->selectionModel,
                                         d->stackedWidget);
@@ -333,15 +332,16 @@ GeolocationEdit::GeolocationEdit(QWidget* const parent, DInfoInterface* const if
     connect(d->progressCancelButton, SIGNAL(clicked()),
             this, SLOT(slotProgressCancelButtonClicked()));
 
-    m_buttons->addButton(QDialogButtonBox::Ok);
+    m_buttons->addButton(QDialogButtonBox::Yes);
     m_buttons->addButton(QDialogButtonBox::Apply);
     m_buttons->addButton(QDialogButtonBox::Close);
-    m_buttons->button(QDialogButtonBox::Ok)->setAutoDefault(false);
+    m_buttons->button(QDialogButtonBox::Yes)->setText(i18n("OK"));
+    m_buttons->button(QDialogButtonBox::Yes)->setAutoDefault(false);
     m_buttons->button(QDialogButtonBox::Apply)->setAutoDefault(false);
     m_buttons->button(QDialogButtonBox::Close)->setAutoDefault(false);
     m_buttons->setParent(hbox);
 
-    connect(m_buttons->button(QDialogButtonBox::Ok), &QPushButton::clicked,
+    connect(m_buttons->button(QDialogButtonBox::Yes), &QPushButton::clicked,
             this, &GeolocationEdit::slotOkClicked);
 
     connect(m_buttons->button(QDialogButtonBox::Apply), &QPushButton::clicked,
@@ -669,22 +669,22 @@ void GeolocationEdit::readSettings()
 
     // TODO: sanely determine a default backend
 
-    const KConfigGroup groupMapWidget = KConfigGroup(&group, "Map Widget");
+    const KConfigGroup groupMapWidget = KConfigGroup(&group, QLatin1String("Map Widget"));
     d->mapWidget->readSettingsFromGroup(&groupMapWidget);
 
-    const KConfigGroup groupCorrelatorWidget = KConfigGroup(&group, "Correlator Widget");
+    const KConfigGroup groupCorrelatorWidget = KConfigGroup(&group, QLatin1String("Correlator Widget"));
     d->correlatorWidget->readSettingsFromGroup(&groupCorrelatorWidget);
 
-    const KConfigGroup groupTreeView = KConfigGroup(&group, "Tree View");
+    const KConfigGroup groupTreeView = KConfigGroup(&group, QLatin1String("Tree View"));
     d->treeView->readSettingsFromGroup(&groupTreeView);
 
-    const KConfigGroup groupSearchWidget = KConfigGroup(&group, "Search Widget");
-    d->searchWidget->readSettingsFromGroup(&groupSearchWidget);
+    const KConfigGroup groupSearchResultWidget = KConfigGroup(&group, QLatin1String("Search Widget"));
+    d->searchWidget->readSettingsFromGroup(&groupSearchResultWidget);
 
-    const KConfigGroup groupRGWidget = KConfigGroup(&group, "Reverse Geocoding Widget");
+    const KConfigGroup groupRGWidget = KConfigGroup(&group, QLatin1String("Reverse Geocoding Widget"));
     d->rgWidget->readSettingsFromGroup(&groupRGWidget);
 
-    const KConfigGroup groupDialog = KConfigGroup(&group, "Dialog");
+    const KConfigGroup groupDialog = KConfigGroup(&group, QLatin1String("Dialog"));
 
     // --------------------------
 
@@ -707,21 +707,23 @@ void GeolocationEdit::readSettings()
 
     if (group.hasKey("SplitterState V1"))
     {
-        const QByteArray splitterState = QByteArray::fromBase64(group.readEntry("SplitterState V1", QByteArray()));
+        QByteArray splitterState;
+        splitterState = group.readEntry("SplitterState V1", splitterState);
 
         if (!splitterState.isEmpty())
         {
-            d->VSplitter->restoreState(splitterState);
+            d->VSplitter->restoreState(QByteArray::fromBase64(splitterState));
         }
     }
 
     if (group.hasKey("SplitterState H1"))
     {
-        const QByteArray splitterState = QByteArray::fromBase64(group.readEntry("SplitterState H1", QByteArray()));
+        QByteArray splitterState;
+        splitterState = group.readEntry("SplitterState H1", splitterState);
 
         if (!splitterState.isEmpty())
         {
-            d->HSplitter->restoreState(splitterState);
+            d->HSplitter->restoreState(QByteArray::fromBase64(splitterState));
         }
     }
 
@@ -735,7 +737,7 @@ void GeolocationEdit::readSettings()
 
     if (d->mapWidget2)
     {
-        const KConfigGroup groupMapWidget2 = KConfigGroup(&group, "Map Widget 2");
+        const KConfigGroup groupMapWidget2 = KConfigGroup(&group, QLatin1String("Map Widget 2"));
         d->mapWidget2->readSettingsFromGroup(&groupMapWidget2);
 
         d->mapWidget2->setActive(true);
@@ -749,25 +751,25 @@ void GeolocationEdit::saveSettings()
 
     // --------------------------
 
-    KConfigGroup groupMapWidget = KConfigGroup(&group, "Map Widget");
+    KConfigGroup groupMapWidget = KConfigGroup(&group, QLatin1String("Map Widget"));
     d->mapWidget->saveSettingsToGroup(&groupMapWidget);
 
     if (d->mapWidget2)
     {
-        KConfigGroup groupMapWidget2 = KConfigGroup(&group, "Map Widget 2");
+        KConfigGroup groupMapWidget2 = KConfigGroup(&group, QLatin1String("Map Widget 2"));
         d->mapWidget2->saveSettingsToGroup(&groupMapWidget2);
     }
 
-    KConfigGroup groupCorrelatorWidget = KConfigGroup(&group, "Correlator Widget");
+    KConfigGroup groupCorrelatorWidget = KConfigGroup(&group, QLatin1String("Correlator Widget"));
     d->correlatorWidget->saveSettingsToGroup(&groupCorrelatorWidget);
 
-    KConfigGroup groupTreeView = KConfigGroup(&group, "Tree View");
+    KConfigGroup groupTreeView = KConfigGroup(&group, QLatin1String("Tree View"));
     d->treeView->saveSettingsToGroup(&groupTreeView);
 
-    KConfigGroup groupSearchWidget = KConfigGroup(&group, "Search Widget");
-    d->searchWidget->saveSettingsToGroup(&groupSearchWidget);
+    KConfigGroup groupSearchResultWidget = KConfigGroup(&group, QLatin1String("Search Widget"));
+    d->searchWidget->saveSettingsToGroup(&groupSearchResultWidget);
 
-    KConfigGroup groupRGWidget = KConfigGroup(&group, "Reverse Geocoding Widget");
+    KConfigGroup groupRGWidget = KConfigGroup(&group, QLatin1String("Reverse Geocoding Widget"));
     d->rgWidget->saveSettingsToGroup(&groupRGWidget);
 
     // --------------------------
@@ -1143,7 +1145,7 @@ void GeolocationEdit::adjustMapLayout(const bool syncSettings)
             {
                 KSharedConfig::Ptr config         = KSharedConfig::openConfig();
                 KConfigGroup group                = config->group(QLatin1String("Geolocation Edit Settings"));
-                const KConfigGroup groupMapWidget = KConfigGroup(&group, "Map Widget");
+                const KConfigGroup groupMapWidget = KConfigGroup(&group, QLatin1String("Map Widget"));
                 d->mapWidget2->readSettingsFromGroup(&groupMapWidget);
                 d->mapWidget2->setActive(true);
             }
@@ -1161,3 +1163,5 @@ void GeolocationEdit::adjustMapLayout(const bool syncSettings)
 }
 
 } // namespace DigikamGenericGeolocationEditPlugin
+
+#include "moc_geolocationedit.cpp"
