@@ -7,7 +7,7 @@
  * Description : a tool to export GPS data to KML file.
  *
  * SPDX-FileCopyrightText: 2006-2007 by Stephane Pontier <shadow dot walker at free dot fr>
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -95,7 +95,7 @@ private:
 
     /*! @todo maybe initialize it in the constructor */
     /*! the root document, used to create all QDomElements */
-    QDomDocument* kmlDocument;
+    QDomDocument* kmlDocument = nullptr;
 };
 
 } // namespace DigikamGenericGeolocationEditPlugin
