@@ -7,7 +7,7 @@
  * Description : time adjust thread.
  *
  * SPDX-FileCopyrightText: 2012      by Smit Mehta <smit dot meh at gmail dot com>
- * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2018-2021 by Maik Qualmann <metzpinguin at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -23,7 +23,6 @@
 // Local includes
 
 #include "dmetadata.h"
-#include "dinfointerface.h"
 #include "timeadjusttask.h"
 
 namespace DigikamGenericTimeAdjustPlugin
@@ -281,3 +280,5 @@ int TimeAdjustThread::indexForUrl(const QUrl& url) const
 }
 
 } // namespace DigikamGenericTimeAdjustPlugin
+
+#include "moc_timeadjustthread.cpp"
