@@ -6,18 +6,10 @@
  * Date        : 2008-11-13
  * Description : printer thread.
  *
- * Copyright (C) 2008      by Orgad Shaneh <orgads at gmail dot com>
- * Copyright (C) 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008      by Orgad Shaneh <orgads at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -38,19 +30,14 @@ class Q_DECL_HIDDEN CalPrinter::Private
 {
 public:
 
-    explicit Private()
-      : cancelled(false),
-        printer  (nullptr),
-        painter  (nullptr)
-    {
-    }
+    Private() = default;
 
-    bool             cancelled;
+    bool             cancelled = false;
 
     QMap<int, QUrl>  months;
-    QPrinter*        printer;
+    QPrinter*        printer   = nullptr;
 
-    CalPainter*      painter;
+    CalPainter*      painter   = nullptr;
 };
 
 CalPrinter::CalPrinter(QPrinter* const printer,
@@ -81,9 +68,9 @@ void CalPrinter::run()
 
     int currPage = 0;
 
-    foreach (const int month, d->months.keys())
+    Q_FOREACH (const int month, d->months.keys())
     {
-        emit pageChanged(currPage);
+        Q_EMIT pageChanged(currPage);
 
         // cppcheck-suppress knownConditionTrueFalse
         if (currPage)
@@ -104,7 +91,7 @@ void CalPrinter::run()
 
     d->painter->end();
 
-    emit pageChanged(currPage);
+    Q_EMIT pageChanged(currPage);
 }
 
 void CalPrinter::cancel()
@@ -114,3 +101,5 @@ void CalPrinter::cancel()
 }
 
 } // namespace Digikam
+
+#include "moc_calprinter.cpp"
