@@ -10,7 +10,7 @@
  * SPDX-FileCopyrightText: 2007-2008 by Orgad Shaneh <orgads at gmail dot com>
  * SPDX-FileCopyrightText: 2011      by Andi Clemens <andi dot clemens at googlemail dot com>
  * SPDX-FileCopyrightText: 2012      by Angelo Naselli <anaselli at linux dot it>
- * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -60,9 +60,7 @@ class Q_DECL_HIDDEN CalSettings::Private
 {
 public:
 
-    explicit Private()
-    {
-    }
+    Private() = default;
 
     QMap<int, QUrl>  monthMap;
     QMap<QDate, Day> special;
@@ -198,6 +196,7 @@ void CalSettings::setDrawLines(bool draw)
     if (params.drawLines != draw)
     {
         params.drawLines = draw;
+
         Q_EMIT settingsChanged();
     }
 }
@@ -207,6 +206,7 @@ void CalSettings::setRatio(int ratio)
     if (params.ratio != ratio)
     {
         params.ratio = ratio;
+
         Q_EMIT settingsChanged();
     }
 }
@@ -382,3 +382,5 @@ void CalSettings::loadSpecial(const QUrl& url, const QColor& color)
 #endif // HAVE_KCALENDAR
 
 } // namespace Digikam
+
+#include "moc_calsettings.cpp"
