@@ -6,17 +6,9 @@
  * Date        : 2006-04-04
  * Description : a tool to generate HTML image galleries
  *
- * Copyright (C) 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -68,13 +60,16 @@ HTMLImageSettingsPage::HTMLImageSettingsPage(QWizard* const dialog, const QStrin
 {
     setObjectName(QLatin1String("ImageSettingsPage"));
 
+    const int spacing   = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                               QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+
     QWidget* const box  = new QWidget(this);
 
     QLabel* const label = new QLabel(this);
     label->setObjectName(QLatin1String("label"));
     QFont font;
     font.setBold(true);
-    font.setWeight(75);
+    font.setWeight(QFont::Bold);
     label->setFont(font);
     label->setText(i18n("Full Image Properties:"));
 
@@ -85,7 +80,7 @@ HTMLImageSettingsPage::HTMLImageSettingsPage(QWizard* const dialog, const QStrin
 
     QLabel* const textLabel2_2_2_2 = new QLabel(this);
     textLabel2_2_2_2->setObjectName(QLatin1String("textLabel2_2_2_2"));
-    textLabel2_2_2_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
+    textLabel2_2_2_2->setAlignment(Qt::AlignRight | Qt::AlignTrailing | Qt::AlignVCenter);
     textLabel2_2_2_2->setWordWrap(false);
     textLabel2_2_2_2->setText(i18n("Format:"));
 
@@ -100,7 +95,7 @@ HTMLImageSettingsPage::HTMLImageSettingsPage(QWizard* const dialog, const QStrin
 
     QLabel* const textLabel4 = new QLabel(this);
     textLabel4->setObjectName(QLatin1String("textLabel4"));
-    textLabel4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
+    textLabel4->setAlignment(Qt::AlignRight | Qt::AlignTrailing | Qt::AlignVCenter);
     textLabel4->setWordWrap(false);
     textLabel4->setText(i18n("Quality:"));
 
@@ -131,7 +126,7 @@ HTMLImageSettingsPage::HTMLImageSettingsPage(QWizard* const dialog, const QStrin
 
     QHBoxLayout* const horizontalLayout_2 = new QHBoxLayout(widget);
     horizontalLayout_2->setContentsMargins(QMargins());
-    horizontalLayout_2->setSpacing(QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    horizontalLayout_2->setSpacing(spacing);
     horizontalLayout_2->setObjectName(QLatin1String("horizontalLayout_2"));
     horizontalLayout_2->addWidget(kcfg_fullResize);
     horizontalLayout_2->addWidget(kcfg_fullSize);
@@ -147,7 +142,7 @@ HTMLImageSettingsPage::HTMLImageSettingsPage(QWizard* const dialog, const QStrin
 
     QHBoxLayout* const horizontalLayout = new QHBoxLayout();
     horizontalLayout->setContentsMargins(QMargins());
-    horizontalLayout->setSpacing(QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    horizontalLayout->setSpacing(spacing);
     horizontalLayout->setObjectName(QLatin1String("horizontalLayout"));
     horizontalLayout->addWidget(kcfg_copyOriginalImage);
     horizontalLayout->addItem(horizontalSpacer_3);
@@ -166,7 +161,7 @@ HTMLImageSettingsPage::HTMLImageSettingsPage(QWizard* const dialog, const QStrin
 
     QLabel* const textLabel2_2_2 = new QLabel(this);
     textLabel2_2_2->setObjectName(QLatin1String("textLabel2_2_2"));
-    textLabel2_2_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
+    textLabel2_2_2->setAlignment(Qt::AlignRight | Qt::AlignTrailing | Qt::AlignVCenter);
     textLabel2_2_2->setWordWrap(false);
     textLabel2_2_2->setText(i18n("Format:"));
 
@@ -181,7 +176,7 @@ HTMLImageSettingsPage::HTMLImageSettingsPage(QWizard* const dialog, const QStrin
 
     QLabel* const textLabel4_2 = new QLabel(this);
     textLabel4_2->setObjectName(QLatin1String("textLabel4_2"));
-    textLabel4_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
+    textLabel4_2->setAlignment(Qt::AlignRight | Qt::AlignTrailing | Qt::AlignVCenter);
     textLabel4_2->setWordWrap(false);
     textLabel4_2->setText(i18n("Quality:"));
 
@@ -195,7 +190,7 @@ HTMLImageSettingsPage::HTMLImageSettingsPage(QWizard* const dialog, const QStrin
 
     QLabel* const textLabel2_2 = new QLabel(this);
     textLabel2_2->setObjectName(QLatin1String("textLabel2_2"));
-    textLabel2_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
+    textLabel2_2->setAlignment(Qt::AlignRight | Qt::AlignTrailing | Qt::AlignVCenter);
     textLabel2_2->setWordWrap(false);
     textLabel2_2->setText(i18n("Size:"));
 
@@ -218,7 +213,7 @@ HTMLImageSettingsPage::HTMLImageSettingsPage(QWizard* const dialog, const QStrin
 
     QGridLayout* const gridLayout       = new QGridLayout(box);
     gridLayout->setContentsMargins(QMargins());
-    gridLayout->setSpacing(QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    gridLayout->setSpacing(spacing);
     gridLayout->setObjectName(QLatin1String("gridLayout"));
     gridLayout->addWidget(label,                    0, 0, 1, 2);
     gridLayout->addWidget(mSaveImageButton,         1, 0, 1, 2);
@@ -309,3 +304,5 @@ void HTMLImageSettingsPage::initializePage()
 }
 
 } // namespace DigikamGenericHtmlGalleryPlugin
+
+#include "moc_htmlimagesettingspage.cpp"
