@@ -6,17 +6,9 @@
  * Date        : 2006-04-04
  * Description : a tool to generate jAlbum image galleries
  *
- * Copyright (C) 2013-2019 by Andrew Goodbody <ajg zero two at elfringham dot co dot uk>
+ * SPDX-FileCopyrightText: 2013-2019 by Andrew Goodbody <ajg zero two at elfringham dot co dot uk>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -80,7 +72,8 @@ JAlbumFinalPage::JAlbumFinalPage(QWizard* const dialog, const QString& title)
 
     vbox->setStretchFactor(d->progressBar, 10);
     vbox->setContentsMargins(QMargins());
-    vbox->setSpacing(QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    vbox->setSpacing(qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing)));
 
     setPageWidget(vbox);
     setLeftBottomPix(QIcon::fromTheme(QLatin1String("system-run")));
@@ -94,7 +87,7 @@ JAlbumFinalPage::~JAlbumFinalPage()
 void JAlbumFinalPage::initializePage()
 {
     d->complete = false;
-    emit completeChanged();
+    Q_EMIT completeChanged();
     QTimer::singleShot(0, this, SLOT(slotProcess()));
 }
 
@@ -129,7 +122,7 @@ void JAlbumFinalPage::slotProcess()
         d->progressView->addEntry(i18n("%1 albums to process:", info->m_albumList.count()),
                                   DHistoryView::ProgressEntry);
 
-        foreach (const QUrl& url, info->m_iface->albumsItems(info->m_albumList))
+        Q_FOREACH (const QUrl& url, info->m_iface->albumsItems(info->m_albumList))
         {
             d->progressView->addEntry(QDir::toNativeSeparators(url.toLocalFile()),
                                       DHistoryView::ProgressEntry);
@@ -165,7 +158,7 @@ void JAlbumFinalPage::slotProcess()
     }
 
     d->complete = true;
-    emit completeChanged();
+    Q_EMIT completeChanged();
 }
 
 bool JAlbumFinalPage::isComplete() const
@@ -174,3 +167,5 @@ bool JAlbumFinalPage::isComplete() const
 }
 
 } // namespace DigikamGenericJAlbumPlugin
+
+#include "moc_jalbumfinalpage.cpp"
