@@ -6,7 +6,7 @@
  * Date        : 2012-05-28
  * Description : Media Server configuration dialog to share a single list of files
  *
- * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2017      by Ahmed Fathy <ahmed dot fathi dot abdelmageed at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -36,7 +36,6 @@
 
 // Local includes
 
-#include "dinfointerface.h"
 #include "ditemslist.h"
 #include "dxmlguiwindow.h"
 #include "workingwidget.h"
@@ -367,3 +366,5 @@ void DMediaServerDlg::slotToggleMediaServer()
 }
 
 } // namespace DigikamGenericMediaServerPlugin
+
+#include "moc_dmediaserverdlg.cpp"
