@@ -6,7 +6,7 @@
  * Date        : 2017-09-24
  * Description : a media server to export collections through DLNA.
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -17,8 +17,6 @@
 // Qt includes
 
 #include <QApplication>
-#include <QList>
-#include <QUrl>
 #include <QFile>
 #include <QStandardPaths>
 
@@ -173,3 +171,5 @@ void DMediaServer::addAlbumsOnServer(const MediaServerMap& map)
 }
 
 } // namespace DigikamGenericMediaServerPlugin
+
+#include "moc_dmediaserver.cpp"
