@@ -6,8 +6,8 @@
  * Date        : 2021-07-24
  * Description : MJPEG server manager
  *
- * SPDX-FileCopyrightText: 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * SPDX-FileCopyrightText: 2021 by Quoc Hưng Tran <quochungtran1999 at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021      by Quoc Hưng Tran <quochungtran1999 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -39,7 +39,6 @@
 
 #include "digikam_debug.h"
 #include "dnotificationwrapper.h"
-#include "mjpegserver.h"
 #include "mjpegframethread.h"
 
 using namespace Digikam;
@@ -399,3 +398,5 @@ bool MjpegServerMngr::load()
 }
 
 } // namespace DigikamGenericMjpegStreamPlugin
+
+#include "moc_mjpegservermngr.cpp"
