@@ -6,17 +6,9 @@
  * Date        : 2011-05-23
  * Description : Autodetect nona binary program and version
  *
- * Copyright (C) 2011-2016 by Benjamin Girault <benjamin dot girault at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2016 by Benjamin Girault <benjamin dot girault at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -44,3 +36,5 @@ NonaBinary::~NonaBinary()
 }
 
 } // namespace DigikamGenericPanoramaPlugin
+
+#include "moc_nonabinary.cpp"
