@@ -7,7 +7,7 @@
  * Description : a tool to create panorama by fusion of several images.
  *
  * SPDX-FileCopyrightText: 2011-2016 by Benjamin Girault <benjamin dot girault at gmail dot com>
- * SPDX-FileCopyrightText: 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -19,7 +19,6 @@
 
 #include <QLabel>
 #include <QMutex>
-#include <QMutexLocker>
 #include <QTextDocument>
 #include <QStandardPaths>
 #include <QVBoxLayout>
@@ -667,3 +666,5 @@ void PanoPreviewPage::slotPanoAction(const DigikamGenericPanoramaPlugin::PanoAct
 }
 
 } // namespace DigikamGenericPanoramaPlugin
+
+#include "moc_panopreviewpage.cpp"
