@@ -6,7 +6,7 @@
  * Date        : 2007-11-07
  * Description : a tool to print images
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -20,9 +20,7 @@
 
 // Qt includes
 
-#include <QImage>
 #include <QSize>
-#include <QPainter>
 #include <QFileInfo>
 #include <QScopedPointer>
 
@@ -726,3 +724,5 @@ void AdvPrintTask::printCaption(QPainter& p,
 }
 
 } // namespace DigikamGenericPrintCreatorPlugin
+
+#include "moc_advprinttask.cpp"
