@@ -7,7 +7,7 @@
  * Description : Layouting photos on a page
  *
  * SPDX-FileCopyrightText: 2007-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2006-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -31,11 +31,7 @@ AtkinsPageLayoutNode::AtkinsPageLayoutNode(double aspectRatio,
                                            int    index)
     : m_a(aspectRatio),
       m_e(relativeArea),
-      m_division(0),
-      m_type(TerminalNode),
-      m_index(index),
-      m_leftChild(nullptr),
-      m_rightChild(nullptr)
+      m_index(index)
 {
 }
 
@@ -43,10 +39,7 @@ AtkinsPageLayoutNode::AtkinsPageLayoutNode(AtkinsPageLayoutNode* const subtree,
                                            AtkinsPageLayoutNode* const terminalChild,
                                            bool horizontal,
                                            int  index)
-    : m_a(0),
-      m_e(0),
-      m_division(0),
-      m_type(horizontal ? HorizontalDivision : VerticalDivision),
+    : m_type(horizontal ? HorizontalDivision : VerticalDivision),
       m_index(index),
       m_leftChild(subtree),
       m_rightChild(terminalChild)
@@ -174,7 +167,7 @@ void AtkinsPageLayoutNode::computeDivisions()
     m_leftChild->computeDivisions();
     m_rightChild->computeDivisions();
 
-    if (m_type == VerticalDivision)        // side by side
+    if      (m_type == VerticalDivision)        // side by side
     {
         double leftDivisionRoot  = std::sqrt(m_leftChild->m_e  / m_leftChild->m_a);
         double rightDivisionRoot = std::sqrt(m_rightChild->m_e / m_rightChild->m_a);
