@@ -7,7 +7,7 @@
  * Description : a tool to print images
  *
  * SPDX-FileCopyrightText: 2008-2012 by Angelo Naselli <anaselli at linux dot it>
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -54,7 +54,6 @@
 #include "advprintfinalpage.h"
 #include "templateicon.h"
 #include "dwizardpage.h"
-#include "dinfointerface.h"
 #include "dfiledialog.h"
 #include "dmetadata.h"
 
@@ -401,3 +400,5 @@ bool AdvPrintWizard::eventFilter(QObject* o, QEvent* e)
 }
 
 } // namespace DigikamGenericPrintCreatorPlugin
+
+#include "moc_advprintwizard.cpp"
