@@ -6,17 +6,9 @@
  * Date        : 2017-06-27
  * Description : a tool to export items by email.
  *
- * Copyright (C) 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -99,7 +91,7 @@ bool MailAlbumsPage::validatePage()
 
     // update image list with album contents.
 
-    foreach (const QUrl& url, d->iface->albumsItems(d->iface->albumChooserItems()))
+    Q_FOREACH (const QUrl& url, d->iface->albumsItems(d->iface->albumChooserItems()))
     {
         d->wizard->settings()->inputImages << url;
     }
@@ -118,3 +110,5 @@ bool MailAlbumsPage::isComplete() const
 }
 
 } // namespace DigikamGenericSendByMailPlugin
+
+#include "moc_mailalbumspage.cpp"
