@@ -6,7 +6,7 @@
  * Date        : 2017-05-25
  * Description : a tool to generate video slideshow from images.
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -25,6 +25,7 @@
 #include <QStyle>
 #include <QTimer>
 #include <QDir>
+#include <QTextBrowser>
 
 // KDE includes
 
@@ -38,7 +39,12 @@
 #include "dprogresswdg.h"
 #include "dhistoryview.h"
 #include "vidslidethread.h"
-#include "vidplayerdlg.h"
+
+#ifdef HAVE_MEDIAPLAYER
+
+#   include "vidplayerdlg.h"
+
+#endif
 
 namespace DigikamGenericVideoSlideShowPlugin
 {
@@ -48,46 +54,40 @@ class Q_DECL_HIDDEN VidSlideFinalPage::Private
 public:
 
     explicit Private(QWizard* const dialog)
-      : progressView(nullptr),
-        progressBar(nullptr),
-        complete(false),
-        encoder(nullptr),
-        wizard(nullptr),
-        settings(nullptr),
-        iface(nullptr)
     {
         wizard = dynamic_cast<VidSlideWizard*>(dialog);
 
         if (wizard)
         {
-            iface    = wizard->iface();
             settings = wizard->settings();
         }
     }
 
-    DHistoryView*     progressView;
-    DProgressWdg*     progressBar;
-    bool              complete;
-    VidSlideThread*   encoder;
-    VidSlideWizard*   wizard;
-    VidSlideSettings* settings;
-    DInfoInterface*   iface;
+    DHistoryView*     progressView = nullptr;
+    DProgressWdg*     progressBar  = nullptr;
+    bool              complete     = false;
+    VidSlideThread*   encoder      = nullptr;
+    VidSlideWizard*   wizard       = nullptr;
+    VidSlideSettings* settings     = nullptr;
+    QTextBrowser*     detailsText  = nullptr;
 };
 
 VidSlideFinalPage::VidSlideFinalPage(QWizard* const dialog, const QString& title)
     : DWizardPage(dialog, title),
-      d(new Private(dialog))
+      d          (new Private(dialog))
 {
     setObjectName(QLatin1String("FinalPage"));
 
     DVBox* const vbox = new DVBox(this);
     d->progressView   = new DHistoryView(vbox);
+    d->detailsText    = new QTextBrowser(vbox);
+    d->detailsText->hide();
     d->progressBar    = new DProgressWdg(vbox);
 
     vbox->setStretchFactor(d->progressBar, 10);
     vbox->setContentsMargins(QMargins());
     vbox->setSpacing(qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing)));
+                          QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing)));
 
     setPageWidget(vbox);
     setLeftBottomPix(QIcon::fromTheme(QLatin1String("system-run")));
@@ -96,7 +96,9 @@ VidSlideFinalPage::VidSlideFinalPage(QWizard* const dialog, const QString& title
 VidSlideFinalPage::~VidSlideFinalPage()
 {
     if (d->encoder)
+    {
         d->encoder->cancel();
+    }
 
     delete d;
 }
@@ -104,7 +106,10 @@ VidSlideFinalPage::~VidSlideFinalPage()
 void VidSlideFinalPage::initializePage()
 {
     d->complete = false;
+    d->detailsText->hide();
+
     Q_EMIT completeChanged();
+
     QTimer::singleShot(0, this, SLOT(slotProcess()));
 }
 
@@ -126,27 +131,10 @@ void VidSlideFinalPage::slotProcess()
     d->progressView->addEntry(i18n("%1 input images to process", d->settings->inputImages.count()),
                                   DHistoryView::ProgressEntry);
 
-    Q_FOREACH (const QUrl& url, d->settings->inputImages)
-    {
-        d->progressView->addEntry(QDir::toNativeSeparators(url.toLocalFile()),
-                                  DHistoryView::ProgressEntry);
-    }
-
-    if (!d->settings->inputAudio.isEmpty())
-    {
-        d->progressView->addEntry(i18n("%1 input audio stream to process:",
-                                       d->settings->inputAudio.count()),
-                                  DHistoryView::ProgressEntry);
-
-        Q_FOREACH (const QUrl& url, d->settings->inputAudio)
-        {
-            d->progressView->addEntry(QDir::toNativeSeparators(url.toLocalFile()),
-                                      DHistoryView::ProgressEntry);
-        }
-    }
-
     d->progressBar->setMinimum(0);
-    d->progressBar->setMaximum(d->settings->inputImages.count());
+
+    // NOTE: last stage is FFmpeg encoding.
+    d->progressBar->setMaximum(d->settings->inputImages.count() + 1);
 
     d->encoder = new VidSlideThread(this);
 
@@ -159,14 +147,19 @@ void VidSlideFinalPage::slotProcess()
     connect(d->encoder, SIGNAL(signalDone(bool)),
             this, SLOT(slotDone(bool)));
 
-    d->encoder->processStream(d->settings);
+    d->encoder->prepareFrames(d->settings);
     d->encoder->start();
 }
 
 void VidSlideFinalPage::cleanupPage()
 {
+    d->detailsText->clear();
+    d->detailsText->hide();
+
     if (d->encoder)
+    {
         d->encoder->cancel();
+    }
 }
 
 void VidSlideFinalPage::slotMessage(const QString& mess, bool err)
@@ -177,6 +170,7 @@ void VidSlideFinalPage::slotMessage(const QString& mess, bool err)
 
 void VidSlideFinalPage::slotDone(bool completed)
 {
+    d->progressBar->setValue(d->progressBar->maximum());
     d->progressBar->progressCompleted();
     d->complete = completed;
 
@@ -184,6 +178,11 @@ void VidSlideFinalPage::slotDone(bool completed)
     {
         d->progressView->addEntry(i18n("Video Slideshow is not completed"),
                                   DHistoryView::WarningEntry);
+
+        d->detailsText->show();
+        d->detailsText->setText(d->encoder->encodingTraces());
+        d->progressView->addEntry(i18n("See the video encoding trace below"),
+                                  DHistoryView::WarningEntry);
     }
     else
     {
@@ -195,15 +194,23 @@ void VidSlideFinalPage::slotDone(bool completed)
             d->progressView->addEntry(i18n("Opening video stream in player..."),
                                       DHistoryView::ProgressEntry);
 
+#ifdef HAVE_MEDIAPLAYER
+
             if (d->settings->outputPlayer == VidSlideSettings::INTERNAL)
             {
-                VidPlayerDlg* const player = new VidPlayerDlg(d->settings->outputVideo, this);
+
+
+                VidPlayerDlg* const player = new VidPlayerDlg(d->settings->outputFile, this);
                 player->show();
                 player->resize(800, 600);
+
+
             }
             else
+
+#endif
             {
-                QDesktopServices::openUrl(QUrl::fromLocalFile(d->settings->outputVideo));
+                QDesktopServices::openUrl(QUrl::fromLocalFile(d->settings->outputFile));
             }
         }
     }
@@ -217,3 +224,5 @@ bool VidSlideFinalPage::isComplete() const
 }
 
 } // namespace DigikamGenericVideoSlideShowPlugin
+
+#include "moc_vidslidefinalpage.cpp"
