@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2008-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
  * SPDX-FileCopyrightText: 2009      by Andi Clemens <andi dot clemens at googlemail dot com>
- * SPDX-FileCopyrightText: 2012-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -20,22 +20,12 @@
 
 #include <QTime>
 #include <QUrl>
-#include <QKeyEvent>
 #include <QIcon>
 
 #if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)) && defined HAVE_QTMULTIMEDIA
 
 #   include <QAudioOutput>
 
-#else
-
-// QtAV includes
-
-#   include "AVError.h"
-#   include "AVPlayerCore.h"
-
-using namespace QtAV;
-
 #endif
 
 // Local includes
@@ -68,7 +58,7 @@ public:
 
 #else
 
-    AVPlayerCore*          mediaObject = nullptr;
+    DAudioPlayer*          mediaObject = nullptr;
 
 #endif
 
@@ -133,23 +123,23 @@ PresentationAudioWidget::PresentationAudioWidget(QWidget* const parent, const QL
             this, SLOT(slotPlayerError(QMediaPlayer::Error)));
 
     connect(d->mediaObject, SIGNAL(positionChanged(qint64)),
-            this, SLOT(slotTimeUpdaterTimeout()));
+            this, SLOT(slotTimeUpdaterTimeout(qint64)));
 
 #else
 
-    d->mediaObject = new AVPlayerCore(this);
+    d->mediaObject = new DAudioPlayer(this);
 
-    connect(d->mediaObject, SIGNAL(mediaStatusChanged(QtAV::MediaStatus)),
-            this, SLOT(slotMediaStateChanged(QtAV::MediaStatus)));
+    connect(d->mediaObject->player(), SIGNAL(mediaStatusChanged(QAVPlayer::MediaStatus)),
+            this, SLOT(slotMediaStateChanged(QAVPlayer::MediaStatus)));
 
-    connect(d->mediaObject, SIGNAL(stateChanged(QtAV::AVPlayerCore::State)),
-            this, SLOT(slotPlayerStateChanged(QtAV::AVPlayerCore::State)));
+    connect(d->mediaObject->player(), SIGNAL(stateChanged(QAVPlayer::State)),
+            this, SLOT(slotPlayerStateChanged(QAVPlayer::State)));
 
-    connect(d->mediaObject, SIGNAL(error(QtAV::AVError)),
-            this, SLOT(slotPlayerError(QtAV::AVError)));
+    connect(d->mediaObject->player(), SIGNAL(errorOccurred(QAVPlayer::Error,QString)),
+            this, SLOT(slotPlayerError(QAVPlayer::Error,QString)));
 
     connect(d->mediaObject, SIGNAL(positionChanged(qint64)),
-            this, SLOT(slotTimeUpdaterTimeout()));
+            this, SLOT(slotTimeUpdaterTimeout(qint64)));
 
 #endif
 
@@ -173,23 +163,20 @@ PresentationAudioWidget::~PresentationAudioWidget()
 
 void PresentationAudioWidget::slotSetVolume(int v)
 {
+    if (d->mediaObject->audioOutput())
+    {
 
 #if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)) && defined HAVE_QTMULTIMEDIA
 
-    if (d->mediaObject->audioOutput())
-    {
         d->mediaObject->audioOutput()->setVolume(v / 100.0);
-    }
 
 #else
 
-    if (d->mediaObject->audio())
-    {
-        d->mediaObject->audio()->setVolume(v / 100.0);
-    }
+        d->mediaObject->setVolume((qreal)v / 100.0);
 
 #endif
 
+    }
 }
 
 bool PresentationAudioWidget::canHide() const
@@ -206,7 +193,7 @@ bool PresentationAudioWidget::isPaused() const
 
 #else
 
-    return d->mediaObject->isPaused();
+    return (d->mediaObject->state() == QAVPlayer::PausedState);
 
 #endif
 
@@ -324,11 +311,13 @@ void PresentationAudioWidget::slotPlay()
 
 #if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)) && defined HAVE_QTMULTIMEDIA
 
-    if ((d->mediaObject->playbackState() != QMediaPlayer::PlayingState) || (d->mediaObject->playbackState() == QMediaPlayer::PausedState))
+    if ((d->mediaObject->playbackState() != QMediaPlayer::PlayingState) ||
+        (d->mediaObject->playbackState() == QMediaPlayer::PausedState))
 
 #else
 
-    if (!d->mediaObject->isPlaying() || d->mediaObject->isPaused())
+    if ((d->mediaObject->state() != QAVPlayer::PlayingState) ||
+        (d->mediaObject->state() == QAVPlayer::PausedState))
 
 #endif
 
@@ -340,39 +329,19 @@ void PresentationAudioWidget::slotPlay()
 
 #else
 
-        if (!d->mediaObject->isPlaying())
+        if (d->mediaObject->state() != QAVPlayer::PlayingState)
 
 #endif
 
         {
-
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)) && defined HAVE_QTMULTIMEDIA
-
             d->mediaObject->setSource(d->urlList[d->currIndex]);
-
-#else
-
-            d->mediaObject->setFile(d->urlList[d->currIndex].toLocalFile());
-
-#endif
-
             qCDebug(DIGIKAM_DPLUGIN_GENERIC_LOG) << "Playing:" << d->urlList[d->currIndex];
             d->mediaObject->play();
             setZeroTime();
         }
         else
         {
-
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)) && defined HAVE_QTMULTIMEDIA
-
             d->mediaObject->pause();
-
-#else
-
-            d->mediaObject->pause(false);
-
-#endif
-
         }
 
         d->canHide = true;
@@ -451,7 +420,7 @@ void PresentationAudioWidget::slotNext()
     slotPlay();
 }
 
-void PresentationAudioWidget::slotTimeUpdaterTimeout()
+void PresentationAudioWidget::slotTimeUpdaterTimeout(qint64 current)
 {
 
 #if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)) && defined HAVE_QTMULTIMEDIA
@@ -460,7 +429,7 @@ void PresentationAudioWidget::slotTimeUpdaterTimeout()
 
 #else
 
-    if (d->mediaObject->mediaStatus() == QtAV::InvalidMedia)
+    if (d->mediaObject->mediaStatus() == QAVPlayer::InvalidMedia)
 
 #endif
 
@@ -469,13 +438,12 @@ void PresentationAudioWidget::slotTimeUpdaterTimeout()
         return;
     }
 
-    qint64 current = d->mediaObject->position();
     int hours      = (int)(current  / (qint64)(60 * 60 * 1000));
     int mins       = (int)((current / (qint64)(60 * 1000)) - (qint64)(hours * 60));
     int secs       = (int)((current / (qint64)1000) - (qint64)(hours * 60 + mins * 60));
     QTime elapsedTime(hours, mins, secs);
 
-    if (d->isZeroTime && d->mediaObject->duration() > 0)
+    if (d->isZeroTime && (d->mediaObject->duration() > 0))
     {
         d->isZeroTime = false;
         qint64 total  = d->mediaObject->duration();
@@ -503,7 +471,7 @@ void PresentationAudioWidget::slotPlayerError(QMediaPlayer::Error err)
 {
     if (err != QMediaPlayer::NoError)
     {
-        qCDebug(DIGIKAM_GENERAL_LOG) << "An error as occured while playing (" << err << ")";
+        qCDebug(DIGIKAM_GENERAL_LOG) << "An error as occurred while playing (" << err << ")";
         slotError();
     }
 }
@@ -537,36 +505,36 @@ void PresentationAudioWidget::slotPlayerStateChanged(QMediaPlayer::PlaybackState
 
 #else
 
-void PresentationAudioWidget::slotMediaStateChanged(QtAV::MediaStatus status)
+void PresentationAudioWidget::slotMediaStateChanged(QAVPlayer::MediaStatus status)
 {
-    if (d->playingNext && (status == QtAV::EndOfMedia))
+    if (status == QAVPlayer::EndOfMedia)
     {
         slotNext();
     }
 }
 
-void PresentationAudioWidget::slotPlayerError(const QtAV::AVError& err)
+void PresentationAudioWidget::slotPlayerError(QAVPlayer::Error err, const QString& message)
 {
-    if (err.error() != AVError::NoError)
+    if (err != QAVPlayer::NoError)
     {
-        qCDebug(DIGIKAM_DPLUGIN_GENERIC_LOG) << "An error as occurred while playing (" << err.string() << ")";
+        qCDebug(DIGIKAM_DPLUGIN_GENERIC_LOG) << "An error as occurred while playing (" << message << ")";
         slotError();
     }
 }
 
-void PresentationAudioWidget::slotPlayerStateChanged(QtAV::AVPlayerCore::State state)
+void PresentationAudioWidget::slotPlayerStateChanged(QAVPlayer::State state)
 {
     switch (state)
     {
-        case QtAV::AVPlayerCore::PausedState:
-        case QtAV::AVPlayerCore::StoppedState:
+        case QAVPlayer::PausedState:
+        case QAVPlayer::StoppedState:
         {
             m_playButton->setIcon(QIcon::fromTheme(QLatin1String("media-playback-start")));
             checkSkip();
             break;
         }
 
-        case QtAV::AVPlayerCore::PlayingState:
+        case QAVPlayer::PlayingState:
         {
             m_playButton->setIcon(QIcon::fromTheme(QLatin1String("media-playback-pause")));
             d->playingNext = true;
@@ -596,3 +564,5 @@ void PresentationAudioWidget::slotError()
 }
 
 } // namespace DigikamGenericPresentationPlugin
+
+#include "moc_presentationaudiowidget.cpp"
