@@ -6,7 +6,7 @@
  * Date        : 2005-04-21
  * Description : slide show tool using preview of pictures.
  *
- * SPDX-FileCopyrightText: 2005-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText:      2004 by Enrico Ros <eros dot kde at email dot it>
  * SPDX-FileCopyrightText: 2019-2020 by Minh Nghia Duong <minhnghiaduong997 at gmail dot com>
  *
@@ -20,10 +20,6 @@
 
 #include <QMimeDatabase>
 #include <QApplication>
-#include <QWheelEvent>
-#include <QMouseEvent>
-#include <QPaintEvent>
-#include <QKeyEvent>
 #include <QScreen>
 #include <QWindow>
 #include <QCursor>
@@ -875,3 +871,5 @@ void SlideShowLoader::slotScreenSelected(int screen)
 }
 
 } // namespace DigikamGenericSlideShowPlugin
+
+#include "moc_slideshowloader.cpp"
