@@ -6,7 +6,7 @@
  * Date        : 2014-09-18
  * Description : slideshow image widget
  *
- * SPDX-FileCopyrightText: 2014-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2019-2020 by Minh Nghia Duong <minhnghiaduong997 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -25,7 +25,6 @@
 // Local includes
 
 #include "digikam_debug.h"
-#include "dimg.h"
 #include "previewloadthread.h"
 
 using namespace Digikam;
@@ -185,9 +184,9 @@ void SlideImage::updatePixmap()
      * pixmap.
      */
 
-    double ratio   = qApp->devicePixelRatio();
+    double dpr     = devicePixelRatio();
 
-    QSize fullSize = QSizeF(ratio * width(), ratio * height()).toSize();
+    QSize fullSize = QSizeF(dpr * width(), dpr * height()).toSize();
     d->pixmap      = QPixmap(fullSize);
     d->pixmap.fill(Qt::black);
     QPainter p(&(d->pixmap));
@@ -202,3 +201,5 @@ void SlideImage::updatePixmap()
 }
 
 } // namespace DigikamGenericSlideShowPlugin
+
+#include "moc_slideimage.cpp"
