@@ -25,7 +25,6 @@
 #include <QJsonValue>
 #include <QJsonArray>
 #include <QByteArray>
-#include <QList>
 #include <QFileInfo>
 #include <QMessageBox>
 #include <QUrlQuery>
@@ -466,3 +465,5 @@ void GDTalker::cancel()
 }
 
 } // namespace DigikamGenericGoogleServicesPlugin
+
+#include "moc_gdtalker.cpp"
