@@ -21,7 +21,6 @@
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QGroupBox>
-#include <QRadioButton>
 #include <QDialogButtonBox>
 #include <QIcon>
 #include <QApplication>
@@ -49,3 +48,5 @@ QString ImageShackNewAlbumDlg::getAlbumTitle()
 }
 
 } // namespace DigikamGenericImageShackPlugin
+
+#include "moc_imageshacknewalbumdlg.cpp"
