@@ -34,7 +34,6 @@
 // Local includes
 
 #include "digikam_debug.h"
-#include "dinfointerface.h"
 #include "digikam_version.h"
 
 namespace DigikamGenericImgUrPlugin
@@ -325,3 +324,5 @@ void ImgurWindow::saveSettings()
 }
 
 } // namespace DigikamGenericImgUrPlugin
+
+#include "moc_imgurwindow.cpp"
