@@ -6,7 +6,7 @@
  * Date        : 2017-06-21
  * Description : a simple web browser dialog based on Qt WebEngine.
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2021      by Joerg Lohse <joergmlpts at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -63,7 +63,7 @@ class InatBrowserCookieJar : public QNetworkCookieJar
 {
 public:
 
-    InatBrowserCookieJar(QObject* const parent = nullptr)
+    explicit InatBrowserCookieJar(QObject* const parent = nullptr)
         : QNetworkCookieJar(parent)
     {
     }
@@ -372,3 +372,5 @@ void INatBrowserDlg::slotCookieRemoved(const QNetworkCookie& cookie)
 }
 
 } // namespace DigikamGenericINatPlugin
+
+#include "moc_inatbrowserdlg.cpp"
