@@ -6,7 +6,7 @@
  * Date        : 2011-03-22
  * Description : a Iface C++ interface
  *
- * SPDX-FileCopyrightText: 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2011      by Alexandre Mendes <alex dot mendes1988 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,7 +20,6 @@
 #include <QFile>
 #include <QStringList>
 #include <QTimer>
-#include <QUrl>
 #include <QUrlQuery>
 #include <QXmlStreamReader>
 #include <QNetworkAccessManager>
@@ -32,7 +31,6 @@
 
 #include "mediawiki_job_p.h"
 #include "mediawiki_iface.h"
-#include "mediawiki_queryinfo.h"
 
 namespace MediaWiki
 {
@@ -295,3 +293,5 @@ void Upload::doWorkProcessReply()
 }
 
 } // namespace MediaWiki
+
+#include "moc_mediawiki_upload.cpp"
