@@ -6,17 +6,9 @@
  * Date        : 2018-05-20
  * Description : a tool to export images to Pinterest web service
  *
- * Copyright (C) 2018      by Tarek Talaat <tarektalaat93 at gmail dot com>
+ * SPDX-FileCopyrightText: 2018      by Tarek Talaat <tarektalaat93 at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -31,8 +23,8 @@ namespace DigikamGenericPinterestPlugin
 {
 
 PWidget::PWidget(QWidget* const parent,
-                   DInfoInterface* const iface,
-                   const QString& toolName)
+                 DInfoInterface* const iface,
+                 const QString& toolName)
     : WSSettingsWidget(parent, iface, toolName)
 {
     getUploadBox()->hide();
@@ -48,7 +40,9 @@ void PWidget::updateLabels(const QString& name, const QString& url)
     QString web(QLatin1String("https://www.pinterest.com/"));
 
     if (!url.isEmpty())
+    {
         web = url;
+    }
 
     getHeaderLbl()->setText(QString::fromLatin1(
         "<b><h2><a href='%1'>"
@@ -66,3 +60,5 @@ void PWidget::updateLabels(const QString& name, const QString& url)
 }
 
 } // namespace DigikamGenericPinterestPlugin
+
+#include "moc_pwidget.cpp"
