@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * SPDX-FileCopyrightText: 2006      by Colin Guthrie <kde at colin dot guthr dot ie>
- * SPDX-FileCopyrightText: 2006-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2008      by Andrea Diamantini <adjam7 at gmail dot com>
  * SPDX-FileCopyrightText: 2010-2019 by Frederic Coiffier <frederic dot coiffier at free dot com>
  *
@@ -38,7 +38,6 @@
 
 #include "dmetadata.h"
 #include "digikam_debug.h"
-#include "piwigoitem.h"
 #include "digikam_version.h"
 #include "wstoolutils.h"
 #include "networkmanager.h"
@@ -1061,3 +1060,5 @@ void PiwigoTalker::deleteTemporaryFile()
 }
 
 } // namespace DigikamGenericPiwigoPlugin
+
+#include "moc_piwigotalker.cpp"
