@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * SPDX-FileCopyrightText: 2006      by Colin Guthrie <kde at colin dot guthr dot ie>
- * SPDX-FileCopyrightText: 2006-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2008      by Andrea Diamantini <adjam7 at gmail dot com>
  * SPDX-FileCopyrightText: 2010-2014 by Frederic Coiffier <frederic dot coiffier at free dot com>
  *
@@ -51,7 +51,6 @@
 #include "digikam_debug.h"
 #include "piwigosession.h"
 #include "piwigologindlg.h"
-#include "piwigoitem.h"
 #include "piwigotalker.h"
 #include "imagedialog.h"
 #include "ditemslist.h"
@@ -745,3 +744,5 @@ void PiwigoWindow::setUiInProgressState(bool inProgress)
 }
 
 } // namespace DigikamGenericPiwigoPlugin
+
+#include "moc_piwigowindow.cpp"
