@@ -7,7 +7,7 @@
  * Description : albums history manager.
  *
  * SPDX-FileCopyrightText: 2004      by Joern Ahrens <joern dot ahrens at kdemail dot net>
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -27,9 +27,7 @@
 
 #include "digikam_debug.h"
 #include "album.h"
-#include "iteminfo.h"
 #include "albummanager.h"
-#include "labelstreeview.h"
 
 // NOTE: ust be declared outside namespace
 
@@ -613,3 +611,5 @@ void AlbumHistory::slotAlbumsCleared()
 }
 
 } // namespace Digikam
+
+#include "moc_albumhistory.cpp"
