@@ -6,7 +6,7 @@
  * Date        : 2004-06-15
  * Description : Albums manager interface - Tag Album helpers.
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
@@ -189,6 +189,8 @@ void AlbumManager::tagItemsCount()
 {
     if (d->tagListJob)
     {
+        disconnect(d->tagListJob, nullptr, this, nullptr);
+
         d->tagListJob->cancel();
         d->tagListJob = nullptr;
     }
@@ -1005,7 +1007,10 @@ void AlbumManager::slotTagChange(const TagChangeset& changeset)
         case TagChangeset::Deleted:
         case TagChangeset::Reparented:
         {
-            d->scanTAlbumsTimer->start();
+            if (!d->scanTAlbumsTimer->isActive())
+            {
+                d->scanTAlbumsTimer->start();
+            }
 
             break;
         }
@@ -1068,7 +1073,10 @@ void AlbumManager::slotImageTagChange(const ImageTagChangeset& changeset)
                 }
             }
 
-            d->tagItemCountTimer->start();
+            if (!d->tagItemCountTimer->isActive())
+            {
+                d->tagItemCountTimer->start();
+            }
 
             break;
         }
@@ -1096,6 +1104,13 @@ void AlbumManager::askUserForWriteChangedTAlbumToFiles(const QList<qlonglong>& i
         return;
     }
 
+    if (settings->settings().useLazySync)
+    {
+        MetadataHubMngr::instance()->addPendingIds(imageIds);
+
+        return;
+    }
+
     if (imageIds.count() > 100)
     {
         int result = d->longTimeMessageBoxResult;
