@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2008-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2010-2011 by Andi Clemens <andi dot clemens at gmail dot com>
- * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -40,14 +40,8 @@ class Q_DECL_HIDDEN AlbumSelectComboBox::Private
 {
 public:
 
-    explicit Private(AlbumSelectComboBox* const q)
-      : model                   (nullptr),
-        filterModel             (nullptr),
-        recursive               (false),
-        isCheckable             (true),
-        closeOnActivate         (false),
-        showCheckStateSummary   (true),
-        q                       (q)
+    explicit Private(AlbumSelectComboBox* const qq)
+        : q(qq)
     {
     }
 
@@ -56,13 +50,14 @@ public:
 
 public:
 
-    AbstractCheckableAlbumModel* model;
-    AlbumFilterModel*            filterModel;
+    AbstractCheckableAlbumModel* model                  = nullptr;
+    AlbumFilterModel*            filterModel            = nullptr;
     QString                      noSelectionText;
-    bool                         recursive;
-    bool                         isCheckable;
-    bool                         closeOnActivate;
-    bool                         showCheckStateSummary;
+    bool                         recursive              = false;
+    bool                         isCheckable            = true;
+    bool                         closeOnActivate        = false;
+    bool                         allSelectedText        = false;
+    bool                         showCheckStateSummary  = true;
 
     AlbumSelectComboBox* const   q;
 };
@@ -76,6 +71,7 @@ AlbumSelectComboBox::AlbumSelectComboBox(QWidget* const parent)
     // Workaround for QLineEdit text when QComboBox loses focus
 
     // --- NOTE: use dynamic binding as updateText() is a virtual slot which can be re-implemented in derived classes.
+
     connect(this, &AlbumSelectComboBox::editTextChanged,
             this, &AlbumSelectComboBox::updateText);
 }
@@ -136,8 +132,10 @@ void AlbumSelectComboBox::installView(QAbstractItemView* v)
 
     // cppcheck-suppress nullPointerRedundantCheck
     view()->sortByColumn(0, Qt::AscendingOrder);
+
     // cppcheck-suppress nullPointerRedundantCheck
     view()->setSortingEnabled(true);
+
     // cppcheck-suppress nullPointerRedundantCheck
     view()->collapseAll();
 }
@@ -225,6 +223,12 @@ void AlbumSelectComboBox::setNoSelectionText(const QString& text)
     updateText();
 }
 
+void AlbumSelectComboBox::setAllSelectedText(bool all)
+{
+    d->allSelectedText = all;
+    updateText();
+}
+
 void AlbumSelectComboBox::setShowCheckStateSummary(bool show)
 {
     d->showCheckStateSummary = show;
@@ -256,7 +260,24 @@ void AlbumSelectComboBox::updateText()
         return;
     }
 
-    QList<Album*> checkedAlbums          = d->model->checkedAlbums();
+    QList<Album*> checkedAlbums;
+
+    if (!d->allSelectedText)
+    {
+        checkedAlbums = d->model->checkedAlbums();
+    }
+    else
+    {
+        if (d->model->albumType() == Album::TAG)
+        {
+            checkedAlbums = AlbumManager::instance()->allTAlbums();
+        }
+        else
+        {
+            checkedAlbums = AlbumManager::instance()->allPAlbums();
+        }
+    }
+
     QList<Album*> partiallyCheckedAlbums = d->model->partiallyCheckedAlbums();
     QString newIncludeText;
     QString newExcludeText;
@@ -271,24 +292,28 @@ void AlbumSelectComboBox::updateText()
         {
             if (d->model->albumType() == Album::TAG)
             {
-                newIncludeText = i18np("1 Tag selected", "%1 Tags selected", checkedAlbums.count());
+                newIncludeText = i18np("1 Tag selected", "%1 Tags selected",
+                                       checkedAlbums.count());
             }
             else
             {
-                newIncludeText = i18np("1 Album selected", "%1 Albums selected", checkedAlbums.count());
+                newIncludeText = i18np("1 Album selected", "%1 Albums selected",
+                                       checkedAlbums.count());
             }
         }
     }
 
-    if (!partiallyCheckedAlbums.isEmpty())
+    if (!partiallyCheckedAlbums.isEmpty() && !d->allSelectedText)
     {
         if (d->model->albumType() == Album::TAG)
         {
-            newExcludeText = i18np("1 Tag excluded", "%1 Tags excluded", partiallyCheckedAlbums.count());
+            newExcludeText = i18np("1 Tag excluded", "%1 Tags excluded",
+                                   partiallyCheckedAlbums.count());
         }
         else
         {
-            newExcludeText = i18np("1 Album excluded", "%1 Albums excluded", partiallyCheckedAlbums.count());
+            newExcludeText = i18np("1 Album excluded", "%1 Albums excluded",
+                                   partiallyCheckedAlbums.count());
         }
     }
 
@@ -475,3 +500,5 @@ void TagTreeViewSelectComboBox::setAlbumModels(TagModel* model,
 } // namespace Digikam
 
 #include "albumselectcombobox.moc"
+
+#include "moc_albumselectcombobox.cpp"
