@@ -7,7 +7,7 @@
  * Description : A widget to select Physical or virtual albums with combo-box
  *
  * SPDX-FileCopyrightText: 2010-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -68,22 +68,7 @@ class Q_DECL_HIDDEN AlbumSelectors::Private
 {
 public:
 
-    explicit Private()
-      : albumSelectCB          (nullptr),
-        tagSelectCB            (nullptr),
-        albumClearButton       (nullptr),
-        tagClearButton         (nullptr),
-        recursiveSelectionAlbum(nullptr),
-        wholeAlbums            (nullptr),
-        recursiveSelectionTags (nullptr),
-        wholeTags              (nullptr),
-        tabWidget              (nullptr),
-        albumWidget            (nullptr),
-        tagWidget              (nullptr),
-        selectionMode          (All),
-        allowRecursive         (false)
-    {
-    }
+    Private() = default;
 
     static const QString         configUseWholeAlbumsEntry;
     static const QString         configUseWholeTagsEntry;
@@ -91,23 +76,23 @@ public:
 
     QString                      configName;
 
-    AlbumTreeViewSelectComboBox* albumSelectCB;
-    TagTreeViewSelectComboBox*   tagSelectCB;
-    ModelClearButton*            albumClearButton;
-    ModelClearButton*            tagClearButton;
+    AlbumTreeViewSelectComboBox* albumSelectCB              = nullptr;
+    TagTreeViewSelectComboBox*   tagSelectCB                = nullptr;
+    ModelClearButton*            albumClearButton           = nullptr;
+    ModelClearButton*            tagClearButton             = nullptr;
 
-    QCheckBox*                   recursiveSelectionAlbum;
-    QCheckBox*                   wholeAlbums;
-    QCheckBox*                   recursiveSelectionTags;
-    QCheckBox*                   wholeTags;
+    QCheckBox*                   recursiveSelectionAlbum    = nullptr;
+    QCheckBox*                   wholeAlbums                = nullptr;
+    QCheckBox*                   recursiveSelectionTags     = nullptr;
+    QCheckBox*                   wholeTags                  = nullptr;
 
-    QTabWidget*                  tabWidget;
-    QWidget*                     albumWidget;
-    QWidget*                     tagWidget;
+    QTabWidget*                  tabWidget                  = nullptr;
+    QWidget*                     albumWidget                = nullptr;
+    QWidget*                     tagWidget                  = nullptr;
 
-    AlbumType                    selectionMode;
+    AlbumType                    selectionMode              = All;
 
-    bool                         allowRecursive;
+    bool                         allowRecursive             = false;
 };
 
 const QString AlbumSelectors::Private::configUseWholeAlbumsEntry(QLatin1String("UseWholeAlbumsEntry"));
@@ -177,8 +162,9 @@ AlbumSelectors::~AlbumSelectors()
 void AlbumSelectors::initAlbumWidget()
 {
     d->albumWidget             = new QWidget(this);
-    d->wholeAlbums             = new QCheckBox(i18nc("@option", "Whole albums collection"), d->albumWidget);
-    d->recursiveSelectionAlbum = new QCheckBox(i18nc("@option", "Recursive Selection"), d->albumWidget);
+    d->wholeAlbums             = new QCheckBox(i18nc("@option", "All albums"), d->albumWidget);
+    d->recursiveSelectionAlbum = new QCheckBox(i18nc("@option", "Recursive"), d->albumWidget);
+    d->recursiveSelectionAlbum->setToolTip(i18nc("@info:tooltip", "Recursive selection."));
     d->recursiveSelectionAlbum->setChecked(true);
 
     if (!d->allowRecursive)
@@ -192,7 +178,10 @@ void AlbumSelectors::initAlbumWidget()
     d->albumSelectCB->setDefaultModel();
     d->albumSelectCB->setRecursive(d->allowRecursive ? d->recursiveSelectionAlbum->isChecked() : false);
     d->albumSelectCB->setNoSelectionText(i18nc("@info", "No Album Selected"));
-    //d->albumSelectCB->setAddExcludeTristate(true);
+/*
+    d->albumSelectCB->setAddExcludeTristate(true);
+
+*/
     d->albumSelectCB->addCheckUncheckContextMenuActions();
 
     d->albumClearButton = new ModelClearButton(d->albumSelectCB->view()->albumModel());
@@ -216,7 +205,7 @@ void AlbumSelectors::initAlbumWidget()
             this, SIGNAL(signalSelectionChanged()));
 
     connect(d->recursiveSelectionAlbum, &QCheckBox::clicked,
-            [this] (bool checked)
+            d->recursiveSelectionAlbum, [this] (bool checked)
         {
             d->albumSelectCB->setRecursive(checked);
         }
@@ -233,8 +222,9 @@ void AlbumSelectors::initAlbumWidget()
 void AlbumSelectors::initTagWidget()
 {
     d->tagWidget              = new QWidget(this);
-    d->wholeTags              = new QCheckBox(i18nc("@option", "Whole tags collection"), d->tagWidget);
-    d->recursiveSelectionTags = new QCheckBox(i18nc("@option", "Recursive Selection"), d->albumWidget);
+    d->wholeTags              = new QCheckBox(i18nc("@option", "All tags"), d->tagWidget);
+    d->recursiveSelectionTags = new QCheckBox(i18nc("@option", "Recursive"), d->albumWidget);
+    d->recursiveSelectionTags->setToolTip(i18nc("@info:tooltip", "Recursive selection."));
     d->recursiveSelectionTags->setChecked(true);
 
     if (!d->allowRecursive)
@@ -274,7 +264,7 @@ void AlbumSelectors::initTagWidget()
             this, SLOT(slotUpdateClearButtons()));
 
     connect(d->recursiveSelectionTags, &QCheckBox::clicked,
-            [this] (bool checked)
+            d->recursiveSelectionTags, [this] (bool checked)
         {
             d->tagSelectCB->setRecursive(checked);
         }
@@ -292,6 +282,7 @@ void AlbumSelectors::slotWholeAlbums(bool b)
     {
         d->albumSelectCB->setEnabled(!b);
         d->albumClearButton->setEnabled(!b);
+        d->albumSelectCB->setAllSelectedText(b);
     }
 
     updateTabText();
@@ -303,6 +294,7 @@ void AlbumSelectors::slotWholeTags(bool b)
     {
         d->tagSelectCB->setEnabled(!b);
         d->tagClearButton->setEnabled(!b);
+        d->tagSelectCB->setAllSelectedText(b);
     }
 
     updateTabText();
@@ -556,3 +548,5 @@ void AlbumSelectors::updateTabText()
 } // namespace Digikam
 
 #include "albumselectors.moc"
+
+#include "moc_albumselectors.cpp"
