@@ -6,20 +6,11 @@
  * Date        : 2007-03-21
  * Description : Collection scanning to database - private containers.
  *
- * Copyright (C) 2005-2006 by Tom Albers <tomalbers at kde dot nl>
- * Copyright (C) 2007-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2006 by Tom Albers <tomalbers at kde dot nl>
+ * SPDX-FileCopyrightText: 2007-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -125,7 +116,7 @@ void CollectionScannerHintContainerImplementation::recordHints(const QList<Album
 {
     QWriteLocker locker(&lock);
 
-    foreach (const AlbumCopyMoveHint& hint, hints)
+    Q_FOREACH (const AlbumCopyMoveHint& hint, hints)
     {
         // automagic casting to src and dst
 
@@ -137,7 +128,7 @@ void CollectionScannerHintContainerImplementation::recordHints(const QList<ItemC
 {
     QWriteLocker locker(&lock);
 
-    foreach (const ItemCopyMoveHint& hint, hints)
+    Q_FOREACH (const ItemCopyMoveHint& hint, hints)
     {
         QList<qlonglong> ids = hint.srcIds();
         QStringList dstNames = hint.dstNames();
@@ -153,7 +144,7 @@ void CollectionScannerHintContainerImplementation::recordHints(const QList<ItemC
 {
     QWriteLocker locker(&lock);
 
-    foreach (const ItemChangeHint& hint, hints)
+    Q_FOREACH (const ItemChangeHint& hint, hints)
     {
         const QList<qlonglong>& ids = hint.ids();
 
