@@ -6,19 +6,10 @@
  * Date        : 2007-04-15
  * Description : Core database abstract backend.
  *
- * Copyright (C) 2007-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -64,6 +55,7 @@ bool CoreDbBackend::initSchema(CoreDbSchemaUpdater* updater)
     if (updater->update())
     {
         d->status = OpenSchemaChecked;
+
         return true;
     }
 
@@ -116,3 +108,5 @@ void CoreDbBackend::recordChangeset(const SearchChangeset& changeset)
 }
 
 } // namespace Digikam
+
+#include "moc_coredbbackend.cpp"
