@@ -7,7 +7,7 @@
  * Description : Core database field enumerations.
  *
  * SPDX-FileCopyrightText: 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -71,17 +71,17 @@ typedef uint8_t ImagesMinSizeType;
 enum ItemInformationField
 {
     ItemInformationNone  = 0,
-    Rating                = 1 << 0,
-    CreationDate          = 1 << 1,
-    DigitizationDate      = 1 << 2,
-    Orientation           = 1 << 3,
-    Width                 = 1 << 4,
-    Height                = 1 << 5,
-    Format                = 1 << 6,
-    ColorDepth            = 1 << 7,
-    ColorModel            = 1 << 8,
-    ColorLabel            = 1 << 9,
-    PickLabel             = 1 << 10,
+    Rating               = 1 << 0,
+    CreationDate         = 1 << 1,
+    DigitizationDate     = 1 << 2,
+    Orientation          = 1 << 3,
+    Width                = 1 << 4,
+    Height               = 1 << 5,
+    Format               = 1 << 6,
+    ColorDepth           = 1 << 7,
+    ColorModel           = 1 << 8,
+    ColorLabel           = 1 << 9,
+    PickLabel            = 1 << 10,
     ItemInformationAll   = Rating           |
                            CreationDate     |
                            DigitizationDate |
@@ -267,14 +267,11 @@ template<typename FieldName> class DatabaseFieldsEnumIterator
 
 public:
 
-    DatabaseFieldsEnumIterator()
-      : i(FieldMetaInfo<FieldName>::First)
-    {
-    }
+    DatabaseFieldsEnumIterator() = default;
 
     bool atEnd() const
     {
-        return i > FieldMetaInfo<FieldName>::Last;
+        return (i > FieldMetaInfo<FieldName>::Last);
     }
 
     void operator++()
@@ -289,7 +286,7 @@ public:
 
 private:
 
-    int i;
+    int i = FieldMetaInfo<FieldName>::First;
 };
 
 /**
@@ -534,37 +531,37 @@ public:
 
     static inline unsigned int uniqueKey(ItemInformation f)
     {
-        return (unsigned int)f | (1 << 26);
+        return (unsigned int)f | (unsigned int)(1 << 26);
     }
 
     static inline unsigned int uniqueKey(ImageMetadata f)
     {
-        return (unsigned int)f | (2 << 26);
+        return (unsigned int)f | (unsigned int)(2 << 26);
     }
 
     static inline unsigned int uniqueKey(ItemComments f)
     {
-        return (unsigned int)f | (3 << 26);
+        return (unsigned int)f | (unsigned int)(3 << 26);
     }
 
     static inline unsigned int uniqueKey(ItemPositions f)
     {
-        return (unsigned int)f | (4 << 26);
+        return (unsigned int)f | (unsigned int)(4 << 26);
     }
 
     static inline unsigned int uniqueKey(ImageHistoryInfo f)
     {
-        return (unsigned int)f | (5 << 26);
+        return (unsigned int)f | (unsigned int)(5 << 26);
     }
 
     static inline unsigned int uniqueKey(VideoMetadata f)
     {
-        return (unsigned int)f | (6 << 26);
+        return (unsigned int)f | (unsigned int)(6 << 26);
     }
 
     static inline unsigned int uniqueKey(CustomEnum f)
     {
-        return (unsigned int)f | (63 << 26);
+        return (unsigned int)f | ((unsigned int)(63) << 26);
     }
 
     // override relevant methods from QHash
