@@ -7,7 +7,7 @@
  * Description : Core database image properties synchronizer
  *
  * SPDX-FileCopyrightText: 2007-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -28,7 +28,6 @@
 // Local includes
 
 #include "collectionmanager.h"
-#include "digikam_config.h"
 
 namespace Digikam
 {
@@ -457,3 +456,5 @@ void CoreDbWatch::slotSearchChangeDBus(const QString& databaseIdentifier,
 #endif
 
 } // namespace Digikam
+
+#include "moc_coredbwatch.cpp"
