@@ -16,8 +16,6 @@
 
 // Local includes
 
-#include "dbjobsthread.h"
-#include "dbjobinfo.h"
 
 namespace Digikam
 {
@@ -113,3 +111,5 @@ GPSDBJobsThread* DBJobsManager::startGPSJobThread(const GPSDBJobInfo& jInfo)
 }
 
 } // namespace Digikam
+
+#include "moc_dbjobsmanager.cpp"
