@@ -7,7 +7,7 @@
  * Description : Database Engine element configuration loader
  *
  * SPDX-FileCopyrightText: 2009-2010 by Holger Foerster <hamsi2k at freenet dot de>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -19,7 +19,6 @@
 
 #include <QDir>
 #include <QDomDocument>
-#include <QDomElement>
 #include <QDomNode>
 #include <QDomNodeList>
 #include <QFile>
@@ -133,9 +132,9 @@ void DbEngineConfigSettingsLoader::readDBActions(const QDomElement& sqlStatement
 
         DbEngineAction action;
         action.name = dbActionElement.attribute(QLatin1String("name"));
-
-        //qCDebug(DIGIKAM_DBENGINE_LOG) << "Getting attribute " << dbActionElement.attribute("name");
-
+/*
+        qCDebug(DIGIKAM_DBENGINE_LOG) << "Getting attribute " << dbActionElement.attribute("name");
+*/
         if (dbActionElement.hasAttribute(QLatin1String("mode")))
         {
             action.mode = dbActionElement.attribute(QLatin1String("mode"));
@@ -143,7 +142,7 @@ void DbEngineConfigSettingsLoader::readDBActions(const QDomElement& sqlStatement
 
         QDomElement databaseElement = dbActionElement.firstChildElement(QLatin1String("statement"));
 
-        for ( ; !databaseElement.isNull();  databaseElement = databaseElement.nextSiblingElement(QLatin1String("statement")))
+        for ( ; !databaseElement.isNull() ;  databaseElement = databaseElement.nextSiblingElement(QLatin1String("statement")))
         {
             if (!databaseElement.hasAttribute(QLatin1String("mode")))
             {
@@ -232,9 +231,9 @@ bool DbEngineConfigSettingsLoader::readConfig(const QString& filepath, int xmlVe
                             filepath);
         return false;
     }
-
-    //qCDebug(DIGIKAM_DBENGINE_LOG) << "Default DB Node contains: " << defaultDB.text();
-
+/*
+    qCDebug(DIGIKAM_DBENGINE_LOG) << "Default DB Node contains: " << defaultDB.text();
+*/
     QDomElement databaseElement = element.firstChildElement(QLatin1String("database"));
 
     for ( ; !databaseElement.isNull(); databaseElement=databaseElement.nextSiblingElement(QLatin1String("database")))
