@@ -7,7 +7,7 @@
  * Description : Database engine gui error handler
  *
  * SPDX-FileCopyrightText: 2009-2010 by Holger Foerster <Hamsi2k at freenet dot de>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -21,7 +21,6 @@
 #include <QMutexLocker>
 #include <QSqlDatabase>
 #include <QSqlError>
-#include <QThread>
 #include <QWaitCondition>
 #include <QProgressDialog>
 #include <QMessageBox>
@@ -45,14 +44,10 @@ class Q_DECL_HIDDEN DbEngineConnectionChecker::Private
 
 public:
 
-    explicit Private()
-        : stop(false),
-          success(false)
-    {
-    }
+    Private() = default;
 
-    bool               stop;
-    bool               success;
+    bool               stop     = false;
+    bool               success  = false;
 
     QMutex             mutex;
     QWaitCondition     condVar;
@@ -138,15 +133,12 @@ class Q_DECL_HIDDEN DbEngineGuiErrorHandler::Private
 
 public:
 
-    explicit Private()
-        : checker(nullptr)
-    {
-    }
+    Private() = default;
 
     QPointer<QProgressDialog>  dialog;
 
     DbEngineParameters         parameters;
-    DbEngineConnectionChecker* checker;
+    DbEngineConnectionChecker* checker      = nullptr;
 };
 
 DbEngineGuiErrorHandler::DbEngineGuiErrorHandler(const DbEngineParameters& parameters)
@@ -194,6 +186,7 @@ bool DbEngineGuiErrorHandler::checkDatabaseConnection()
 
     bool result = d->checker->checkSuccessful();
     delete d->checker;
+
     return result;
 }
 
@@ -248,3 +241,5 @@ void DbEngineGuiErrorHandler::consultUserForError(DbEngineErrorAnswer* answer, c
 }
 
 } // namespace Digikam
+
+#include "moc_dbengineguierrorhandler.cpp"
