@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2007-2008 by Marcel Wiesweg  <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2010      by Holger Foerster <hamsi2k at freenet dot de>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier  <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2018      by Mario Frank     <mario dot frank at uni minus potsdam dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -383,7 +383,7 @@ void DbEngineParameters::readFromConfig(const QString& configGroup)
         databaseNameThumbnails    = group.readPathEntry(configDatabaseNameThumbnails,            QString());
         databaseNameFace          = group.readPathEntry(configDatabaseNameFace,                  QString());
         databaseNameSimilarity    = group.readPathEntry(configDatabaseNameSimilarity,            QString());
-        walMode                   = group.readEntry(configDatabaseWALMode,                       false);
+        walMode                   = group.readEntry(configDatabaseWALMode,                       true);
     }
     else
     {
@@ -417,12 +417,24 @@ void DbEngineParameters::readFromConfig(const QString& configGroup)
 
 #if defined(HAVE_MYSQLSUPPORT) && defined(HAVE_INTERNALMYSQL)
 
-    internalServer                = group.readEntry(configInternalDatabaseServer,                false);
-    internalServerDBPath          = group.readEntry(configInternalDatabaseServerPath,            serverPrivatePath());
-    internalServerMysqlInitCmd    = group.readEntry(configInternalDatabaseServerMysqlInitCmd,    defaultMysqlInitCmd());
-    internalServerMysqlAdminCmd   = group.readEntry(configInternalDatabaseServerMysqlAdminCmd,   defaultMysqlAdminCmd());
-    internalServerMysqlServerCmd  = group.readEntry(configInternalDatabaseServerMysqlServerCmd,  defaultMysqlServerCmd()); 
-    internalServerMysqlUpgradeCmd = group.readEntry(configInternalDatabaseServerMysqlUpgradeCmd, defaultMysqlUpgradeCmd());
+    if (isSQLite())
+    {
+        internalServer                = group.readEntry(configInternalDatabaseServer,                false);
+        internalServerDBPath          = group.readEntry(configInternalDatabaseServerPath,            QString());
+        internalServerMysqlInitCmd    = group.readEntry(configInternalDatabaseServerMysqlInitCmd,    QString());
+        internalServerMysqlAdminCmd   = group.readEntry(configInternalDatabaseServerMysqlAdminCmd,   QString());
+        internalServerMysqlServerCmd  = group.readEntry(configInternalDatabaseServerMysqlServerCmd,  QString());
+        internalServerMysqlUpgradeCmd = group.readEntry(configInternalDatabaseServerMysqlUpgradeCmd, QString());
+    }
+    else
+    {
+        internalServer                = group.readEntry(configInternalDatabaseServer,                false);
+        internalServerDBPath          = group.readEntry(configInternalDatabaseServerPath,            serverPrivatePath());
+        internalServerMysqlInitCmd    = group.readEntry(configInternalDatabaseServerMysqlInitCmd,    defaultMysqlInitCmd());
+        internalServerMysqlAdminCmd   = group.readEntry(configInternalDatabaseServerMysqlAdminCmd,   defaultMysqlAdminCmd());
+        internalServerMysqlServerCmd  = group.readEntry(configInternalDatabaseServerMysqlServerCmd,  defaultMysqlServerCmd());
+        internalServerMysqlUpgradeCmd = group.readEntry(configInternalDatabaseServerMysqlUpgradeCmd, defaultMysqlUpgradeCmd());
+    }
 
 #else
 
@@ -874,7 +886,7 @@ QString DbEngineParameters::defaultMysqlInitCmd()      // For Linux, Windows and
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group(configGroupDatabase);
 
-    if (group.readEntry(configInternalDatabaseServerUseMariaDB, false))
+    if (group.readEntry(configInternalDatabaseServerUseMariaDB, true))
     {
         return QLatin1String("mariadb-install-db");
     }
@@ -887,7 +899,7 @@ QString DbEngineParameters::defaultMysqlAdminCmd()     // For Linux, Windows and
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group(configGroupDatabase);
 
-    if (group.readEntry(configInternalDatabaseServerUseMariaDB, false))
+    if (group.readEntry(configInternalDatabaseServerUseMariaDB, true))
     {
         return QLatin1String("mariadb-admin");
     }
@@ -900,7 +912,7 @@ QString DbEngineParameters::defaultMysqlServerCmd()    // For Linux, Windows and
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group(configGroupDatabase);
 
-    if (group.readEntry(configInternalDatabaseServerUseMariaDB, false))
+    if (group.readEntry(configInternalDatabaseServerUseMariaDB, true))
     {
         return QLatin1String("mariadbd");
     }
@@ -913,7 +925,7 @@ QString DbEngineParameters::defaultMysqlUpgradeCmd()   // For Linux, Windows and
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group(configGroupDatabase);
 
-    if (group.readEntry(configInternalDatabaseServerUseMariaDB, false))
+    if (group.readEntry(configInternalDatabaseServerUseMariaDB, true))
     {
         return QLatin1String("mariadb-upgrade");
     }
@@ -939,7 +951,7 @@ QDebug operator<<(QDebug dbg, const DbEngineParameters& p)
     dbg.nospace() << "   Internal Server Path:        " << p.internalServerDBPath                              << QT_ENDL;
     dbg.nospace() << "   Internal Server Init Cmd:    " << p.internalServerMysqlInitCmd                        << QT_ENDL;
     dbg.nospace() << "   Internal Server Admin Cmd:   " << p.internalServerMysqlAdminCmd                       << QT_ENDL;
-    dbg.nospace() << "   Internal Server Server Cmd:  " << p.internalServerMysqlServerCmd                      << QT_ENDL;
+    dbg.nospace() << "   Internal Server Program Cmd: " << p.internalServerMysqlServerCmd                      << QT_ENDL;
     dbg.nospace() << "   Internal Server Upgrade Cmd: " << p.internalServerMysqlUpgradeCmd                     << QT_ENDL;
     dbg.nospace() << "   Username:                    " << p.userName                                          << QT_ENDL;
     dbg.nospace() << "   Password:                    " << QString().fill(QLatin1Char('X'), p.password.size()) << QT_ENDL;
