@@ -6,21 +6,12 @@
  * Date        : 2005-04-21
  * Description : Handling access to one item and associated data - Groups
  *
- * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2007-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2013      by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2005      by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -68,7 +59,7 @@ void ItemInfoList::loadGroupImageIds() const
 {
     ItemInfoList infoList;
 
-    foreach (const ItemInfo& info, *this)
+    Q_FOREACH (const ItemInfo& info, *this)
     {
         if (info.m_data && !info.m_data->groupImageCached)
         {
@@ -180,7 +171,7 @@ void ItemInfo::addToGroup(const ItemInfo& givenLeader)
 
     idsToBeGrouped << m_data->id;
 
-    foreach (const qlonglong& ids, idsToBeGrouped)
+    Q_FOREACH (const qlonglong& ids, idsToBeGrouped)
     {
         // remove current grouping
 
