@@ -7,7 +7,7 @@
  * Description : Listing information from database - PAlbum helpers.
  *
  * SPDX-FileCopyrightText: 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2007-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2015      by Mohamed_Anwer  <m_dot_anwer at gmx dot com>
  * SPDX-FileCopyrightText: 2018      by Mario Frank    <mario dot frank at uni minus potsdam dot de>
  *
@@ -118,8 +118,10 @@ void ItemLister::listPAlbum(ItemListerReceiver* const receiver,
         record.format            = (*it).toString();
         ++it;
         record.creationDate      = (*it).toDateTime();
+        record.creationDate.setTimeSpec(Qt::UTC);
         ++it;
         record.modificationDate  = (*it).toDateTime();
+        record.modificationDate.setTimeSpec(Qt::UTC);
         ++it;
         record.fileSize          = (*it).toLongLong();
         ++it;
