@@ -7,7 +7,7 @@
  * Description : database SQL queries helper class
  *
  * SPDX-FileCopyrightText: 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -45,8 +45,8 @@ public:
     QString&                sql;
     SearchXmlCachingReader& reader;
     QList<QVariant>*        boundValues;
-    ItemQueryPostHooks*     hooks;
-    SearchXml::Relation     relation;
+    ItemQueryPostHooks*     hooks       = nullptr;
+    SearchXml::Relation     relation    = SearchXml::Equal;
 
 public:
 
