@@ -7,7 +7,7 @@
  * Description : Scanning a single item - file metadata helper.
  *
  * SPDX-FileCopyrightText: 2007-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2013-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -78,15 +78,22 @@ QDateTime ItemScanner::creationDateFromFilesystem(const QFileInfo& info)
 
     if (ctime.isValid())
     {
+        ctime.setTimeSpec(Qt::UTC);
+
         return ctime;
     }
 
     if (mtime.isValid())
     {
+        mtime.setTimeSpec(Qt::UTC);
+
         return mtime;
     }
 
-    return QDateTime::currentDateTime();
+    QDateTime dateTime = QDateTime::currentDateTime();
+    dateTime.setTimeSpec(Qt::UTC);
+
+    return dateTime;
 }
 
 void ItemScanner::scanItemInformation()
