@@ -6,22 +6,13 @@
  * Date        : 2009-03-05
  * Description : Filter values for use with ItemFilterModel
  *
- * Copyright (C) 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C)      2010 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C)      2011 by Michael G. Hansen <mike at mghansen dot de>
- * Copyright (C)      2014 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * SPDX-FileCopyrightText: 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText:      2010 by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText:      2011 by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText:      2014 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -48,13 +39,6 @@ namespace Digikam
 {
 
 ItemFilterSettings::ItemFilterSettings()
-    : m_untaggedFilter      (false),
-      m_matchingCond        (OrCondition),
-      m_ratingFilter        (0),
-      m_ratingCond          (GreaterEqualCondition),
-      m_isUnratedExcluded   (false),
-      m_mimeTypeFilter      (MimeFilter::AllFiles),
-      m_geolocationCondition(GeolocationNoFilter)
 {
 }
 
@@ -278,7 +262,7 @@ void ItemFilterSettings::setIdWhitelist(const QList<qlonglong>& idList, const QS
 template <class ContainerA, class ContainerB>
 bool containsAnyOf(const ContainerA& listA, const ContainerB& listB)
 {
-    foreach (const typename ContainerA::value_type& a, listA)
+    Q_FOREACH (const typename ContainerA::value_type& a, listA)
     {
         if (listB.contains(a))
         {
@@ -292,7 +276,7 @@ bool containsAnyOf(const ContainerA& listA, const ContainerB& listB)
 template <class ContainerA, typename Value, class ContainerB>
 bool containsNoneOfExcept(const ContainerA& list, const ContainerB& noneOfList, const Value& exception)
 {
-    foreach (const typename ContainerB::value_type& n, noneOfList)
+    Q_FOREACH (const typename ContainerB::value_type& n, noneOfList)
     {
         if (n != exception && list.contains(n))
         {
@@ -317,7 +301,7 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
 
     bool match = false;
 
-    if (!m_includeTagFilter.isEmpty() || !m_excludeTagFilter.isEmpty())
+    if      (!m_includeTagFilter.isEmpty() || !m_excludeTagFilter.isEmpty())
     {
         QList<int>                 tagIds = info.tagIds();
         QList<int>::const_iterator it;
@@ -340,6 +324,7 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
         else // AND matching condition...
         {
             // m_untaggedFilter and non-empty tag filter, combined with AND, is logically no match
+
             if (!m_untaggedFilter)
             {
                 for (it = m_includeTagFilter.begin() ; it != m_includeTagFilter.end() ; ++it)
@@ -421,6 +406,7 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
             {
                 // Searching for "has no ColorLabel" requires special handling:
                 // Scan that the tag ids contains none of the ColorLabel tags, except maybe the NoColorLabel tag
+
                 matchCL = containsNoneOfExcept(tagIds, TagsCache::instance()->colorLabelTags(), noColorLabelTagId);
             }
         }
@@ -448,13 +434,13 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
             rating = 0;
         }
 
-        if (m_isUnratedExcluded && rating == 0)
+        if (m_isUnratedExcluded && (rating == 0))
         {
             match = false;
         }
         else
         {
-            if (m_ratingCond == GreaterEqualCondition)
+            if      (m_ratingCond == GreaterEqualCondition)
             {
                 // If the rating is not >=, i.e it is <, then it does not match.
 
@@ -520,6 +506,26 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
             break;
         }
 
+        case MimeFilter::JPEGXLFiles:
+        {
+            if (info.format() != QLatin1String("JXL"))
+            {
+                match = false;
+            }
+
+            break;
+        }
+
+        case MimeFilter::WEBPFiles:
+        {
+            if (info.format() != QLatin1String("WEBP"))
+            {
+                match = false;
+            }
+
+            break;
+        }
+
         case MimeFilter::PNGFiles:
         {
             if (info.format() != QLatin1String("PNG"))
@@ -540,6 +546,16 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
             break;
         }
 
+        case MimeFilter::AVIFFiles:
+        {
+            if (info.format() != QLatin1String("AVIF"))
+            {
+                match = false;
+            }
+
+            break;
+        }
+
         case MimeFilter::PGFFiles:
         {
             if (info.format() != QLatin1String("PGF"))
@@ -637,7 +653,7 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
 
     if (m_geolocationCondition != GeolocationNoFilter)
     {
-        if (m_geolocationCondition == GeolocationNoCoordinates)
+        if      (m_geolocationCondition == GeolocationNoCoordinates)
         {
             if (info.hasCoordinates())
             {
@@ -659,14 +675,17 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
     {
         bool textMatch = false;
 
-        QRegExp textRegExp(m_textFilterSettings.text);
-        textRegExp.setPatternSyntax(QRegExp::WildcardUnix);
-        textRegExp.setCaseSensitivity(m_textFilterSettings.caseSensitive);
+        QRegularExpression textRegExp(m_textFilterSettings.text);
+
+        if (m_textFilterSettings.caseSensitive == Qt::CaseInsensitive)
+        {
+            textRegExp.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
+        }
 
         // Image name
 
         if ((m_textFilterSettings.textFields & SearchTextFilterSettings::ImageName) &&
-            (textRegExp.exactMatch(info.name())                                     ||
+            (textRegExp.match(info.name()).hasMatch()                               ||
             info.name().contains(m_textFilterSettings.text, m_textFilterSettings.caseSensitive)))
         {
             textMatch = true;
@@ -675,7 +694,7 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
         // Image title
 
         if ((m_textFilterSettings.textFields & SearchTextFilterSettings::ImageTitle) &&
-            (textRegExp.exactMatch(info.title())                                     ||
+            (textRegExp.match(info.title()).hasMatch()                               ||
             info.title().contains(m_textFilterSettings.text, m_textFilterSettings.caseSensitive)))
         {
             textMatch = true;
@@ -684,7 +703,7 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
         // Image comment
 
         if ((m_textFilterSettings.textFields & SearchTextFilterSettings::ImageComment) &&
-            (textRegExp.exactMatch(info.comment())                                     ||
+            (textRegExp.match(info.comment()).hasMatch()                               ||
             info.comment().contains(m_textFilterSettings.text, m_textFilterSettings.caseSensitive)))
         {
             textMatch = true;
@@ -692,10 +711,10 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
 
         // Tag names
 
-        foreach (int id, info.tagIds())
+        Q_FOREACH (int id, info.tagIds())
         {
             if ((m_textFilterSettings.textFields & SearchTextFilterSettings::TagName) &&
-                (textRegExp.exactMatch(m_tagNameHash.value(id))                       ||
+                (textRegExp.match(m_tagNameHash.value(id)).hasMatch()                 ||
                 m_tagNameHash.value(id).contains(m_textFilterSettings.text, m_textFilterSettings.caseSensitive)))
             {
                 textMatch = true;
@@ -705,7 +724,7 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
         // Album names
 
         if ((m_textFilterSettings.textFields & SearchTextFilterSettings::AlbumName) &&
-            (textRegExp.exactMatch(m_albumNameHash.value(info.albumId()))           ||
+            (textRegExp.match(m_albumNameHash.value(info.albumId())).hasMatch()     ||
             m_albumNameHash.value(info.albumId()).contains(m_textFilterSettings.text, m_textFilterSettings.caseSensitive)))
         {
             textMatch = true;
@@ -715,13 +734,13 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
 
         if (m_textFilterSettings.textFields & SearchTextFilterSettings::ImageAspectRatio)
         {
-            QRegExp expRatio (QLatin1String("^\\d+:\\d+$"));
-            QRegExp expFloat (QLatin1String("^\\d+(.\\d+)?$"));
+            QRegularExpression expRatio (QLatin1String("^\\d+:\\d+$"));
+            QRegularExpression expFloat (QLatin1String("^\\d+(.\\d+)?$"));
 
-            if ((expRatio.indexIn(m_textFilterSettings.text) > -1) && m_textFilterSettings.text.contains(QRegExp(QLatin1String(":\\d+"))))
+            if      (m_textFilterSettings.text.contains(expRatio) && m_textFilterSettings.text.contains(QRegularExpression(QLatin1String(":\\d+"))))
             {
                 QString trimmedTextFilterSettingsText = m_textFilterSettings.text;
-                QStringList numberStringList          = trimmedTextFilterSettingsText.split(QLatin1Char(':'), QString::SkipEmptyParts);
+                QStringList numberStringList          = trimmedTextFilterSettingsText.split(QLatin1Char(':'), QT_SKIP_EMPTY_PARTS);
 
                 if (numberStringList.length() == 2)
                 {
@@ -739,7 +758,7 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
                     }
                 }
             }
-            else if (expFloat.indexIn(m_textFilterSettings.text) > -1)
+            else if (m_textFilterSettings.text.contains(expFloat))
             {
                 QString trimmedTextFilterSettingsText = m_textFilterSettings.text;
                 bool    canConverse                   = false;
@@ -764,17 +783,17 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
             int pixelSize = size.height()*size.width();
             QString text  = m_textFilterSettings.text;
 
-            if      (text.contains(QRegExp(QLatin1String("^>\\d{1,15}$"))) &&
+            if      (text.contains(QRegularExpression(QLatin1String("^>\\d{1,15}$"))) &&
                 (pixelSize > (text.remove(0, 1)).toInt()))
             {
                 textMatch = true;
             }
-            else if (text.contains(QRegExp(QLatin1String("^<\\d{1,15}$"))) &&
+            else if (text.contains(QRegularExpression(QLatin1String("^<\\d{1,15}$"))) &&
                      (pixelSize < (text.remove(0, 1)).toInt()))
             {
                 textMatch = true;
             }
-            else if (text.contains(QRegExp(QLatin1String("^\\d+$"))) &&
+            else if (text.contains(QRegularExpression(QLatin1String("^\\d+$"))) &&
                      (pixelSize == text.toInt()))
             {
                 textMatch = true;
@@ -830,8 +849,6 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
 // -------------------------------------------------------------------------------------------------
 
 VersionItemFilterSettings::VersionItemFilterSettings()
-    : m_includeTagFilter  (0),
-      m_exceptionTagFilter(0)
 {
 }
 
@@ -895,7 +912,7 @@ bool VersionItemFilterSettings::isHiddenBySettings(const ItemInfo& info) const
 {
     QList<int> tagIds = info.tagIds();
 
-    foreach (int tagId, m_excludeTagFilter)
+    Q_FOREACH (int tagId, m_excludeTagFilter)
     {
         if (tagIds.contains(tagId))
         {
@@ -959,7 +976,6 @@ bool VersionItemFilterSettings::isFilteringByTags() const
 // -------------------------------------------------------------------------------------------------
 
 GroupItemFilterSettings::GroupItemFilterSettings()
-    : m_allOpen(false)
 {
 }
 
