@@ -32,7 +32,7 @@ class DIGIKAM_DATABASE_EXPORT ItemListModel : public ItemThumbnailModel
 
 public:
 
-    explicit ItemListModel(QObject* const parent = nullptr);
+    explicit ItemListModel(QWidget* const parent);
     ~ItemListModel() override;
 
     // NOTE: necessary methods to add and remove ItemInfos to the model are inherited from ItemModel
