@@ -7,7 +7,7 @@
  * Description : Mysql internal database server
  *
  * SPDX-FileCopyrightText: 2009-2011 by Holger Foerster <Hamsi2k at freenet dot de>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2016      by Swati Lodha <swatilodha27 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -40,8 +40,6 @@
 
 #include "digikam_debug.h"
 #include "digikam_globals.h"
-#include "dbengineparameters.h"
-#include "databaseserverstarter.h"
 
 namespace Digikam
 {
@@ -50,14 +48,10 @@ class Q_DECL_HIDDEN DatabaseServer::Private
 {
 public:
 
-    explicit Private()
-        : databaseProcess(nullptr),
-          serverPort(3307)
-    {
-    }
+    Private() = default;
 
     DbEngineParameters     params;
-    QProcess*              databaseProcess;
+    QProcess*              databaseProcess = nullptr;
 
     QString                internalDBName;
     QString                mysqlUpgradePath;
@@ -70,7 +64,7 @@ public:
     QString                actualConfig;
     QString                globalConfig;
 
-    int                    serverPort;
+    int                    serverPort      = 3307;
 };
 
 DatabaseServer::DatabaseServer(const DbEngineParameters& params, DatabaseServerStarter* const parent)
@@ -138,6 +132,7 @@ void DatabaseServer::run()
     while (databaseServerStateEnum != stopped);
 
     qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Shutting down database server";
+
     Q_EMIT done();
 }
 
@@ -838,3 +833,5 @@ QString DatabaseServer::processErrorLog(QProcess* const process, const QString&
 }
 
 } // namespace Digikam
+
+#include "moc_databaseserver.cpp"
