@@ -6,19 +6,10 @@
  * Date        : 2010-09-27
  * Description : Interface for info stored about a face tag in the database
  *
- * Copyright (C) 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
- * Copyright (C) 2010-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -39,24 +30,24 @@ namespace Digikam
 {
 
 FaceTagsIface::FaceTagsIface()
-    : m_type(InvalidFace),
+    : m_type   (InvalidFace),
       m_imageId(0),
-      m_tagId(0)
+      m_tagId  (0)
 {
 }
 
 FaceTagsIface::FaceTagsIface(Type type, qlonglong imageId, int tagId, const TagRegion& region)
-    : m_type(type),
+    : m_type   (type),
       m_imageId(imageId),
-      m_tagId(tagId),
-      m_region(region)
+      m_tagId  (tagId),
+      m_region (region)
 {
 }
 
 FaceTagsIface::FaceTagsIface(const QString& attribute, qlonglong imageId, int tagId, const TagRegion& region)
     : m_imageId(imageId),
-      m_tagId(tagId),
-      m_region(region)
+      m_tagId  (tagId),
+      m_region (region)
 {
     m_type = typeForAttribute(attribute, tagId);
 }
@@ -210,7 +201,17 @@ FaceTagsIface::Type FaceTagsIface::typeForAttribute(const QString& attribute, in
 
 FaceTagsIface FaceTagsIface::fromVariant(const QVariant& var)
 {
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+    if (var.typeId() == QVariant::List)
+
+#else
+
     if (var.type() == QVariant::List)
+
+#endif
+
     {
         QList<QVariant> list(var.toList());
 
