@@ -6,7 +6,7 @@
  * Date        : 2017-05-06
  * Description : interface to database information for shared tools.
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2019-2020 by Minh Nghia Duong <minhnghiaduong997 at gmail dot com>
  * SPDX-FileCopyrightText: 2017      by Mario Frank <mario dot frank at uni minus potsdam dot de>
  *
@@ -75,7 +75,7 @@ public:
 
     void        openSetupPage(SetupPage page)                                             override;
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     QList<GPSItemContainer*> currentGPSItems()                                      const override;
 
