@@ -6,20 +6,11 @@
  * Date        : 2005-05-17
  * Description : low level files management interface.
  *
- * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2012-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2018      by Maik Qualmann <metzpinguin at gmail dot com>
+ * SPDX-FileCopyrightText: 2005      by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2018      by Maik Qualmann <metzpinguin at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -29,6 +20,8 @@
 // Qt includes
 
 #include <QObject>
+#include <QMutex>
+#include <QMap>
 
 // Local includes
 
@@ -97,11 +90,14 @@ public:
     static void rename(const QUrl& src, const QString& newName, bool overwrite = false);
 
     /// Trash operations
+    static int  getTrashCounter(const QString& albumRootPath);
     static void restoreTrash(const DTrashItemInfoList& infos);
     static void emptyTrash(const DTrashItemInfoList& infos);
+    static void buildCollectionTrashCounters();
 
 Q_SIGNALS:
 
+    void signalTrashCounters();
     void signalTrashFinished();
     void signalRenameFinished();
     void signalRenameFailed(const QUrl& url);
@@ -111,6 +107,7 @@ private:
     void processJob(IOJobData* const data);
     void createJob(IOJobData* const data);
 
+    void updateAlbumDate(int albumID);
     QString getItemString(IOJobData* const data)         const;
     ProgressItem* getProgressItem(IOJobData* const data) const;
     void addAlbumChildrenToList(QList<int>& list, Album* const album);
@@ -118,8 +115,9 @@ private:
 private Q_SLOTS:
 
     void slotResult();
-    void slotOneProccessed(const QUrl& url);
     void slotCancel(ProgressItem* item);
+    void slotOneProccessed(const QUrl& url);
+    void slotTrashCounterMap(const QMap<QString, int>& counterMap);
 
 private:
 
@@ -130,7 +128,9 @@ private:
 
 private:
 
-    int          m_processingCount;
+    int                m_processingCount;
+    QMap<QString, int> m_trashCounterMap;
+    QMutex             m_trashCounterMutex;
 
     friend class DIOCreator;
 };
