@@ -6,7 +6,7 @@
  * Date        : 2009-11-03
  * Description : A dialog base class which can handle multiple pages.
  *
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 1999-2001 by Mirko Boehm <mirko at kde dot org>
  * SPDX-FileCopyrightText: 1999-2001 by Espen Sand <espen at kde dot org>
  * SPDX-FileCopyrightText: 1999-2001 by Holger Freyther <freyther at kde dot org>
@@ -22,7 +22,6 @@
 
 #include <QTimer>
 #include <QLayout>
-#include <QDialogButtonBox>
 
 namespace Digikam
 {
@@ -249,3 +248,5 @@ void DConfigDlg::setButtonBox(QDialogButtonBox* const box)
 }
 
 } // namespace Digikam
+
+#include "moc_dconfigdlg.cpp"
