@@ -6,7 +6,7 @@
  * Date        : 2006-30-08
  * Description : a progress dialog for digiKam
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -39,27 +39,18 @@ class Q_DECL_HIDDEN DProgressDlg::Private
 {
 public:
 
-    explicit Private()
-      : logo       (nullptr),
-        title      (nullptr),
-        label      (nullptr),
-        actionPix  (nullptr),
-        actionLabel(nullptr),
-        progress   (nullptr),
-        buttons    (nullptr)
-    {
-    }
+    Private() = default;
 
-    QLabel*           logo;
-    QLabel*           title;
-    QLabel*           label;
+    QLabel*           logo          = nullptr;
+    QLabel*           title         = nullptr;
+    QLabel*           label         = nullptr;
 
-    QLabel*           actionPix;
-    DAdjustableLabel* actionLabel;
+    QLabel*           actionPix     = nullptr;
+    DAdjustableLabel* actionLabel   = nullptr;
 
-    QProgressBar*     progress;
+    QProgressBar*     progress      = nullptr;
 
-    QDialogButtonBox* buttons;
+    QDialogButtonBox* buttons       = nullptr;
 };
 
 DProgressDlg::DProgressDlg(QWidget* const parent, const QString& caption)
@@ -183,3 +174,5 @@ void DProgressDlg::setTitle(const QString& text)
 }
 
 } // namespace Digikam
+
+#include "moc_dprogressdlg.cpp"
