@@ -6,7 +6,7 @@
  * Date        : 2008-03-13
  * Description : Image files selection dialog - Improved Qt based file dialog.
  *
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -17,34 +17,8 @@
 namespace Digikam
 {
 
-class Q_DECL_HIDDEN ImageDialog::Private
-{
-
-public:
-
-    explicit Private()
-        : dlg         (nullptr),
-          provider    (nullptr),
-          showToolTips(true),
-          toolTipTimer(nullptr),
-          toolTip     (nullptr),
-          toolTipView (nullptr)
-    {
-    }
-
-    QStringList               fileFormats;
-    QList<QUrl>               urls;
-    DFileDialog*              dlg;
-    ImageDialogIconProvider*  provider;
-    bool                      showToolTips;
-    QTimer*                   toolTipTimer;
-    ImageDialogToolTip*       toolTip;
-    QAbstractItemView*        toolTipView;
-    QModelIndex               toolTipIndex;
-    QUrl                      toolTipUrl;
-};
-
-ImageDialog::ImageDialog(QWidget* const parent, const QUrl& url, bool singleSelect, const QString& caption)
+ImageDialog::ImageDialog(QWidget* const parent, const QUrl& url,
+                         bool singleSelect, const QString& caption)
     : QObject(parent),
       d      (new Private)
 {
@@ -257,3 +231,5 @@ QList<QUrl> ImageDialog::getImageURLs(QWidget* const parent, const QUrl& url, co
 }
 
 } // namespace Digikam
+
+#include "moc_imagedialog.cpp"
