@@ -6,18 +6,9 @@
  * Date        : 2008-03-13
  * Description : Image files selection dialog - list view icon provider.
  *
- * Copyright (C) 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -70,15 +61,17 @@ QIcon ImageDialogIconProvider::icon(const QFileInfo& info) const
         QString path    = info.absoluteFilePath();
         qCDebug(DIGIKAM_GENERAL_LOG) << "request thumb icon for " << path;
 
-        QMimeType mtype = QMimeDatabase().mimeTypeForFile(path);
-        QString suffix  = info.suffix().toUpper();
+        QString mimeType = QMimeDatabase().mimeTypeForFile(path).name();
+        QString suffix   = info.suffix().toUpper();
 
-        if (mtype.name().startsWith(QLatin1String("image/")) ||
-            (suffix == QLatin1String("PGF"))                 ||
-            (suffix == QLatin1String("KRA"))                 ||
-            (suffix == QLatin1String("CR3"))                 ||
-            (suffix == QLatin1String("HIF"))                 ||
-            (suffix == QLatin1String("HEIC"))                ||
+        if (mimeType.startsWith(QLatin1String("image/")) ||
+            (suffix == QLatin1String("PGF"))             ||
+            (suffix == QLatin1String("JXL"))             ||
+            (suffix == QLatin1String("AVIF"))            ||
+            (suffix == QLatin1String("KRA"))             ||
+            (suffix == QLatin1String("CR3"))             ||
+            (suffix == QLatin1String("HIF"))             ||
+            (suffix == QLatin1String("HEIC"))            ||
             (suffix == QLatin1String("HEIF")))
         {
             // --- Critical section.
@@ -97,7 +90,9 @@ QIcon ImageDialogIconProvider::icon(const QFileInfo& info) const
                     // resize and center pixmap on target icon.
 
                     QPixmap pix = QPixmap::fromImage(images.first());
-                    pix         = pix.scaled(QSize(256, 256), Qt::KeepAspectRatio, Qt::FastTransformation);
+                    pix         = pix.scaled(QSize(256, 256),
+                                             Qt::KeepAspectRatio,
+                                             Qt::FastTransformation);
 
                     QPixmap icon(QSize(256, 256));
                     icon.fill(Qt::transparent);
@@ -120,4 +115,18 @@ QIcon ImageDialogIconProvider::icon(const QFileInfo& info) const
     return QFileIconProvider::icon(info);
 }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+QIcon ImageDialogIconProvider::icon(QAbstractFileIconProvider::IconType type) const
+
+#else
+
+QIcon ImageDialogIconProvider::icon(IconType type) const
+
+#endif
+
+{
+    return QFileIconProvider::icon(type);
+}
+
 } // namespace Digikam
