@@ -6,7 +6,7 @@
  * Date        : 2008-03-13
  * Description : Image files selection dialog - private declarations.
  *
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -51,4 +51,28 @@
 #include "thumbnailsize.h"
 #include "dfiledialog.h"
 
+namespace Digikam
+{
+
+class Q_DECL_HIDDEN ImageDialog::Private
+{
+
+public:
+
+    explicit Private() = default;
+
+    QStringList               fileFormats;
+    QList<QUrl>               urls;
+    DFileDialog*              dlg           = nullptr;
+    ImageDialogIconProvider*  provider      = nullptr;
+    bool                      showToolTips  = true;;
+    QTimer*                   toolTipTimer  = nullptr;
+    ImageDialogToolTip*       toolTip       = nullptr;
+    QAbstractItemView*        toolTipView   = nullptr;
+    QModelIndex               toolTipIndex;
+    QUrl                      toolTipUrl;
+};
+
+} // namespace Digikam
+
 #endif // DIGIKAM_IMAGE_DIALOG_P_H
