@@ -6,18 +6,9 @@
  * Date        : 2008-04-07
  * Description : Solid hardware list dialog
  *
- * Copyright (C) 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -73,23 +64,18 @@ class Q_DECL_HIDDEN SolidHardwareDlg::Private
 {
 public:
 
-    explicit Private()
-      : header    (nullptr),
-        searchBar (nullptr),
-        eventsList(nullptr)
-    {
-    }
+    Private() = default;
 
-    QLabel*        header;
-    SearchTextBar* searchBar;
-    QTreeWidget*   eventsList;
+    QLabel*        header       = nullptr;
+    SearchTextBar* searchBar    = nullptr;
+    QTreeWidget*   eventsList   = nullptr;
 };
 
 SolidHardwareDlg::SolidHardwareDlg(QWidget* const parent)
     : InfoDlg(parent),
       d      (new Private)
 {
-    setWindowTitle(i18nc("@title", "List of detected hardware"));
+    setWindowTitle(i18nc("@title:window", "List of Detected Hardware"));
 
     d->header     = new QLabel(this);
     d->header->setText(i18nc("@label", "%1 uses Solid framework version %2\n"
@@ -257,6 +243,7 @@ void SolidHardwareDlg::slotPopulateDevices()
 
 #endif
 
+            // cppcheck-suppress knownConditionTrueFalse
             if (title.isEmpty())
             {
                 if (!device.vendor().isEmpty())
@@ -434,3 +421,5 @@ void SolidHardwareDlg::slotDeviceRemoved(const QString& udi)
 }
 
 } // namespace Digikam
+
+#include "moc_solidhardwaredlg.cpp"
