@@ -7,19 +7,10 @@
  * Description : digiKam 8/16 bits image management API.
  *               Private data container.
  *
- * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005      by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -125,16 +116,7 @@ class DIGIKAM_EXPORT DImg::Private : public QSharedData
 {
 public:
 
-    explicit Private()
-      : null        (true),
-        alpha       (false),
-        sixteenBit  (false),
-        width       (0),
-        height      (0),
-        data        (nullptr),
-        lanczos_func(nullptr)
-    {
-    }
+    Private() = default;
 
     ~Private()
     {
@@ -144,15 +126,15 @@ public:
 
 public:
 
-    bool                    null;
-    bool                    alpha;
-    bool                    sixteenBit;
+    bool                    null            = true;
+    bool                    alpha           = false;
+    bool                    sixteenBit      = false;
 
-    unsigned int            width;
-    unsigned int            height;
+    unsigned int            width           = 0;
+    unsigned int            height          = 0;
 
-    unsigned char*          data;
-    LANCZOS_DATA_TYPE*      lanczos_func;
+    unsigned char*          data            = nullptr;
+    LANCZOS_DATA_TYPE*      lanczos_func    = nullptr;
 
     MetaEngineData          metaData;
     QMap<QString, QVariant> attributes;
@@ -171,7 +153,7 @@ public:
     {
         QMultiMap<int, DPluginDImg*> pluginMap;
 
-        foreach (DPlugin* const p, DPluginLoader::instance()->allPlugins())
+        Q_FOREACH (DPlugin* const p, DPluginLoader::instance()->allPlugins())
         {
             int prio;
             DPluginDImg* const plug = dynamic_cast<DPluginDImg*>(p);
@@ -201,7 +183,7 @@ public:
 
         if (!format.isNull())
         {
-            foreach (DPlugin* const p, DPluginLoader::instance()->allPlugins())
+            Q_FOREACH (DPlugin* const p, DPluginLoader::instance()->allPlugins())
             {
                 int prio;
                 DPluginDImg* const plug = dynamic_cast<DPluginDImg*>(p);
