@@ -6,7 +6,7 @@
  * Date        : 2004-12-01
  * Description : image curves manipulation methods.
  *
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2010-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -23,12 +23,14 @@ namespace Digikam
 {
 
 CurvesContainer::CurvesContainer()
-    : curvesType(ImageCurves::CURVE_SMOOTH), sixteenBit(false)
+    : curvesType(ImageCurves::CURVE_SMOOTH),
+      sixteenBit(false)
 {
 }
 
 CurvesContainer::CurvesContainer(int type, bool sixteenBit)
-    : curvesType((ImageCurves::CurveType)type), sixteenBit(sixteenBit)
+    : curvesType((ImageCurves::CurveType)type),
+      sixteenBit(sixteenBit)
 {
 }
 
