@@ -6,7 +6,7 @@
  * Date        : 2004-12-01
  * Description : image curves manipulation methods.
  *
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -75,7 +75,7 @@ public:
      *
      * @param otherCurves other curves object to adapt config from
      */
-    void fillFromOtherCurves(ImageCurves* const otherCurves);
+    void fillFromOtherCurves(const ImageCurves* const otherCurves);
 
 
     /// Methods to manipulate the curves data.
