@@ -6,18 +6,9 @@
  * Date        : 2007-01-08
  * Description : Hue/Saturation preview widget
  *
- * Copyright (C) 2007-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -29,8 +20,6 @@
 #include <QImage>
 #include <QPainter>
 #include <QPixmap>
-#include <QPaintEvent>
-#include <QResizeEvent>
 
 // Local includes
 
@@ -129,3 +118,5 @@ void HSPreviewWidget::updatePixmap()
 }
 
 } // namespace Digikam
+
+#include "moc_hspreviewwidget.cpp"
