@@ -4,7 +4,7 @@
  * Description : a tool to fix automatically camera lens aberrations
  *
  * SPDX-FileCopyrightText: 2008      by Adrian Schroeter <adrian at suse dot de>
- * SPDX-FileCopyrightText: 2008-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -18,7 +18,6 @@
 #include <QGridLayout>
 #include <QLabel>
 #include <QString>
-#include <QWidget>
 #include <QApplication>
 #include <QStyle>
 #include <QVariant>
@@ -837,3 +836,5 @@ void LensFunCameraSelector::slotDistanceChanged()
 #if defined(Q_CC_CLANG)
 #   pragma clang diagnostic pop
 #endif
+
+#include "moc_lensfuncameraselector.cpp"
