@@ -4,7 +4,7 @@
  * Description : a tool to fix automatically camera lens aberrations
  *
  * SPDX-FileCopyrightText: 2008      by Adrian Schroeter <adrian at suse dot de>
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -27,36 +27,20 @@ class DIGIKAM_EXPORT LensFunContainer
 
 public:
 
-    explicit LensFunContainer()
-      : filterCCA       (true),
-        filterVIG       (true),
-        filterDST       (true),
-        filterGEO       (true),
-        cropFactor      (-1.0),
-        focalLength     (-1.0),
-        aperture        (-1.0),
-        subjectDistance (-1.0),
-        cameraMake      (QString()),
-        cameraModel     (QString()),
-        lensModel       (QString())
-    {
-    };
-
-    ~LensFunContainer()
-    {
-    };
+    LensFunContainer()  = default;
+    ~LensFunContainer() = default;
 
 public:
 
-    bool      filterCCA;       ///< Chromatic Aberration Corrections
-    bool      filterVIG;       ///< Vignetting Corrections
-    bool      filterDST;       ///< Distortion Corrections
-    bool      filterGEO;       ///< Geometry Corrections
+    bool      filterCCA         = true;       ///< Chromatic Aberration Corrections
+    bool      filterVIG         = true;       ///< Vignetting Corrections
+    bool      filterDST         = true;       ///< Distortion Corrections
+    bool      filterGEO         = true;       ///< Geometry Corrections
 
-    double    cropFactor;
-    double    focalLength;
-    double    aperture;
-    double    subjectDistance;
+    double    cropFactor        = -1.0;
+    double    focalLength       = -1.0;
+    double    aperture          = -1.0;
+    double    subjectDistance   = -1.0;
 
     QString   cameraMake;
     QString   cameraModel;
