@@ -6,7 +6,7 @@
  * Date        : 2010-25-02
  * Description : Levels image filter
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -44,9 +44,7 @@ public:
         }
     };
 
-    ~LevelsContainer()
-    {
-    };
+    ~LevelsContainer() = default;
 
 public:
 
