@@ -6,7 +6,7 @@
  * Date        : 2010-12-14
  * Description : Filter to manage and help with raw loading
  *
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2005-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,7 +20,6 @@
 #include "drawdecoder.h"
 #include "bcgfilter.h"
 #include "curvesfilter.h"
-#include "digikam_export.h"
 #include "dimgloaderobserver.h"
 #include "filteraction.h"
 #include "icctransform.h"
@@ -164,3 +163,5 @@ void RawProcessingFilter::filterImage()
 }
 
 } // namespace Digikam
+
+#include "moc_rawprocessingfilter.cpp"
