@@ -7,7 +7,7 @@
  * Description : DImg image loader interface
  *
  * SPDX-FileCopyrightText: 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -17,7 +17,6 @@
 
 // C++ includes
 
-#include <limits>
 #include <new>
 #include <cstddef>
 
@@ -25,13 +24,15 @@
 
 #include <QScopedPointer>
 
+// KDE includes
+
+#include <kmemoryinfo.h>
+
 // Local includes
 
-#include "digikam_debug.h"
 #include "dimg_p.h"
 #include "dmetadata.h"
 #include "dimgloaderobserver.h"
-#include "dmemoryinfo.h"
 
 namespace Digikam
 {
@@ -169,16 +170,16 @@ qint64 DImgLoader::checkAllocation(qint64 fullSize)
 
     if (fullSize > (qint64)(100 * 1024 * 1024))
     {
-        DMemoryInfo memory;
+        KMemoryInfo memInfo;
 
-        if (memory.isNull())
+        if (memInfo.isNull())
         {
             qCWarning(DIGIKAM_DIMG_LOG) << "Not a recognized platform to get memory information";
 
             return -1;
         }
 
-        qint64 available = memory.availablePhysical();
+        qint64 available = memInfo.availablePhysical();
 
         if (available == 0)
         {
