@@ -6,18 +6,9 @@
  * Date        : 2018-12-31
  * Description : configuration view for external generic plugin
  *
- * Copyright (C) 2018-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -34,7 +25,7 @@ namespace Digikam
 DPluginConfViewGeneric::DPluginConfViewGeneric(QWidget* const parent)
     : DPluginConfView(parent)
 {
-    loadPlugins();
+    this->loadPlugins();
 }
 
 DPluginConfViewGeneric::~DPluginConfViewGeneric()
@@ -47,7 +38,7 @@ void DPluginConfViewGeneric::loadPlugins()
 
     if (loader)
     {
-        foreach (DPlugin* const tool, loader->allPlugins())
+        Q_FOREACH (DPlugin* const tool, loader->allPlugins())
         {
             DPluginGeneric* const gene = dynamic_cast<DPluginGeneric*>(tool);
 
@@ -64,3 +55,5 @@ void DPluginConfViewGeneric::loadPlugins()
 }
 
 } // namespace Digikam
+
+#include "moc_dpluginconfviewgeneric.cpp"
