@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : manager to load external plugins at run-time: private container
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -62,7 +62,7 @@ QFileInfoList DPluginLoader::Private::pluginEntriesList() const
     QStringList pathList;
 
     // First we try to load in first the local plugin if DK_PLUG_PATH variable is declared.
-    // Else, we will load plusing from the system using the standard Qt plugin path.
+    // Else, we will load plugins from the system using the standard Qt plugin path.
 
     QByteArray  dkenv = qgetenv("DK_PLUGIN_PATH");
 
@@ -119,7 +119,8 @@ QFileInfoList DPluginLoader::Private::pluginEntriesList() const
         {
             it.next();
 
-            if (!it.filePath().contains(QLatin1String("dSYM")) &&  // Ignore debug binary extensions under MacOS
+            if (!it.filePath().contains(QLatin1String("dSYM"))   &&  // Ignore debug binary extensions under MacOS
+                !it.filePath().contains(QLatin1String("marble")) &&  // Ignore Marble plugins.
                 !dupFiles.contains(it.fileInfo().baseName()))
             {
                 dupFiles << it.fileInfo().baseName();
