@@ -6,17 +6,9 @@
  * Date        : 2014-09-12
  * Description : Web Service tool utils methods
  *
- * Copyright (C) 2014-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -24,19 +16,47 @@
 
 // Qt includes
 
+#include <QRandomGenerator>
 #include <QStandardPaths>
 #include <QApplication>
 #include <QByteArray>
 #include <QBuffer>
 #include <QTime>
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
-#   include <QRandomGenerator>
-#endif
-
 namespace Digikam
 {
 
+QString WSToolUtils::decodeKey(const QString& key)
+{
+    QByteArray keyArray = QByteArray::fromBase64(key.toLatin1());
+    int pos             = 0;
+
+    for (int i = 0 ; i < keyArray.size() ; ++i)
+    {
+        keyArray[i] = (keyArray[i] ^ possibleCharacters()[pos].toLatin1());
+        pos         = (++pos == possibleCharacters().length()) ? 0 : pos;
+    }
+
+    return QString::fromLatin1(keyArray);
+}
+
+QString WSToolUtils::randomString(const int& length)
+{
+    QString randomString;
+    QRandomGenerator* const generator = QRandomGenerator::global();
+
+    for (int i = 0 ; i < length ; ++i)
+    {
+        const int index = generator->bounded(possibleCharacters().length());
+        QChar nextChar  = possibleCharacters().at(index);
+        randomString.append(nextChar);
+    }
+
+    return randomString;
+}
+
+// ------------------------------------------------------------------------------------
+
 QDir WSToolUtils::makeTemporaryDir(const char* prefix)
 {
     QString subDir = QString::fromLatin1("digikam-%1-%2").arg(QString::fromUtf8(prefix)).arg(qApp->applicationPid());
@@ -65,49 +85,66 @@ void WSToolUtils::removeTemporaryDir(const char* prefix)
 
 // ------------------------------------------------------------------------------------
 
-QString WSToolUtils::randomString(const int& length)
-{
-    const QString possibleCharacters(QLatin1String("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789"));
-
-    QString randomString;
-
-#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
-
-    qsrand((uint)QTime::currentTime().msec());
-
-#else
-
-    QRandomGenerator* const generator = QRandomGenerator::global();
-
-#endif
-
-    for (int i = 0 ; i < length ; ++i)
-    {
-#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
-
-        const int index = qrand() % possibleCharacters.length();
-
-#else
-
-        const int index = generator->bounded(possibleCharacters.length());
-
-#endif
-
-        QChar nextChar  = possibleCharacters.at(index);
-        randomString.append(nextChar);
-    }
-
-    return randomString;
-}
-
-// ------------------------------------------------------------------------------------
-
 QSettings* WSToolUtils::getOauthSettings(QObject* const parent)
 {
-    QString dkoauth = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) +
-                      QLatin1String("/digikam_oauthrc");
+    QString dkoauth = oauthConfigFile();
 
     return (new QSettings(dkoauth, QSettings::IniFormat, parent));
 }
 
+// ------------------------------------------------------------------------------------
+
+void WSToolUtils::saveToken(const QString& name, const QString& token)
+{
+    QString dkoauth = oauthConfigFile();
+
+    QSettings settings(dkoauth, QSettings::IniFormat);
+    QByteArray code = token.toLatin1().toBase64();
+
+    settings.beginGroup(name);
+    settings.setValue(QLatin1String("refreshToken"), code);
+    settings.endGroup();
+}
+
+QString WSToolUtils::readToken(const QString& name)
+{
+    QString dkoauth = oauthConfigFile();
+
+    QSettings settings(dkoauth, QSettings::IniFormat);
+
+    settings.beginGroup(name);
+    QByteArray code = settings.value(QLatin1String("refreshToken")).toByteArray();
+    settings.endGroup();
+
+    return QString::fromLatin1(QByteArray::fromBase64(code));
+}
+
+void WSToolUtils::clearToken(const QString& name)
+{
+    QString dkoauth = oauthConfigFile();
+
+    QSettings settings(dkoauth, QSettings::IniFormat);
+
+    settings.beginGroup(name);
+    settings.remove(QString());
+    settings.endGroup();
+}
+
+// ------------------------------------------------------------------------------------
+
+QString WSToolUtils::oauthConfigFile()
+{
+    QString dkoauth = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) +
+                      QLatin1String("/digikam_oauthrc");
+
+    return dkoauth;
+}
+
+// ------------------------------------------------------------------------------------
+
+QString WSToolUtils::possibleCharacters()
+{
+    return QLatin1String("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789");
+}
+
 } // namespace Digikam
