@@ -5,19 +5,10 @@
  * Date        : 2019-07-22
  * Description : Class to perform faces detection using OpenCV DNN module
  *
- * Copyright (C) 2019 by Thanh Trung Dinh <dinhthanhtrung1996 at gmail dot com>
- * Copyright (C) 2020 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2019 by Thanh Trung Dinh <dinhthanhtrung1996 at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -41,11 +32,11 @@ namespace Digikam
 
 enum DetectorNNModel
 {
-    SSDMOBILENET = 0,   /// SSD MobileNet neural network inference.
-    YOLO                /// YOLO neural network inference.
+    SSDMOBILENET = 0,   ///< SSD MobileNet neural network inference.
+    YOLO                ///< YOLO neural network inference.
 };
 
-class OpenCVDNNFaceDetector
+class DIGIKAM_EXPORT OpenCVDNNFaceDetector
 {
 
 public:
@@ -68,7 +59,7 @@ public:
 
 private:
 
-    cv::Mat prepareForDetection(cv::Mat& cvImage, cv::Size& paddedSize) const;
+    cv::Mat prepareForDetection(cv::Mat& cvImage, cv::Size& paddedSize)              const;
 
 private:
 
