@@ -7,7 +7,7 @@
  *               The internal DNN library interface
  *
  * SPDX-FileCopyrightText: 2019      by Thanh Trung Dinh <dinhthanhtrung1996 at gmail dot com>
- * SPDX-FileCopyrightText: 2020-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2020      by Nghia Duong <minhnghiaduong997 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -58,9 +58,9 @@ public:
     /**
      * Calculate different between 2 vectors
      */
-    static double cosineDistance(std::vector<float> v1, std::vector<float> v2);
-    static double L2squareDistance(std::vector<float> v1, std::vector<float> v2);
-    static double L2squareNormDistance(std::vector<float> v1, std::vector<float> v2);
+    static double cosineDistance(const std::vector<float>& v1, const std::vector<float>& v2);
+    static double L2squareDistance(const std::vector<float>& v1, const std::vector<float>& v2);
+    static double L2squareNormDistance(const std::vector<float>& v1, const std::vector<float>& v2);
 
     /**
      * Convert face embedding between different formats
