@@ -6,18 +6,9 @@
  * Date        : 2011-02-23
  * Description : a widget to filter album contents by text query
  *
- * Copyright (C) 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -41,19 +32,19 @@ class Q_DECL_HIDDEN TextFilter::Private
 public:
 
     explicit Private()
+      : itemNameAction       (nullptr),
+        itemTitleAction      (nullptr),
+        itemCommentAction    (nullptr),
+        tagNameAction        (nullptr),
+        albumNameAction      (nullptr),
+        itemAspectRatioAction(nullptr),
+        itemPixelSizeAction  (nullptr),
+        clearAllAction       (nullptr),
+        selAllAction         (nullptr),
+        optionsBtn           (nullptr),
+        optionsMenu          (nullptr),
+        searchTextBar        (nullptr)
     {
-        itemNameAction        = nullptr;
-        itemTitleAction       = nullptr;
-        itemCommentAction     = nullptr;
-        tagNameAction         = nullptr;
-        albumNameAction       = nullptr;
-        optionsBtn            = nullptr;
-        optionsMenu           = nullptr;
-        searchTextBar         = nullptr;
-        itemAspectRatioAction = nullptr;
-        itemPixelSizeAction   = nullptr;
-        clearAllAction        = nullptr;
-        selAllAction          = nullptr;
     }
 
     QAction*       itemNameAction;
@@ -207,7 +198,7 @@ void TextFilter::slotSearchTextFieldsChanged()
     SearchTextFilterSettings settings(d->searchTextBar->searchTextSettings());
     settings.textFields = searchTextFields();
 
-    emit signalSearchTextFilterSettings(settings);
+    Q_EMIT signalSearchTextFilterSettings(settings);
 }
 
 void TextFilter::reset()
@@ -217,3 +208,5 @@ void TextFilter::reset()
 }
 
 } // namespace Digikam
+
+#include "moc_textfilter.cpp"
