@@ -6,19 +6,10 @@
  * Date        : 2015-06-15
  * Description : IO Jobs thread for file system jobs
  *
- * Copyright (C) 2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * Copyright (C) 2018 by Maik Qualmann <metzpinguin at gmail dot com>
+ * SPDX-FileCopyrightText: 2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * SPDX-FileCopyrightText: 2018 by Maik Qualmann <metzpinguin at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -148,7 +139,6 @@ void IOJobsThread::listDTrashItems(const QString& collectionPath)
             this, SIGNAL(signalFinished()));
 
     collection.insert(j, 0);
-    d->jobsCount++;
 
     appendJobs(collection);
 }
@@ -183,6 +173,23 @@ void IOJobsThread::emptyDTrashItems(IOJobData* const data)
     appendJobs(collection);
 }
 
+void IOJobsThread::buildTrashCounters()
+{
+    ActionJobCollection collection;
+
+    BuildTrashCountersJob* const j = new BuildTrashCountersJob();
+
+    connect(j, SIGNAL(signalTrashCountersMap(QMap<QString,int>)),
+            this, SIGNAL(signalTrashCountersMap(QMap<QString,int>)));
+
+    connect(j, SIGNAL(signalDone()),
+            this, SIGNAL(signalFinished()));
+
+    collection.insert(j, 0);
+
+    appendJobs(collection);
+}
+
 bool IOJobsThread::isCanceled() const
 {
     return d->isCanceled;
@@ -222,7 +229,7 @@ void IOJobsThread::slotOneJobFinished()
 
     if (d->jobsCount == 0)
     {
-        emit signalFinished();
+        Q_EMIT signalFinished();
         qCDebug(DIGIKAM_IOJOB_LOG) << "Thread Finished";
     }
 }
@@ -239,3 +246,5 @@ void IOJobsThread::slotCancel()
 }
 
 } // namespace Digikam
+
+#include "moc_iojobsthread.cpp"
