@@ -7,7 +7,7 @@
  * Description : Exiv2 library interface.
  *               Internal private container.
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -22,7 +22,6 @@
 #   include <QTextCodec>
 #endif
 
-#include <QFile>
 #include <qplatformdefs.h>
 
 // Local includes
@@ -67,15 +66,7 @@ bool s_metaEngineSupportBmff = false;
 bool s_metaEngineWarnOrError = false;
 
 MetaEngine::Private::Private(MetaEngine* const q)
-    : writeWithExifTool     (false),
-      writeRawFiles         (false),
-      writeDngFiles         (false),
-      updateFileTimeStamp   (false),
-      useXMPSidecar4Reading (false),
-      useCompatibleFileName (false),
-      metadataWritingMode   (WRITE_TO_FILE_ONLY),
-      loadedFromSidecar     (false),
-      parent                (q),
+    : parent                (q),
       data                  (new MetaEngineData::Private)
 {
     QMutexLocker lock(&s_metaEngineMutex);
@@ -101,6 +92,11 @@ const std::string& MetaEngine::Private::itemComments() const
     return data.constData()->imageComments;
 }
 
+const Exiv2::ByteOrder& MetaEngine::Private::exifByteOrder() const
+{
+    return data.constData()->exifByteOrder;
+}
+
 Exiv2::ExifData& MetaEngine::Private::exifMetadata()
 {
     return data.data()->exifMetadata;
@@ -116,6 +112,11 @@ std::string& MetaEngine::Private::itemComments()
     return data.data()->imageComments;
 }
 
+Exiv2::ByteOrder& MetaEngine::Private::exifByteOrder()
+{
+    return data.data()->exifByteOrder;
+}
+
 #ifdef _XMP_SUPPORT_
 
 const Exiv2::XmpData& MetaEngine::Private::xmpMetadata() const
@@ -136,12 +137,16 @@ void MetaEngine::Private::copyPrivateData(const Private* const other)
 
     data                  = other->data;
     filePath              = other->filePath;
+    mimeType              = other->mimeType;
+    pixelSize             = other->pixelSize;
     writeRawFiles         = other->writeRawFiles;
     writeDngFiles         = other->writeDngFiles;
+    writeWithExifTool     = other->writeWithExifTool;
+    loadedFromSidecar     = other->loadedFromSidecar;
     updateFileTimeStamp   = other->updateFileTimeStamp;
+    metadataWritingMode   = other->metadataWritingMode;
     useXMPSidecar4Reading = other->useXMPSidecar4Reading;
     useCompatibleFileName = other->useCompatibleFileName;
-    metadataWritingMode   = other->metadataWritingMode;
 }
 
 bool MetaEngine::Private::saveToXMPSidecar(const QFileInfo& finfo) const
@@ -153,6 +158,10 @@ bool MetaEngine::Private::saveToXMPSidecar(const QFileInfo& finfo) const
         return false;
     }
 
+    QFileInfo xmpInfo(xmpFile);
+    QDateTime modTime = xmpInfo.exists() ? xmpInfo.fileTime(QFileDevice::FileModificationTime)
+                                         : finfo.fileTime(QFileDevice::FileModificationTime);
+
     QMutexLocker lock(&s_metaEngineMutex);
 
     try
@@ -178,11 +187,11 @@ bool MetaEngine::Private::saveToXMPSidecar(const QFileInfo& finfo) const
 
 #if EXIV2_TEST_VERSION(0,27,99)
 
-        return saveUsingExiv2(finfo, std::move(image));
+        return saveUsingExiv2(xmpInfo, modTime, std::move(image));
 
 #else
 
-        return saveUsingExiv2(finfo, image);
+        return saveUsingExiv2(xmpInfo, modTime, image);
 
 #endif
 
@@ -210,11 +219,13 @@ bool MetaEngine::Private::saveToFile(const QFileInfo& finfo) const
         return false;
     }
 
+    QDateTime modTime = finfo.fileTime(QFileDevice::FileModificationTime);
+
     QMutexLocker lock(&s_metaEngineMutex);
 
     if (writeWithExifTool)
     {
-        return saveUsingExifTool(finfo);
+        return saveUsingExifTool(finfo, modTime);
     }
     else
     {
@@ -238,11 +249,11 @@ bool MetaEngine::Private::saveToFile(const QFileInfo& finfo) const
 
 #if EXIV2_TEST_VERSION(0,27,99)
 
-            return saveUsingExiv2(finfo, std::move(image));
+            return saveUsingExiv2(finfo, modTime, std::move(image));
 
 #else
 
-            return saveUsingExiv2(finfo, image);
+            return saveUsingExiv2(finfo, modTime, image);
 
 #endif
 
@@ -262,7 +273,9 @@ bool MetaEngine::Private::saveToFile(const QFileInfo& finfo) const
     }
 }
 
-bool MetaEngine::Private::saveUsingExiv2(const QFileInfo& finfo, Exiv2::Image::AutoPtr image) const
+bool MetaEngine::Private::saveUsingExiv2(const QFileInfo& finfo,
+                                         const QDateTime& modTime,
+                                         Exiv2::Image::AutoPtr image) const
 {
     QMutexLocker lock(&s_metaEngineMutex);
 
@@ -270,17 +283,7 @@ bool MetaEngine::Private::saveUsingExiv2(const QFileInfo& finfo, Exiv2::Image::A
 
     if (!ext.isEmpty())
     {
-
-#ifdef _XMP_SUPPORT_
-
-        if (s_rawFileExtensions().contains(ext) && (image->imageType() != Exiv2::ImageType::xmp))
-
-#else
-
         if (s_rawFileExtensions().contains(ext))
-
-#endif // _XMP_SUPPORT_
-
         {
             // NOTE: never touch RAW files with Exiv2 as it's not safe. Use ExifTool backend instead.
 
@@ -455,40 +458,22 @@ bool MetaEngine::Private::saveUsingExiv2(const QFileInfo& finfo, Exiv2::Image::A
             qCDebug(DIGIKAM_METAENGINE_LOG) << "Support for writing metadata is limited for file" << finfo.fileName();
         }
 
-#ifdef _XMP_SUPPORT_
-
-        if (!updateFileTimeStamp && (image->imageType() != Exiv2::ImageType::xmp))
-
-#else
-
-        if (!updateFileTimeStamp)
-
-#endif // _XMP_SUPPORT_
+        image->writeMetadata();
 
+        if (!updateFileTimeStamp && modTime.isValid())
         {
             // Don't touch modification timestamp of file.
 
-            QDateTime modDateTime = finfo.fileTime(QFileDevice::FileModificationTime);
+            QFile modFile(finfo.filePath());
 
-            image->writeMetadata();
-
-            if (modDateTime.isValid())
+            if (modFile.open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::ExistingOnly))
             {
-                QFile modFile(finfo.filePath());
+                modFile.setFileTime(modTime, QFileDevice::FileModificationTime);
 
-                if (modFile.open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::ExistingOnly))
-                {
-                    modFile.setFileTime(modDateTime, QFileDevice::FileModificationTime);
+                qCDebug(DIGIKAM_METAENGINE_LOG) << "File time stamp restored";
 
-                    qCDebug(DIGIKAM_METAENGINE_LOG) << "File time stamp restored";
-
-                    modFile.close();
-                }
+                modFile.close();
             }
-         }
-        else
-        {
-            image->writeMetadata();
         }
 
         return true;
@@ -505,7 +490,8 @@ bool MetaEngine::Private::saveUsingExiv2(const QFileInfo& finfo, Exiv2::Image::A
     return false;
 }
 
-bool MetaEngine::Private::saveUsingExifTool(const QFileInfo& finfo) const
+bool MetaEngine::Private::saveUsingExifTool(const QFileInfo& finfo,
+                                            const QDateTime& modTime) const
 {
     QString ext = finfo.suffix().toLower();
 
@@ -546,49 +532,39 @@ bool MetaEngine::Private::saveUsingExifTool(const QFileInfo& finfo) const
 
     // ---
 
-    parent->exportChanges(exvPath);
+    if (!parent->exportChanges(exvPath))
+    {
+        qCWarning(DIGIKAM_METAENGINE_LOG) << "Exiv2 error exception for" << finfo.fileName()
+                                          << "Writing of metadata aborted!";
+        QFile::remove(exvPath);
 
-    if (!updateFileTimeStamp)
+        return false;
+    }
+
+    bool hasCSet = (parent->getIptcTagData("Iptc.Envelope.CharacterSet") == "\33%G");
+
+    if (!parser->applyChanges(finfo.filePath(), exvPath,
+                              parent->hasExif(), parent->hasXmp(), hasCSet))
+    {
+        qCWarning(DIGIKAM_METAENGINE_LOG) << "Cannot apply changes with ExifTool on" << finfo.filePath();
+        QFile::remove(exvPath);
+
+        return false;
+    }
+
+    if (!updateFileTimeStamp && modTime.isValid())
     {
         // Don't touch modification timestamp of file.
 
-        QDateTime modDateTime = finfo.fileTime(QFileDevice::FileModificationTime);
-        bool hasCSet          = (parent->getIptcTagData("Iptc.Envelope.CharacterSet") == "\33%G");
+        QFile modFile(finfo.filePath());
 
-        if (!parser->applyChanges(finfo.filePath(), exvPath,
-                                  parent->hasExif(), parent->hasXmp(), hasCSet))
+        if (modFile.open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::ExistingOnly))
         {
-            qCWarning(DIGIKAM_METAENGINE_LOG) << "Cannot apply changes with ExifTool on" << finfo.filePath();
-            QFile::remove(exvPath);
+            modFile.setFileTime(modTime, QFileDevice::FileModificationTime);
 
-            return false;
-        }
+            qCDebug(DIGIKAM_METAENGINE_LOG) << "File time stamp restored";
 
-        if (modDateTime.isValid())
-        {
-            QFile modFile(finfo.filePath());
-
-            if (modFile.open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::ExistingOnly))
-            {
-                modFile.setFileTime(modDateTime, QFileDevice::FileModificationTime);
-
-                qCDebug(DIGIKAM_METAENGINE_LOG) << "File time stamp restored";
-
-                modFile.close();
-            }
-        }
-    }
-    else
-    {
-        bool hasCSet = (parent->getIptcTagData("Iptc.Envelope.CharacterSet") == "\33%G");
-
-        if (!parser->applyChanges(finfo.filePath(), exvPath,
-                                  parent->hasExif(), parent->hasXmp(), hasCSet))
-        {
-            qCWarning(DIGIKAM_METAENGINE_LOG) << "Cannot apply changes with ExifTool on" << finfo.filePath();
-            QFile::remove(exvPath);
-
-            return false;
+            modFile.close();
         }
     }
 
@@ -616,6 +592,37 @@ QString MetaEngine::Private::convertCommentValue(const Exiv2::Exifdatum& exifDat
 
     try
     {
+        QByteArray rawComment(exifDatum.size(), '\0');
+        exifDatum.copy((Exiv2::byte*)rawComment.data(), Exiv2::littleEndian);
+
+        if ((rawComment.size() > 8) && rawComment.startsWith("UNICODE\0"))
+        {
+            rawComment = rawComment.mid(8);
+
+            if ((rawComment.size() % 2) != 0)
+            {
+                qCDebug(DIGIKAM_METAENGINE_LOG) << "Comment not properly 16 bit encoded";
+
+                return QString();
+            }
+
+            // change the byte order if we have a big-endian
+            // image or encounter a possible incorrect byte order
+
+            if ((exifByteOrder() == Exiv2::bigEndian) || (rawComment.at(0) == '\0'))
+            {
+                const QByteArray tmpComment(rawComment);
+
+                for (int i = 0 ; i < rawComment.size() ; i += 2)
+                {
+                    rawComment[i]     = tmpComment.at(i + 1);
+                    rawComment[i + 1] = tmpComment.at(i);
+                }
+            }
+
+            return QString::fromUtf16((char16_t*)rawComment.data(), rawComment.size() / 2);
+        }
+
         std::string comment;
         std::string charset;
 
@@ -642,29 +649,7 @@ QString MetaEngine::Private::convertCommentValue(const Exiv2::Exifdatum& exifDat
             }
         }
 
-        if      (charset == "Unicode")
-        {
-
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
-
-            QByteArray rawComment(exifDatum.size(), '\0');
-            exifDatum.copy((Exiv2::byte*)rawComment.data(), Exiv2::bigEndian);
-
-            // remove "UNICODE\0"
-
-            rawComment          = rawComment.mid(8, rawComment.size() - 8);
-            QString utf16String = QString::fromUtf16((ushort*)rawComment.data());
-
-            if (utf16String.isValidUtf16())
-            {
-                return QString::fromUtf8(utf16String.toUtf8());
-            }
-
-#endif
-
-            return QString::fromUtf8(comment.data());
-        }
-        else if (charset == "Jis")
+        if      (charset == "Jis")
         {
 
 #if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
@@ -686,6 +671,7 @@ QString MetaEngine::Private::convertCommentValue(const Exiv2::Exifdatum& exifDat
             {
                 const char* tmp = comment.c_str();
 
+                // cppcheck-suppress knownConditionTrueFalse
                 if (tmp)
                 {
                     return codec->toUnicode(tmp);
