@@ -7,7 +7,7 @@
  * Description : Exiv2 library interface.
  *               Embedded preview loading.
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -33,10 +33,7 @@ class Q_DECL_HIDDEN MetaEnginePreviews::Private
 {
 public:
 
-    explicit Private()
-        : manager(nullptr)
-    {
-    }
+    Private() = default;
 
     ~Private()
     {
@@ -86,7 +83,7 @@ public:
 public:
 
     Exiv2::Image::AutoPtr           image;
-    Exiv2::PreviewManager*          manager;
+    Exiv2::PreviewManager*          manager = nullptr;
     QList<Exiv2::PreviewProperties> properties;
 };
 
