@@ -99,7 +99,7 @@ public:
     {
     }
 
-    void enumerate(QWidget* const w)
+    void enumerate(const QWidget* const w)
     {
         // recurse
 
@@ -324,3 +324,5 @@ void ActionItemModel::slotActionChanged()
 }
 
 } // namespace Digikam
+
+#include "moc_categorizeditemmodel.cpp"
