@@ -45,7 +45,6 @@ public:
 
     explicit Private()
       : jobThread               (nullptr),
-        refreshTimer            (nullptr),
         incrementalTimer        (nullptr),
         recurseAlbums           (false),
         recurseTags             (false),
@@ -56,7 +55,6 @@ public:
 
     QList<Album*>     currentAlbums;
     DBJobsThread*     jobThread;
-    QTimer*           refreshTimer;
     QTimer*           incrementalTimer;
 
     bool              recurseAlbums;
@@ -67,21 +65,15 @@ public:
     bool              extraValueJob;
 };
 
-ItemAlbumModel::ItemAlbumModel(QObject* const parent)
+ItemAlbumModel::ItemAlbumModel(QWidget* const parent)
     : ItemThumbnailModel(parent),
       d(new Private)
 {
     qRegisterMetaType<QList<ItemListerRecord>>("QList<ItemListerRecord>");
 
-    d->refreshTimer     = new QTimer(this);
-    d->refreshTimer->setSingleShot(true);
-
     d->incrementalTimer = new QTimer(this);
     d->incrementalTimer->setSingleShot(true);
 
-    connect(d->refreshTimer, SIGNAL(timeout()),
-            this, SLOT(slotNextRefresh()));
-
     connect(d->incrementalTimer, SIGNAL(timeout()),
             this, SLOT(slotNextIncrementalRefresh()));
 
@@ -256,38 +248,14 @@ void ItemAlbumModel::incrementalRefresh()
 
 bool ItemAlbumModel::hasScheduledRefresh() const
 {
-    return (d->refreshTimer->isActive() || d->incrementalTimer->isActive() || hasIncrementalRefreshPending());
-}
-
-void ItemAlbumModel::scheduleRefresh()
-{
-    if (!d->refreshTimer->isActive())
-    {
-        d->incrementalTimer->stop();
-        d->refreshTimer->start(100);
-    }
+    return (d->incrementalTimer->isActive() || hasIncrementalRefreshPending());
 }
 
 void ItemAlbumModel::scheduleIncrementalRefresh()
 {
     if (!hasScheduledRefresh())
     {
-        d->incrementalTimer->start(100);
-    }
-}
-
-void ItemAlbumModel::slotNextRefresh()
-{
-    // Refresh, unless job is running, then postpone restart until job is finished
-    // Rationale: Let the job run, don't stop it possibly several times
-
-    if (d->jobThread)
-    {
-        d->refreshTimer->start(50);
-    }
-    else
-    {
-        refresh();
+        d->incrementalTimer->start(250);
     }
 }
 
@@ -295,7 +263,7 @@ void ItemAlbumModel::slotNextIncrementalRefresh()
 {
     if (d->jobThread)
     {
-        d->incrementalTimer->start(50);
+        d->incrementalTimer->start(100);
     }
     else
     {
@@ -316,9 +284,6 @@ void ItemAlbumModel::startListJob(const QList<Album*>& albums)
         d->jobThread = nullptr;
     }
 
-    CoreDbUrl url;
-    QList<int> ids;
-
     // stop preloading Thumbnails
 
     imageInfosCleared();
@@ -328,6 +293,9 @@ void ItemAlbumModel::startListJob(const QList<Album*>& albums)
         return;
     }
 
+    CoreDbUrl url;
+    QList<int> ids;
+
     if ((albums.first()->type() == Album::TAG) || (albums.first()->type() == Album::SEARCH))
     {
         for (QList<Album*>::const_iterator it = albums.constBegin() ; it != albums.constEnd() ; ++it)
@@ -520,6 +488,14 @@ void ItemAlbumModel::slotData(const QList<ItemListerRecord>& records)
 
         addItemInfos(newItemsList);
     }
+
+    // A refresh has just been completed, but another one has already
+    // started, then slow down the refresh significantly.
+
+    if (hasScheduledRefresh())
+    {
+        d->incrementalTimer->start(1000);
+    }
 }
 
 void ItemAlbumModel::slotImageChange(const ImageChangeset& changeset)
@@ -529,6 +505,8 @@ void ItemAlbumModel::slotImageChange(const ImageChangeset& changeset)
         return;
     }
 
+    ItemModel::slotImageChange(changeset);
+
     // already scheduled to refresh?
 
     if (hasScheduledRefresh())
@@ -541,6 +519,8 @@ void ItemAlbumModel::slotImageChange(const ImageChangeset& changeset)
     if ((DatabaseFields::Images)changeset.changes() == DatabaseFields::Status)
     {
         scheduleIncrementalRefresh();
+
+        return;
     }
 
     // If we list a search, a change to a property may alter the search result
@@ -596,8 +576,6 @@ void ItemAlbumModel::slotImageChange(const ImageChangeset& changeset)
             }
         }
     }
-
-    ItemModel::slotImageChange(changeset);
 }
 
 void ItemAlbumModel::slotImageTagChange(const ImageTagChangeset& changeset)
@@ -607,6 +585,15 @@ void ItemAlbumModel::slotImageTagChange(const ImageTagChangeset& changeset)
         return;
     }
 
+    ItemModel::slotImageTagChange(changeset);
+
+    // already scheduled to refresh?
+
+    if (hasScheduledRefresh())
+    {
+        return;
+    }
+
     bool doRefresh = false;
     QList<Album*>::iterator it;
 
@@ -641,8 +628,6 @@ void ItemAlbumModel::slotImageTagChange(const ImageTagChangeset& changeset)
     {
         scheduleIncrementalRefresh();
     }
-
-    ItemModel::slotImageTagChange(changeset);
 }
 
 void ItemAlbumModel::slotCollectionImageChange(const CollectionImageChangeset& changeset)
@@ -654,7 +639,7 @@ void ItemAlbumModel::slotCollectionImageChange(const CollectionImageChangeset& c
 
     // already scheduled to refresh?
 
-    if (d->refreshTimer->isActive())
+    if (hasScheduledRefresh())
     {
         return;
     }
@@ -805,3 +790,5 @@ void ItemAlbumModel::slotAlbumsCleared()
 }
 
 } // namespace Digikam
+
+#include "moc_itemalbummodel.cpp"
