@@ -6,7 +6,7 @@
  * Date        : 2011-07-03
  * Description : A widget to provide feedback or propose opportunistic interactions
  *
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2011      by Aurelien Gateau <agateau at kde dot org>
  * SPDX-FileCopyrightText: 2014      by Dominik Haumann <dhaumann at kde dot org>
  *
@@ -22,11 +22,8 @@
 #include <QEvent>
 #include <QGridLayout>
 #include <QHBoxLayout>
-#include <QLabel>
 #include <QPainter>
 #include <QShowEvent>
-#include <QTimeLine>
-#include <QToolButton>
 #include <QStyle>
 
 // KDE includes
@@ -237,3 +234,5 @@ int DNotificationWidget::Private::bestContentHeight() const
 }
 
 } // namespace Digikam
+
+#include "moc_dnotificationwidget_p.cpp"
