@@ -6,7 +6,7 @@
  * Date        : 2004-11-17
  * Description : a tab to display item metadata information
  *
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -56,20 +56,15 @@ public:
         EXIFTOOL
     };
 
-    explicit Private()
-      : exifWidget     (nullptr),
-        makernoteWidget(nullptr),
-        iptcWidget     (nullptr),
-        xmpWidget      (nullptr),
-        exifToolWidget (nullptr)
-    {
-    }
+public:
 
-    ExifWidget*      exifWidget;
-    MakerNoteWidget* makernoteWidget;
-    IptcWidget*      iptcWidget;
-    XmpWidget*       xmpWidget;
-    ExifToolWidget*  exifToolWidget;
+    Private() = default;
+
+    ExifWidget*      exifWidget         = nullptr;
+    MakerNoteWidget* makernoteWidget    = nullptr;
+    IptcWidget*      iptcWidget         = nullptr;
+    XmpWidget*       xmpWidget          = nullptr;
+    ExifToolWidget*  exifToolWidget     = nullptr;
 };
 
 ItemPropertiesMetadataTab::ItemPropertiesMetadataTab(QWidget* const parent)
@@ -274,3 +269,5 @@ void ItemPropertiesMetadataTab::setCurrentData(DMetadata* const metaData, const
 }
 
 } // namespace Digikam
+
+#include "moc_itempropertiesmetadatatab.cpp"
