@@ -6,7 +6,7 @@
  * Date        : 2004-11-17
  * Description : item properties side bar (without support of digiKam database).
  *
- * SPDX-FileCopyrightText: 2004-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -39,11 +39,11 @@ class ItemSelectionPropertiesTab;
 class ItemPropertiesMetadataTab;
 class ItemPropertiesColorsTab;
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
 class ItemPropertiesGPSTab;
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
 class DIGIKAM_EXPORT ItemPropertiesSideBar : public Sidebar
 {
@@ -108,11 +108,11 @@ protected:
     ItemPropertiesMetadataTab*  m_metadataTab;
     ItemPropertiesColorsTab*    m_colorTab;
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     ItemPropertiesGPSTab*       m_gpsTab;
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
 };
 
