@@ -6,14 +6,14 @@
  * Date        : 2008-10-09
  * Description : internal private container for DRawDecoder
  *
- * SPDX-FileCopyrightText: 2008-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DRAW_DECODER_PRIVATE_H
-#define DIGIKAM_DRAW_DECODER_PRIVATE_H
+#ifndef DIGIKAM_DRAW_DECODER_P_H
+#define DIGIKAM_DRAW_DECODER_P_H
 
 #include "digikam_config.h"
 
@@ -29,7 +29,6 @@
 // Local includes
 
 #include "digikam_debug.h"
-#include "digikam_config.h"
 #include "drawinfo.h"
 #include "drawdecoder.h"
 #include "drawfiles.h"
@@ -107,13 +106,13 @@ public:
 
 private:
 
-    double       m_progress;
+    double       m_progress = 0.0;
 
-    DRawDecoder* m_parent;
+    DRawDecoder* m_parent   = nullptr;
 
     friend class DRawDecoder;
 };
 
 } // namespace Digikam
 
-#endif // DIGIKAM_DRAW_DECODER_PRIVATE_H
+#endif // DIGIKAM_DRAW_DECODER_P_H
