@@ -6,7 +6,7 @@
  * Date        : 2003-16-10
  * Description : application settings interface
  *
- * SPDX-FileCopyrightText: 2003-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2003-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  * SPDX-FileCopyrightText: 2017      by Simon Frei <freisim93 at gmail dot com>
  *
@@ -232,7 +232,6 @@ ApplicationSettings::Private::Private(ApplicationSettings* const qq)
       updateWithDebug                                   (false),
       sidebarTitleStyle                                 (DMultiTabBar::AllIconsText),
       albumSortRole                                     (ApplicationSettings::ByFolder),
-      albumSortChanged                                  (false),
       imageSortOrder                                    (0),
       imageSorting                                      (0),
       imageSeparationMode                               (0),
@@ -374,7 +373,6 @@ void ApplicationSettings::Private::init()
 
     syncToDigikam                                     = false;
     syncToBaloo                                       = false;
-    albumSortChanged                                  = false;
 
     faceDetectionAccuracy                             = 0.7;
     faceDetectionYoloV3                               = false;
