@@ -7,7 +7,7 @@
  * Description : dialog to edit and create digiKam Tags
  *
  * SPDX-FileCopyrightText: 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -70,33 +70,23 @@ class Q_DECL_HIDDEN TagEditDlg::Private
 {
 public:
 
-    explicit Private()
-      : create         (false),
-        topLabel       (nullptr),
-        iconButton     (nullptr),
-        resetIconButton(nullptr),
-        buttons        (nullptr),
-        keySeqWidget   (nullptr),
-        mainRootAlbum  (nullptr),
-        titleEdit      (nullptr)
-    {
-    }
+    Private() = default;
 
-    bool                create;
+    bool                create          = false;
 
-    QLabel*             topLabel;
+    QLabel*             topLabel        = nullptr;
 
     QString             icon;
 
-    QPushButton*        iconButton;
-    QPushButton*        resetIconButton;
+    QPushButton*        iconButton      = nullptr;
+    QPushButton*        resetIconButton = nullptr;
 
-    QDialogButtonBox*   buttons;
+    QDialogButtonBox*   buttons         = nullptr;
 
-    KKeySequenceWidget* keySeqWidget;
+    KKeySequenceWidget* keySeqWidget    = nullptr;
 
-    TAlbum*             mainRootAlbum;
-    SearchTextBar*      titleEdit;
+    TAlbum*             mainRootAlbum   = nullptr;
+    SearchTextBar*      titleEdit       = nullptr;
 };
 
 TagEditDlg::TagEditDlg(QWidget* const parent, TAlbum* const album, bool create)
@@ -573,3 +563,5 @@ TagsListCreationErrorDialog::TagsListCreationErrorDialog(QWidget* const parent,
 } // namespace Digikam
 
 #include "tageditdlg.moc"
+
+#include "moc_tageditdlg.cpp"
