@@ -6,7 +6,7 @@
  * Date        : 2011-12-28
  * Description : Low level threads management for batch processing on multi-core
  *
- * SPDX-FileCopyrightText: 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText:      2014 by Veaceslav Munteanu <veaceslav dot munteanu90 at gmail dot com>
  * SPDX-FileCopyrightText: 2011-2012 by Janardhan Reddy <annapareddyjanardhanreddy at gmail dot com>
  *
@@ -23,6 +23,7 @@
 #include <QObject>
 #include <QThread>
 #include <QRunnable>
+#include <QElapsedTimer>
 
 // Local includes
 
@@ -72,6 +73,13 @@ public Q_SLOTS:
      */
     void cancel();
 
+public:
+
+    /**
+     * Timer to determine the running time of the job.
+     */
+    QElapsedTimer m_timer;
+
 protected:
 
     /**
