@@ -17,7 +17,6 @@
 // Qt includes
 
 #include <QMutex>
-#include <QMutexLocker>
 #include <QWaitCondition>
 
 // Local includes
@@ -386,3 +385,5 @@ bool DynamicThread::runningFlag() const volatile
 }
 
 } // namespace Digikam
+
+#include "moc_dynamicthread.cpp"
