@@ -18,17 +18,21 @@
 // Qt includes
 
 #include <QString>
+#include <QStringList>
 #include <QList>
 #include <QUrl>
 #include <QSize>
 #include <QMap>
+#include <QTime>
 
 // Local includes
 
+#include "digikam_export.h"
 #include "filesaveconflictbox.h"
 #include "transitionmngr.h"
 #include "effectmngr.h"
-#include "digikam_export.h"
+#include "frameosdsettings.h"
+#include "dinfointerface.h"
 
 class KConfigGroup;
 
@@ -207,7 +211,9 @@ public:
     static QMap<VidPlayer,  QString> videoPlayerNames();
 
     static QSize videoSizeFromType(VidType type);       ///< Return the current size from a type of video.
-    static bool isVideoTVFormat(VidType type);        ///< Return true if type is a video TV format. If false is returned type is computer graphics screen format.
+    static bool isVideoTVFormat(VidType type);          ///< Return true if type is a video TV format. If false is returned type is computer graphics screen format.
+
+    QStringList defaultFFmpegSearchPaths() const;
 
 public:
 
@@ -216,7 +222,7 @@ public:
     // -- Generator settings ------
 
     QList<QUrl>                       inputImages;      ///< Images stream.
-    QList<QUrl>                       inputAudio;       ///< Soundtracks stream.
+    QString                           audioTrack;       ///< Soundtrack stream.
 
     TransitionMngr::TransType         transition;       ///< Transition type between images.
 
@@ -231,12 +237,27 @@ public:
     EffectMngr::EffectType            vEffect;          ///< Encoded video effect while displaying images.
 
     FileSaveConflictBox::ConflictRule conflictRule;     ///< Rule to follow if video file already exists.
-    QUrl                              outputDir;        ///< Encoded video stream directory.
+    QString                           outputDir;        ///< Encoded video stream directory.
 
     // ---------------------
 
+    QString                           tempDir;          ///< To store temporary frames.
+    QString                           outputFile;       ///< Path to encoded video.
+    QString                           filesList;        ///< Path to list of frame files to encode.
     QString                           outputVideo;      ///< Target video file encoded at end.
     VidPlayer                         outputPlayer;     ///< Open video stream in player at end.
+    QString                           ffmpegPath;       ///< Path to FFmpeg binary.
+    bool                              equalize;         ///< Equalize filter to applying while encoding video from frames.
+    int                               strength;         ///< Equalization strength factor.
+
+    // -- FFMpeg features --------
+
+    QMap<QString, QString>            ffmpegCodecs;     ///< Map of FFmpeg codec names and features.
+    QMap<QString, QString>            ffmpegFormats;    ///< Map of FFmpeg format names and features.
+    QTime                             soundtrackLength; ///< Duration of the soundtrack.
+
+    FrameOsdSettings                  osdSettings;      ///< On Screen Display parameters.
+    DInfoInterface*                   iface;            ///< Plugin host interface to handle item properties.
 };
 
 } // namespace Digikam
