@@ -4,20 +4,11 @@
  * https://www.digikam.org
  *
  * Date        : 2017-05-25
- * Description : a tool to generate video slideshow from images.
+ * Description : a tool to generate video slideshow frames from images.
  *
- * Copyright (C) 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -62,8 +53,7 @@ private:
 
 private:
 
-    class Private;
-    Private* const d;
+    VidSlideSettings* m_settings = nullptr;
 };
 
 } // namespace Digikam
