@@ -7,7 +7,7 @@
  * Description : Graphics View item for DImg
  *
  * SPDX-FileCopyrightText: 2010-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -19,7 +19,6 @@
 // Qt includes
 
 #include <QStyleOptionGraphicsItem>
-#include <QApplication>
 #include <QPainter>
 #include <QPoint>
 #include <QRect>
@@ -189,6 +188,13 @@ ImageZoomSettings* GraphicsDImgItem::zoomSettings()
     return &d->zoomSettings;
 }
 
+void GraphicsDImgItem::setDisplayWidget(QWidget* const widget)
+{
+    Q_D(GraphicsDImgItem);
+
+    d->zoomSettings.setDisplayWidget(widget);
+}
+
 QRectF GraphicsDImgItem::boundingRect() const
 {
     Q_D(const GraphicsDImgItem);
@@ -198,7 +204,7 @@ QRectF GraphicsDImgItem::boundingRect() const
     return QRectF(QPointF(0, 0), d->zoomSettings.zoomedSize()).toAlignedRect();
 }
 
-void GraphicsDImgItem::paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget*)
+void GraphicsDImgItem::paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget)
 {
     Q_D(GraphicsDImgItem);
 
@@ -226,12 +232,12 @@ void GraphicsDImgItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*
      * pixmap.
      */
 
-    double ratio          = qApp->devicePixelRatio();
+    qreal dpr             = widget->devicePixelRatio();
 
-    QRect  scaledDrawRect = QRectF(ratio * drawRect.x(),
-                                   ratio * drawRect.y(),
-                                   ratio * drawRect.width(),
-                                   ratio * drawRect.height()).toRect();
+    QRect  scaledDrawRect = QRectF(dpr * drawRect.x(),
+                                   dpr * drawRect.y(),
+                                   dpr * drawRect.width(),
+                                   dpr * drawRect.height()).toRect();
 
     if (d->cachedPixmaps.find(scaledDrawRect, &pix, &pixSourceRect))
     {
@@ -248,8 +254,8 @@ void GraphicsDImgItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*
     {
         // scale "as if" scaling to whole image, but clip output to our exposed region
 
-        QSize scaledCompleteSize = QSizeF(ratio * completeSize.width(),
-                                          ratio * completeSize.height()).toSize();
+        QSize scaledCompleteSize = QSizeF(dpr * completeSize.width(),
+                                          dpr * completeSize.height()).toSize();
         DImg scaledImage         = d->image.smoothScaleClipped(scaledCompleteSize.width(),
                                                                scaledCompleteSize.height(),
                                                                scaledDrawRect.x(),
@@ -268,3 +274,5 @@ void GraphicsDImgItem::contextMenuEvent(QGraphicsSceneContextMenuEvent* e)
 }
 
 } // namespace Digikam
+
+#include "moc_graphicsdimgitem.cpp"
