@@ -22,7 +22,6 @@
 // Qt includes
 
 #include <QApplication>
-#include <QFlags>
 #include <QGraphicsProxyWidget>
 #include <QGraphicsScene>
 #include <QGraphicsSceneMouseEvent>
@@ -790,3 +789,5 @@ void RegionFrameItem::setRectInSceneCoordinatesAdjusted(const QRectF& rect)
 }
 
 } // namespace Digikam
+
+#include "moc_regionframeitem.cpp"
