@@ -6,19 +6,10 @@
  * Date        : 2010-01-16
  * Description : Qt item view for images
  *
- * Copyright (C) 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2011-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -220,9 +211,11 @@ private Q_SLOTS:
 
 private:
 
-    // Hidden copy constructor and assignment operator.
-    ItemViewCategorized(const ItemViewCategorized&);
-    ItemViewCategorized& operator=(const ItemViewCategorized&);
+    // Disable
+    ItemViewCategorized(const ItemViewCategorized&)            = delete;
+    ItemViewCategorized& operator=(const ItemViewCategorized&) = delete;
+
+private:
 
     void ensureSelectionAfterChanges();
 
