@@ -6,7 +6,7 @@
  * Date        : 2008-07-30
  * Description : digiKam about data.
  *
- * SPDX-FileCopyrightText: 2008-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -65,7 +65,7 @@ const QString DAboutData::digiKamFamily()
 
 const QString DAboutData::copyright()
 {
-    return i18n("(c) 2001-2023, digiKam developers team");
+    return i18n("(c) 2001-2024, digiKam developers team");
 }
 
 const QUrl DAboutData::webProjectUrl()
@@ -162,7 +162,7 @@ void DAboutData::authorsRegistration(KAboutData& aboutData)
                         );
 
     aboutData.addCredit ( ki18n("Quốc Hưng Trần").toString(),
-                          ki18n("MJPEGStream plugin, OCR text Converter plugin").toString(),
+                          ki18n("MJPEGStream plugin, OCR text Converter plugin, auto-tags assignment engine").toString(),
                           QLatin1String("quochungtran1999 at gmail dot com "),
                           QLatin1String("https://www.linkedin.com/in/qu%E1%BB%91c-h%C6%B0ng-tr%E1%BA%A7n-92a504163/")
                         );
@@ -448,3 +448,5 @@ void DAboutData::authorsRegistration(KAboutData& aboutData)
 }
 
 } // namespace Digikam
+
+#include "moc_daboutdata.cpp"
