@@ -6,7 +6,7 @@
  * Date        : 2014-11-30
  * Description : Save space slider widget
  *
- * SPDX-FileCopyrightText: 2014-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText:      2010 by Justin Noel <justin at ics dot com>
  * SPDX-FileCopyrightText:      2010 by Cyrille Berger <cberger at cberger dot net>
  *
@@ -65,6 +65,7 @@ public:
         STYLE_NOQUIRK,
         STYLE_MACINTOSH,
         STYLE_PLASTIQUE,
+        STYLE_WINDOWS,
         STYLE_BREEZE,
         STYLE_FUSION,
         STYLE_OXYGEN,
@@ -230,6 +231,7 @@ void DAbstractSliderSpinBox::paint(QPainter& painter)
 
     if ((d->style == DAbstractSliderSpinBoxPrivate::STYLE_GTK2)    ||
         (d->style == DAbstractSliderSpinBoxPrivate::STYLE_OXYGEN)  ||
+        (d->style == DAbstractSliderSpinBoxPrivate::STYLE_WINDOWS) ||
         (d->style == DAbstractSliderSpinBoxPrivate::STYLE_MACINTOSH))
     {
         progressOpts.state |= QStyle::State_Horizontal;
@@ -689,6 +691,7 @@ QSize DAbstractSliderSpinBox::sizeHint() const
             break;
 
         case DAbstractSliderSpinBoxPrivate::STYLE_MACINTOSH:
+        case DAbstractSliderSpinBoxPrivate::STYLE_WINDOWS:
         case DAbstractSliderSpinBoxPrivate::STYLE_FUSION:
         case DAbstractSliderSpinBoxPrivate::STYLE_OXYGEN:
         case DAbstractSliderSpinBoxPrivate::STYLE_GTK2:
@@ -968,6 +971,10 @@ void DAbstractSliderSpinBox::changeEvent(QEvent* e)
         {
             d->style = DAbstractSliderSpinBoxPrivate::STYLE_PLASTIQUE;
         }
+        else if (style()->objectName() == QLatin1String("windows"))
+        {
+            d->style = DAbstractSliderSpinBoxPrivate::STYLE_WINDOWS;
+        }
         else if (style()->objectName() == QLatin1String("breeze"))
         {
             d->style = DAbstractSliderSpinBoxPrivate::STYLE_BREEZE;
@@ -1230,3 +1237,5 @@ void DDoubleSliderSpinBox::setInternalValue(int _value, bool blockUpdateSignal)
 }
 
 } // namespace Digikam
+
+#include "moc_dsliderspinbox.cpp"
