@@ -6,7 +6,7 @@
  * Date        : 2022-08-01
  * Description : Text edit widgets with spellcheck support and edition limitations.
  *
- * SPDX-FileCopyrightText: 2021-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -71,6 +71,7 @@ void DTextEdit::Private::init(DTextEdit* const parent)
 #endif
 
     parent->setLinesVisible(lines);
+    parent->setTabChangesFocus(true);
 
     clrBtn = new DTextEditClearButton(parent);
     parent->setCornerWidget(clrBtn);
@@ -152,3 +153,5 @@ void DPlainTextEdit::Private::init(DPlainTextEdit* const parent)
 }
 
 } // namespace Digikam
+
+#include "moc_dtextedit_p.cpp"
