@@ -6,19 +6,10 @@
  * Date        : 2013-08-01
  * Description : Qt model view for Showfoto item - the delegate Private
  *
- * Copyright (C) 2013      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * Copyright (C) 2013-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * SPDX-FileCopyrightText: 2013-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -57,17 +48,11 @@ class Q_DECL_HIDDEN ShowfotoDelegate::ShowfotoDelegatePrivate : public ShowfotoI
 public:
 
     ShowfotoDelegatePrivate()
-      : contentWidth       (0),
-        drawImageFormat    (true),
-        drawFocusFrame     (true),
-        drawMouseOverFrame (true),
-        currentView        (nullptr),
-        currentModel       (nullptr)
     {
         actualPixmapRectCache.setMaxCost(250);
     }
 
-    int                    contentWidth;
+    int                    contentWidth             = 0;
 
     QRect                  dateRect;
     QRect                  pixmapRect;
@@ -78,14 +63,14 @@ public:
     QRect                  groupRect;
     QRect                  coordinatesRect;
 
-    bool                   drawImageFormat;
-    bool                   drawFocusFrame;
-    bool                   drawMouseOverFrame;
+    bool                   drawImageFormat          = true;
+    bool                   drawFocusFrame           = true;
+    bool                   drawMouseOverFrame       = true;
 
     QCache<int, QRect>     actualPixmapRectCache;
 
-    ShowfotoThumbnailBar*  currentView;
-    QAbstractItemModel*    currentModel;
+    ShowfotoThumbnailBar*  currentView              = nullptr;
+    QAbstractItemModel*    currentModel             = nullptr;
 
 public:
 
@@ -99,7 +84,6 @@ class Q_DECL_HIDDEN ShowfotoThumbnailDelegatePrivate : public ShowfotoDelegate::
 public:
 
     ShowfotoThumbnailDelegatePrivate()
-      : flow              (QListView::LeftToRight)
     {
         // switch off drawing of frames
 
@@ -111,7 +95,7 @@ public:
 
 public:
 
-    QListView::Flow flow;
+    QListView::Flow flow        = QListView::LeftToRight;
     QRect           viewSize;
 };
 
@@ -121,9 +105,7 @@ class Q_DECL_HIDDEN ShowfotoNormalDelegatePrivate : public ShowfotoDelegate::Sho
 {
 public:
 
-    ShowfotoNormalDelegatePrivate()
-    {
-    }
+    ShowfotoNormalDelegatePrivate() = default;
 
     void init(ShowfotoNormalDelegate* const q, ShowfotoThumbnailBar* const parent);
 };
