@@ -31,7 +31,6 @@
 // Local includes
 
 #include "highlighter.h"
-#include "parser.h"
 
 // Constants
 
@@ -447,3 +446,5 @@ void AdvancedRenameInput::writeSettings()
 }
 
 } // namespace Digikam
+
+#include "moc_advancedrenameinput.cpp"
