@@ -6,18 +6,9 @@
  * Date        : 2010-08-08
  * Description : a class that manages the files to be renamed
  *
- * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -29,10 +20,12 @@
 
 // Qt includes
 
-#include <QList>
 #include <QMap>
+#include <QList>
+#include <QUuid>
 #include <QFileInfo>
 #include <QStorageInfo>
+#include <QRegularExpression>
 
 // Local includes
 
@@ -62,16 +55,7 @@ struct SortByDate
         QFileInfo fi1(s1);
         QFileInfo fi2(s2);
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
-
         return (fi1.birthTime() < fi2.birthTime());
-
-#else
-
-        return (fi1.created() < fi2.created());
-
-#endif
-
     }
 };
 
@@ -96,14 +80,20 @@ public:
         parserType   (AdvancedRenameManager::DefaultParser),
         sortAction   (AdvancedRenameManager::SortCustom),
         sortDirection(AdvancedRenameManager::SortAscending),
-        startIndex   (1)
+        startIndex   (1),
+        cutFileName  (0)
     {
     }
 
     QStringList                          files;
+
+    QList<QString>                       randomList;
+
     QMap<QString, int>                   fileIndexMap;
     QMap<QString, int>                   folderIndexMap;
     QMap<QString, int>                   fileGroupIndexMap;
+    QMap<QString, int>                   fileCounterIndexMap;
+
     QMap<QString, QDateTime>             fileDatesMap;
     QMap<QString, QString>               renamedFiles;
 
@@ -114,6 +104,7 @@ public:
     AdvancedRenameManager::SortDirection sortDirection;
 
     int                                  startIndex;
+    int                                  cutFileName;
 };
 
 AdvancedRenameManager::AdvancedRenameManager()
@@ -144,12 +135,12 @@ void AdvancedRenameManager::setSortAction(SortAction action)
 
     QList<QUrl> list;
 
-    foreach (const QString& file, d->files)
+    Q_FOREACH (const QString& file, d->files)
     {
         list << QUrl::fromLocalFile(file);
     }
 
-    emit signalSortingChanged(list);
+    Q_EMIT signalSortingChanged(list);
 }
 
 AdvancedRenameManager::SortAction AdvancedRenameManager::sortAction() const
@@ -164,12 +155,12 @@ void AdvancedRenameManager::setSortDirection(SortDirection direction)
 
     QList<QUrl> list;
 
-    foreach (const QString& file, d->files)
+    Q_FOREACH (const QString& file, d->files)
     {
         list << QUrl::fromLocalFile(file);
     }
 
-    emit signalSortingChanged(list);
+    Q_EMIT signalSortingChanged(list);
 }
 
 AdvancedRenameManager::SortDirection AdvancedRenameManager::sortDirection() const
@@ -183,6 +174,11 @@ void AdvancedRenameManager::setStartIndex(int index)
     initialize();
 }
 
+void AdvancedRenameManager::setCutFileName(int index)
+{
+    d->cutFileName = index;
+}
+
 void AdvancedRenameManager::setWidget(AdvancedRenameWidget* widget)
 {
     if (!widget)
@@ -264,13 +260,14 @@ void AdvancedRenameManager::parseFiles(const QString& parseString)
 
     d->parser->reset();
 
-    foreach (const QString& file, d->files)
+    Q_FOREACH (const QString& file, d->files)
     {
         QUrl url              = QUrl::fromLocalFile(file);
         ParseSettings settings;
         settings.fileUrl      = url;
         settings.parseString  = parseString;
         settings.startIndex   = d->startIndex;
+        settings.cutFileName  = d->cutFileName;
         settings.creationTime = d->fileDatesMap[file];
         settings.manager      = this;
         d->renamedFiles[file] = d->parser->parse(settings);
@@ -286,7 +283,7 @@ void AdvancedRenameManager::parseFiles(const QString& parseString, const ParseSe
 
     d->parser->reset();
 
-    foreach (const QString& file, d->files)
+    Q_FOREACH (const QString& file, d->files)
     {
         QUrl url               = QUrl::fromLocalFile(file);
         ParseSettings settings = _settings;
@@ -301,7 +298,7 @@ void AdvancedRenameManager::parseFiles(const QString& parseString, const ParseSe
 
 void AdvancedRenameManager::addFiles(const QList<ParseSettings>& files)
 {
-    foreach (const ParseSettings& ps, files)
+    Q_FOREACH (const ParseSettings& ps, files)
     {
         addFile(ps.fileUrl.toLocalFile(), ps.creationTime);
     }
@@ -314,6 +311,7 @@ void AdvancedRenameManager::clearMappings()
     d->fileIndexMap.clear();
     d->folderIndexMap.clear();
     d->fileGroupIndexMap.clear();
+    d->fileCounterIndexMap.clear();
     d->renamedFiles.clear();
 }
 
@@ -383,7 +381,7 @@ QMap<QString, QString> AdvancedRenameManager::newFileList(bool checkFileSystem)
     {
         QMap<QString, QString> renamedFiles;
 
-        foreach (const QString& fileName, d->renamedFiles.keys())
+        Q_FOREACH (const QString& fileName, d->renamedFiles.keys())
         {
             renamedFiles[fileName] = newName(fileName);
         }
@@ -409,14 +407,18 @@ bool AdvancedRenameManager::initialize()
 
     initializeFileList();
 
-    // fill normal index map
+    // fill normal index map and file random string map
 
     {
         int counter = 1;
 
-        foreach (const QString& file, d->files)
+        Q_FOREACH (const QString& file, d->files)
         {
+            QString random = QUuid::createUuid().toString();
+            random.remove(QLatin1Char('-'));
+
             d->fileIndexMap[file] = counter++;
+            d->randomList        << random.mid(1, 32);
         }
     }
 
@@ -425,7 +427,7 @@ bool AdvancedRenameManager::initialize()
     {
         int counter = 1;
 
-        foreach (const QString& file, d->files)
+        Q_FOREACH (const QString& file, d->files)
         {
             if (!d->fileGroupIndexMap.contains(fileGroupKey(file)))
             {
@@ -436,10 +438,10 @@ bool AdvancedRenameManager::initialize()
 
     // fill folder group index map
 
-    {
-        QMap<QString, QList<QString> > dirMap;
+    QMap<QString, QList<QString> > dirMap;
 
-        foreach (const QString& file, d->files)
+    {
+        Q_FOREACH (const QString& file, d->files)
         {
             QFileInfo fi(file);
             QString path = fi.absolutePath();
@@ -455,11 +457,11 @@ bool AdvancedRenameManager::initialize()
             }
         }
 
-        foreach (const QString& dir, dirMap.keys())
+        Q_FOREACH (const QString& dir, dirMap.keys())
         {
             int index = 0;
 
-            foreach (const QString& f, dirMap[dir])
+            Q_FOREACH (const QString& f, dirMap[dir])
             {
                 if (!d->folderIndexMap.contains(f))
                 {
@@ -469,13 +471,48 @@ bool AdvancedRenameManager::initialize()
         }
     }
 
+    // fill file counter index map
+
+    {
+        QString regExp(QLatin1String("(.*?)(\\d+)((_v\\d+[.])|[.])(.*)?"));
+        QRegularExpression counterRegExp(QRegularExpression::anchoredPattern(regExp));
+
+        Q_FOREACH (const QString& path, dirMap.keys())
+        {
+            QDir dir(path);
+            d->fileCounterIndexMap[path] = 0;
+
+            Q_FOREACH (const QString& file, dir.entryList(QDir::Files))
+            {
+                if (d->files.contains(dir.filePath(file)) ||
+                    file.endsWith(QLatin1String(".xmp")))
+                {
+                    continue;
+                }
+
+                QRegularExpressionMatch match = counterRegExp.match(file);
+
+                if (match.hasMatch())
+                {
+                    int count = match.captured(2).toInt();
+
+                    if (d->fileCounterIndexMap[path] < count)
+                    {
+                        d->fileCounterIndexMap[path] = count;
+                    }
+                }
+            }
+        }
+    }
+
     return true;
 }
 
 QString AdvancedRenameManager::fileGroupKey(const QString& filename) const
 {
     QFileInfo fi(filename);
-    QString tmp = fi.absoluteFilePath().left(fi.absoluteFilePath().lastIndexOf(fi.suffix()));
+    QString tmp = fi.absolutePath() + QLatin1Char('/');
+    tmp        += fi.completeBaseName().mid(d->cutFileName) + QLatin1Char('.');
 
     return tmp;
 }
@@ -495,6 +532,23 @@ int AdvancedRenameManager::indexOfFileGroup(const QString& filename)
     return d->fileGroupIndexMap.value(fileGroupKey(filename), -1);
 }
 
+int AdvancedRenameManager::indexOfFileCounter(const QString& filename)
+{
+    QFileInfo fi(filename);
+
+    return d->fileCounterIndexMap.value(fi.absolutePath(), -1);
+}
+
+QString AdvancedRenameManager::randomStringOfIndex(int index)
+{
+    if ((index < 0) || (index >= d->randomList.size()))
+    {
+        return QString();
+    }
+
+    return d->randomList.at(index);
+}
+
 QString AdvancedRenameManager::newName(const QString& filename) const
 {
     // For the Linux or Windows file system,
@@ -510,7 +564,7 @@ QString AdvancedRenameManager::newName(const QString& filename) const
         sysType.contains(QLatin1String("NTFS")) ||
         sysType.contains(QLatin1String("FUSEBLK")))
     {
-        regExpStr.append(QLatin1String("<>,:=\";|\\\\/"));
+        regExpStr.append(QLatin1String("<>:=\"|\\\\/"));
 
         if (sysType.contains(QLatin1String("FAT")))
         {
@@ -518,7 +572,7 @@ QString AdvancedRenameManager::newName(const QString& filename) const
         }
     }
 
-    QRegExp regExp(regExpStr + QLatin1Char(']'));
+    QRegularExpression regExp(regExpStr + QLatin1Char(']'));
     newName.replace(regExp, QLatin1String("_"));
 
     return newName;
@@ -536,3 +590,5 @@ void AdvancedRenameManager::addFile(const QString& filename, const QDateTime& da
 }
 
 } // namespace Digikam
+
+#include "moc_advancedrenamemanager.cpp"
