@@ -16,7 +16,6 @@
 
 // Qt includes
 
-#include <QTreeWidget>
 #include <QHeaderView>
 #include <QGridLayout>
 #include <QString>
@@ -283,3 +282,5 @@ void DbKeySelectorView::removeChildlessHeaders()
 }
 
 } // namespace Digikam
+
+#include "moc_dbkeyselector.cpp"
