@@ -6,7 +6,7 @@
  * Date        : 2009-02-15
  * Description : Plasma Address Book contacts interface
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -17,9 +17,7 @@
 // Qt includes
 
 #include <QApplication>
-#include <QAction>
 #include <QString>
-#include <QMenu>
 #include <QIcon>
 
 // KDE includes
@@ -139,3 +137,5 @@ void AkonadiIface::slotABCMenuTriggered(QAction* action)
 }
 
 } // namespace Digikam
+
+#include "moc_akonadiiface.cpp"
