@@ -6,20 +6,11 @@
  * Date        : 2008-05-19
  * Description : Find Duplicates tree-view search album.
  *
- * Copyright (C) 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -66,14 +57,14 @@ FindDuplicatesAlbum::FindDuplicatesAlbum(QWidget* const parent)
 {
     d->thumbLoadThread = ThumbnailLoadThread::defaultThread();
 
+    setColumnCount(5);
+    setSortingEnabled(true);
     setRootIsDecorated(false);
     setUniformRowHeights(true);
+    setAllColumnsShowFocus(true);
     setSelectionMode(QAbstractItemView::ExtendedSelection);
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    setAllColumnsShowFocus(true);
     setIconSize(QSize(d->iconSize, d->iconSize));
-    setSortingEnabled(true);
-    setColumnCount(5);
     setHeaderLabels(QStringList() << i18n("Ref. images")
                                   << i18n("Ref. dates")
                                   << i18n("Ref. albums")
@@ -156,7 +147,7 @@ void FindDuplicatesAlbum::slotThumbnailLoaded(const LoadingDescription& desc,
 void FindDuplicatesAlbum::updateDuplicatesAlbumItems(const QList<SAlbum*>& sAlbumsToRebuild,
                                                      const QList<qlonglong>& deletedImages)
 {
-    foreach (QTreeWidgetItem* const selectedItem, selectedItems())
+    Q_FOREACH (QTreeWidgetItem* const selectedItem, selectedItems())
     {
         FindDuplicatesAlbumItem* const item = dynamic_cast<FindDuplicatesAlbumItem*>(selectedItem);
 
@@ -206,7 +197,7 @@ void FindDuplicatesAlbum::removeDuplicates()
     // Buffer the urls for deletion and imageids
     // for notification of the AlbumManager
 
-    foreach (const ItemInfo& info, duplicatedItems)
+    Q_FOREACH (const ItemInfo& info, duplicatedItems)
     {
         urlList  << info.fileUrl();
     }
@@ -222,3 +213,5 @@ void FindDuplicatesAlbum::removeDuplicates()
 }
 
 } // namespace Digikam
+
+#include "moc_findduplicatesalbum.cpp"
