@@ -6,19 +6,11 @@
  * Date        : 2010-05-12
  * Description : Backend for reverse geocoding using geonames.org (non-US)
  *
- * Copyright (C) 2010 by Michael G. Hansen <mike at mghansen dot de>
- * Copyright (C) 2010 by Gabriel Voicu <ping dot gabi at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010      by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2010      by Gabriel Voicu <ping dot gabi at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -26,7 +18,6 @@
 
 // Qt includes
 
-#include <QNetworkAccessManager>
 #include <QDomDocument>
 #include <QUrlQuery>
 #include <QTimer>
@@ -34,6 +25,7 @@
 // Local includes
 
 #include "digikam_debug.h"
+#include "networkmanager.h"
 #include "gpscommon.h"
 
 namespace Digikam
@@ -96,7 +88,7 @@ BackendGeonamesRG::BackendGeonamesRG(QObject* const parent)
     : RGBackend(parent),
       d        (new Private())
 {
-    d->mngr = new QNetworkAccessManager(this);
+    d->mngr = NetworkManager::instance()->getNetworkManager(this);
 
     connect(d->mngr, SIGNAL(finished(QNetworkReply*)),
             this, SLOT(slotFinished(QNetworkReply*)));
@@ -192,8 +184,9 @@ QMap<QString, QString> BackendGeonamesRG::makeQMapFromXML(const QString& xmlData
 
         if (!e.isNull())
         {
-            if ((e.tagName().compare(QLatin1String("countryName")) == 0) ||
-                (e.tagName().compare(QLatin1String("name"))        == 0))
+            if ((e.tagName() == QLatin1String("countryName")) ||
+                (e.tagName() == QLatin1String("countryCode")) ||
+                (e.tagName() == QLatin1String("name")))
             {
                 mappedData.insert(e.tagName(), e.text());
                 resultString.append(e.tagName() + QLatin1Char(':') + e.text() + QLatin1Char('\n'));
@@ -224,20 +217,20 @@ QString BackendGeonamesRG::backendName()
 
 void BackendGeonamesRG::slotFinished(QNetworkReply* reply)
 {
-    if (reply->error() != QNetworkReply::NoError)
-    {
-        d->errorMessage = reply->errorString();
-        emit signalRGReady(d->jobs.first().request);
-        reply->deleteLater();
-        d->jobs.clear();
-
-        return;
-    }
-
     for (int i = 0 ; i < d->jobs.count() ; ++i)
     {
         if (d->jobs.at(i).netReply == reply)
         {
+            if (reply->error() != QNetworkReply::NoError)
+            {
+                d->errorMessage = reply->errorString();
+                Q_EMIT signalRGReady(d->jobs.first().request);
+                reply->deleteLater();
+                d->jobs.clear();
+
+                return;
+            }
+
             d->jobs[i].data.append(reply->readAll());
             break;
         }
@@ -260,7 +253,7 @@ void BackendGeonamesRG::slotFinished(QNetworkReply* reply)
                 d->jobs[i].request[j].rgData =  resultMap;
             }
 
-            emit signalRGReady(d->jobs[i].request);
+            Q_EMIT signalRGReady(d->jobs[i].request);
 
             d->jobs.removeAt(i);
 
@@ -269,11 +262,10 @@ void BackendGeonamesRG::slotFinished(QNetworkReply* reply)
                 QTimer::singleShot(500, this, SLOT(nextPhoto()));
             }
 
+            reply->deleteLater();
             break;
         }
     }
-
-    reply->deleteLater();
 }
 
 void BackendGeonamesRG::cancelRequests()
@@ -283,3 +275,5 @@ void BackendGeonamesRG::cancelRequests()
 }
 
 } // namespace Digikam
+
+#include "moc_backend-geonames-rg.cpp"
