@@ -6,7 +6,7 @@
  * Date        : 2009-12-01
  * Description : Google-Maps-backend for geolocation interface
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2011 by Michael G. Hansen <mike at mghansen dot de>
  * SPDX-FileCopyrightText: 2014      by Justus Schwartz <justus at gmx dot li>
  *
@@ -85,12 +85,14 @@ public:
 
     void setActive(const bool state)                                                      override;
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     void centerOn(const Marble::GeoDataLatLonBox& latLonBox, const bool useSaneZoomLevel) override;
 
 #endif
 
+    void reload()                                                                         override;
+
 public Q_SLOTS:
 
     void slotClustersNeedUpdating()                                                       override;
@@ -119,7 +121,6 @@ private Q_SLOTS:
 
     void slotHTMLInitialized();
     void slotSetCenterTimer();
-    void slotInputUserAPIKey();
     void slotMessageEvent(const QString& message);
     void slotMapTypeActionTriggered(QAction* action);
     void slotHTMLEvents(const QStringList& eventStrings);
