@@ -6,7 +6,7 @@
  * Date        : 2006-09-19
  * Description : Correlator for tracks and images
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2010      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -27,14 +27,10 @@ class Q_DECL_HIDDEN TrackCorrelator::Private
 {
 public:
 
-    explicit Private()
-      : trackManager(nullptr),
-        thread      (nullptr)
-    {
-    }
+    Private() = default;
 
-    TrackManager*           trackManager;
-    TrackCorrelatorThread*  thread;
+    TrackManager*           trackManager = nullptr;
+    TrackCorrelatorThread*  thread       = nullptr;
 };
 
 TrackCorrelator::TrackCorrelator(TrackManager* const trackManager,
@@ -103,3 +99,5 @@ void TrackCorrelator::cancelCorrelation()
 }
 
 } // namespace Digikam
+
+#include "moc_track_correlator.cpp"
