@@ -6,19 +6,10 @@
  * Date        : 2010-06-21
  * Description : A simple model to hold a tree structure.
  *
- * Copyright (C) 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2010-2014 by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2014 by Michael G. Hansen <mike at mghansen dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -31,14 +22,10 @@ class Q_DECL_HIDDEN SimpleTreeModel::Private
 {
 public:
 
-    explicit Private()
-        : rootItem   (nullptr),
-          columnCount(1)
-    {
-    }
+    Private() = default;
 
-    SimpleTreeModel::Item* rootItem;
-    int                    columnCount;
+    SimpleTreeModel::Item* rootItem     = nullptr;
+    int                    columnCount  = 1;
 };
 
 
@@ -91,7 +78,7 @@ bool SimpleTreeModel::setData(const QModelIndex& index, const QVariant& value, i
 
     item->dataColumns[column].insert(role, value);
 
-    emit dataChanged(index, index);
+    Q_EMIT dataChanged(index, index);
 
     return true;
 }
@@ -268,3 +255,5 @@ QModelIndex SimpleTreeModel::itemToIndex(const Item* const item) const
 }
 
 } // namespace Digikam
+
+#include "moc_simpletreemodel.cpp"
