@@ -6,7 +6,7 @@
  * Date        : 2003-01-15
  * Description : Undo state container
  *
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -22,24 +22,15 @@ class UndoState
 {
 public:
 
-    explicit UndoState()
-      : hasUndo           (false),
-        hasRedo           (false),
-        hasChanges        (false),
-        hasUndoableChanges(false)
-    {
-    }
-
-    ~UndoState()
-    {
-    }
+    UndoState()  = default;
+    ~UndoState() = default;
 
 public:
 
-    bool hasUndo;
-    bool hasRedo;
-    bool hasChanges;
-    bool hasUndoableChanges;
+    bool hasUndo            = false;
+    bool hasRedo            = false;
+    bool hasChanges         = false;
+    bool hasUndoableChanges = false;
 };
 
 } // namespace Digikam
