@@ -7,7 +7,7 @@
  * Description : Dialog to adjust soft proofing settings
  *
  * SPDX-FileCopyrightText: 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2013-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -35,7 +35,6 @@
 
 #include "dlayoutbox.h"
 #include "iccprofilescombobox.h"
-#include "iccsettingscontainer.h"
 #include "iccsettings.h"
 #include "iccprofileinfodlg.h"
 #include "dexpanderbox.h"
@@ -247,3 +246,5 @@ void SoftProofDialog::slotHelp()
 }
 
 } // namespace Digikam
+
+#include "moc_softproofdialog.cpp"
