@@ -6,7 +6,7 @@
  * Date        : 2006-01-20
  * Description : core image editor GUI implementation private data.
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -226,7 +226,6 @@ public:
     static const QString         configUseRawImportToolEntry;
     static const QString         configRawImportToolIidEntry;
     static const QString         configUseThemeBackgroundColorEntry;
-    static const QString         configVerticalSplitterSizesEntry;
     static const QString         configVerticalSplitterStateEntry;
 
     QToolButton*                 cmViewIndicator;
@@ -275,6 +274,7 @@ public:
     QList<int>                   fullscreenSizeBackup;
 
     QMap<QString, KService::Ptr> servicesMap;
+    QMap<QString, DServiceInfo>  newServicesMap;
 };
 
 const QString EditorWindow::Private::configAutoZoomEntry(QLatin1String("AutoZoom"));
@@ -306,7 +306,6 @@ const QString EditorWindow::Private::configExpoIndicatorModeEntry(QLatin1String(
 const QString EditorWindow::Private::configUseRawImportToolEntry(QLatin1String("UseRawImportTool"));
 const QString EditorWindow::Private::configRawImportToolIidEntry(QLatin1String("RawImportToolIid"));
 const QString EditorWindow::Private::configUseThemeBackgroundColorEntry(QLatin1String("UseThemeBackgroundColor"));
-const QString EditorWindow::Private::configVerticalSplitterSizesEntry(QLatin1String("Vertical Splitter Sizes"));
 const QString EditorWindow::Private::configVerticalSplitterStateEntry(QLatin1String("Vertical Splitter State"));
 
 void EditorWindow::Private::legacyUpdateSplitterState(KConfigGroup& group)
