@@ -7,7 +7,7 @@
  * Description : digiKam image editor GUI
  *
  * SPDX-FileCopyrightText: 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2004-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -82,6 +82,8 @@ ImageWindow::ImageWindow()
     setAutoSaveSettings(configGroupName(), true);
     d->viewContainer->setAutoSaveSettings(QLatin1String("ImageViewer Thumbbar"), true);
 
+    d->thumbBarDock->reInitialize();
+
     //-------------------------------------------------------------
 
     d->rightSideBar->setConfigGroup(KConfigGroup(&group, QLatin1String("Right Sidebar")));
@@ -1363,3 +1365,5 @@ DInfoInterface* ImageWindow::infoIface(DPluginAction* const ac)
 }
 
 } // namespace Digikam
+
+#include "moc_imagewindow.cpp"
