@@ -6,18 +6,9 @@
  * Date        : 2011-04-27
  * Description : image preview item for image editor.
  *
- * Copyright (C) 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -82,17 +73,17 @@ void ImagePreviewItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*
      * pixmap.
      */
 
-    double ratio          = qApp->devicePixelRatio();
+    qreal dpr             = widget->devicePixelRatio();
 
-    QRect  scaledDrawRect = QRectF(ratio * drawRect.x(),
-                                   ratio * drawRect.y(),
-                                   ratio * drawRect.width(),
-                                   ratio * drawRect.height()).toRect();
+    QRect  scaledDrawRect = QRectF(dpr * drawRect.x(),
+                                   dpr * drawRect.y(),
+                                   dpr * drawRect.width(),
+                                   dpr * drawRect.height()).toRect();
 
     // scale "as if" scaling to whole image, but clip output to our exposed region
 
-    QSize scaledCompleteSize = QSizeF(ratio * completeSize.width(),
-                                      ratio * completeSize.height()).toSize();
+    QSize scaledCompleteSize = QSizeF(dpr * completeSize.width(),
+                                      dpr * completeSize.height()).toSize();
     DImg scaledImage         = d->image.smoothScaleClipped(scaledCompleteSize.width(),
                                                            scaledCompleteSize.height(),
                                                            scaledDrawRect.x(),
@@ -162,3 +153,5 @@ void ImagePreviewItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*
 }
 
 } // namespace Digikam
+
+#include "moc_imagepreviewitem.cpp"
