@@ -7,7 +7,7 @@
  * Description : image region widget item for image editor.
  *
  * SPDX-FileCopyrightText: 2013-2014 by Yiou Wang <geow812 at gmail dot com>
- * SPDX-FileCopyrightText: 2013-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -70,6 +70,8 @@ ImageRegionItem::ImageRegionItem(ImageRegionWidget* const widget, bool paintExtr
     dd->view        = widget;
     dd->iface       = new ImageIface;
     dd->paintExtras = paintExtras;
+
+    setDisplayWidget(widget);
     setAcceptHoverEvents(true);
     setImage(dd->iface->original() ? dd->iface->original()->copy() : DImg());
 }
@@ -334,3 +336,5 @@ void ImageRegionItem::hoverLeaveEvent(QGraphicsSceneHoverEvent*)
 }
 
 } // namespace Digikam
+
+#include "moc_imageregionitem.cpp"
