@@ -7,7 +7,7 @@
  * Description : USB Mass Storage camera interface
  *
  * SPDX-FileCopyrightText: 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -20,7 +20,6 @@
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
-#include <QStringList>
 #include <QDirIterator>
 #include <QTextDocument>
 #include <QtGlobal>
@@ -164,6 +163,7 @@ bool UMSCamera::getFolders(const QString& folder)
 
     QStringList subFolderList;
 
+    // cppcheck-suppress knownConditionTrueFalse
     while (it.hasNext() && !m_cancel)
     {
         subFolderList << it.next();
@@ -687,3 +687,5 @@ void UMSCamera::getUUIDFromSolid()
 }
 
 } // namespace Digikam
+
+#include "moc_umscamera.cpp"
