@@ -6,7 +6,7 @@
  * Date        : 2007-04-11
  * Description : light table thumbs bar
  *
- * SPDX-FileCopyrightText: 2007-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -67,7 +67,7 @@ class Q_DECL_HIDDEN LightTableItemListModel : public ItemListModel
 
 public:
 
-    explicit LightTableItemListModel(QObject* const parent = nullptr)
+    explicit LightTableItemListModel(QWidget* const parent)
         : ItemListModel(parent),
           m_exclusive  (false)
     {
@@ -154,19 +154,13 @@ class Q_DECL_HIDDEN LightTableThumbBar::Private
 
 public:
 
-    explicit Private()
-      : navigateByPair  (false),
-        imageInfoModel  (nullptr),
-        imageFilterModel(nullptr),
-        dragDropHandler (nullptr)
-    {
-    }
+    Private() = default;
 
-    bool                     navigateByPair;
+    bool                     navigateByPair     = false;
 
-    LightTableItemListModel* imageInfoModel;
-    ItemFilterModel*         imageFilterModel;
-    ItemDragDropHandler*     dragDropHandler;
+    LightTableItemListModel* imageInfoModel     = nullptr;
+    ItemFilterModel*         imageFilterModel   = nullptr;
+    ItemDragDropHandler*     dragDropHandler    = nullptr;
 };
 
 LightTableThumbBar::LightTableThumbBar(QWidget* const parent)
@@ -247,6 +241,7 @@ void LightTableThumbBar::slotDockLocationChanged(Qt::DockWidgetArea area)
 void LightTableThumbBar::clear()
 {
     d->imageInfoModel->clearItemInfos();
+
     Q_EMIT signalContentChanged();
 }
 
@@ -487,3 +482,5 @@ void LightTableThumbBar::slotSetupChanged()
 } // namespace Digikam
 
 #include "lighttablethumbbar.moc"
+
+#include "moc_lighttablethumbbar.cpp"
