@@ -6,7 +6,7 @@
  * Date        : 2013-08-19
  * Description : image quality sorter maintenance tool
  *
- * SPDX-FileCopyrightText: 2013-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013-2014 by Gowtham Ashok <gwty93 at gmail dot com>
  * SPDX-FileCopyrightText: 2021-2022 by Phuoc Khanh Le <phuockhanhnk94 at gmail dot com>
  *
@@ -120,11 +120,23 @@ void ImageQualitySorter::slotStart()
 
         if      ((*it)->type() == Album::PHYSICAL)
         {
-            aPaths = CoreDbAccess().db()->getItemURLsInAlbum((*it)->id());
+            Q_FOREACH (const QString& path, CoreDbAccess().db()->getItemURLsInAlbum((*it)->id()))
+            {
+                if (!aPaths.contains(path))
+                {
+                    aPaths << path;
+                }
+            }
         }
         else if ((*it)->type() == Album::TAG)
         {
-            aPaths = CoreDbAccess().db()->getItemURLsInTag((*it)->id());
+            Q_FOREACH (const QString& path, CoreDbAccess().db()->getItemURLsInTag((*it)->id()))
+            {
+                if (!aPaths.contains(path))
+                {
+                    aPaths << path;
+                }
+            }
         }
 
         if (d->mode == NonAssignedItems)
@@ -163,3 +175,5 @@ void ImageQualitySorter::slotAdvance(const QImage& img)
 }
 
 } // namespace Digikam
+
+#include "moc_imagequalitysorter.cpp"
