@@ -6,19 +6,10 @@
  * Date        : 2012-01-31
  * Description : maintenance manager
  *
- * Copyright (C) 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2012      by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012      by Andi Clemens <andi dot clemens at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -45,6 +36,7 @@
 #include "thumbsgenerator.h"
 #include "fingerprintsgenerator.h"
 #include "duplicatesfinder.h"
+#include "autotagsassignment.h"
 #include "imagequalitysorter.h"
 #include "metadatasynchronizer.h"
 #include "dnotificationwrapper.h"
@@ -59,33 +51,25 @@ class Q_DECL_HIDDEN MaintenanceMngr::Private
 {
 public:
 
-    explicit Private()
-      : running(false),
-        newItemsFinder(nullptr),
-        thumbsGenerator(nullptr),
-        fingerPrintsGenerator(nullptr),
-        duplicatesFinder(nullptr),
-        metadataSynchronizer(nullptr),
-        imageQualitySorter(nullptr),
-        facesDetector(nullptr),
-        databaseCleaner(nullptr)
-    {
-    }
+    Private() = default;
 
-    bool                   running;
+public:
+
+    bool                   running               = false;
 
     QElapsedTimer          duration;
 
     MaintenanceSettings    settings;
 
-    NewItemsFinder*        newItemsFinder;
-    ThumbsGenerator*       thumbsGenerator;
-    FingerPrintsGenerator* fingerPrintsGenerator;
-    DuplicatesFinder*      duplicatesFinder;
-    MetadataSynchronizer*  metadataSynchronizer;
-    ImageQualitySorter*    imageQualitySorter;
-    FacesDetector*         facesDetector;
-    DbCleaner*             databaseCleaner;
+    NewItemsFinder*        newItemsFinder        = nullptr;
+    ThumbsGenerator*       thumbsGenerator       = nullptr;
+    FingerPrintsGenerator* fingerPrintsGenerator = nullptr;
+    DuplicatesFinder*      duplicatesFinder      = nullptr;
+    MetadataSynchronizer*  metadataSynchronizer  = nullptr;
+    AutotagsAssignment*    autotagsAssignment    = nullptr;
+    ImageQualitySorter*    imageQualitySorter    = nullptr;
+    FacesDetector*         facesDetector         = nullptr;
+    DbCleaner*             databaseCleaner       = nullptr;
 };
 
 MaintenanceMngr::MaintenanceMngr(QObject* const parent)
@@ -167,10 +151,15 @@ void MaintenanceMngr::slotToolCompleted(ProgressItem* tool)
         d->facesDetector = nullptr;
         stage7();
     }
+    else if(tool == dynamic_cast<ProgressItem*>(d->autotagsAssignment))
+    {
+        d->autotagsAssignment = nullptr;
+        stage8();
+    }
    else if (tool == dynamic_cast<ProgressItem*>(d->imageQualitySorter))
     {
         d->imageQualitySorter = nullptr;
-        stage8();
+        stage9();
     }
     else if (tool == dynamic_cast<ProgressItem*>(d->metadataSynchronizer))
     {
@@ -188,7 +177,8 @@ void MaintenanceMngr::slotToolCanceled(ProgressItem* tool)
         (tool == dynamic_cast<ProgressItem*>(d->databaseCleaner))       ||
         (tool == dynamic_cast<ProgressItem*>(d->facesDetector))         ||
         (tool == dynamic_cast<ProgressItem*>(d->imageQualitySorter))    ||
-        (tool == dynamic_cast<ProgressItem*>(d->metadataSynchronizer)))
+        (tool == dynamic_cast<ProgressItem*>(d->metadataSynchronizer))  ||
+        (tool == dynamic_cast<ProgressItem*>(d->autotagsAssignment)))
     {
         cancel();
     }
@@ -208,7 +198,7 @@ void MaintenanceMngr::stage1()
         {
             QStringList paths;
 
-            foreach (Album* const a, d->settings.albums)
+            Q_FOREACH (Album* const a, d->settings.albums)
             {
                 PAlbum* const palbum = dynamic_cast<PAlbum*>(a);
 
@@ -336,7 +326,28 @@ void MaintenanceMngr::stage7()
 {
     qCDebug(DIGIKAM_GENERAL_LOG) << "stage7";
 
-    if (d->settings.qualitySort && d->settings.quality.enableSorter)
+    if (d->settings.autotagsAssignment)
+    {
+        AlbumList list;
+        list << d->settings.albums;
+        list << d->settings.tags;
+
+        d->autotagsAssignment = new AutotagsAssignment((AutotagsAssignment::AutotagsAssignmentScanMode)d->settings.autotaggingScanMode, list, d->settings.modelSelectionMode);
+        d->autotagsAssignment->setNotificationEnabled(false);
+        d->autotagsAssignment->setUseMultiCoreCPU(d->settings.useMutiCoreCPU);
+        d->autotagsAssignment->start();
+    }
+    else
+    {
+        stage8();
+    }
+}
+
+void MaintenanceMngr::stage8()
+{
+    qCDebug(DIGIKAM_GENERAL_LOG) << "stage8";
+
+    if (d->settings.qualitySort)
     {
         AlbumList list;
         list << d->settings.albums;
@@ -349,13 +360,13 @@ void MaintenanceMngr::stage7()
     }
     else
     {
-        stage8();
+        stage9();
     }
 }
 
-void MaintenanceMngr::stage8()
+void MaintenanceMngr::stage9()
 {
-    qCDebug(DIGIKAM_GENERAL_LOG) << "stage8";
+    qCDebug(DIGIKAM_GENERAL_LOG) << "stage9";
 
     if (d->settings.metadataSync)
     {
@@ -384,13 +395,15 @@ void MaintenanceMngr::done()
                          i18n("All operations are done.\nDuration: %1", t.toString()),
                          qApp->activeWindow(), i18n("digiKam Maintenance"));
 
-    emit signalComplete();
+    Q_EMIT signalComplete();
 }
 
 void MaintenanceMngr::cancel()
 {
     d->running = false;
-    emit signalComplete();
+    Q_EMIT signalComplete();
 }
 
 } // namespace Digikam
+
+#include "moc_maintenancemngr.cpp"
