@@ -6,18 +6,9 @@
  * Date        : 2008-11-24
  * Description : Batch Tool Container.
  *
- * Copyright (C) 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -25,13 +16,12 @@
 
 // Qt includes
 
-#include <QDataStream>
-#include <QDateTime>
-#include <QFileInfo>
-#include <QPolygon>
-#include <QWidget>
 #include <QLabel>
-#include <QUuid>
+#include <QWidget>
+#include <QPolygon>
+#include <QFileInfo>
+#include <QDateTime>
+#include <QDataStream>
 #include <QScopedPointer>
 
 // KDE includes
@@ -41,14 +31,13 @@
 // Local includes
 
 #include "drawdecoder.h"
+#include "dimgloader.h"
 #include "digikam_debug.h"
 #include "dimgbuiltinfilter.h"
 #include "dimgloaderobserver.h"
 #include "dimgthreadedfilter.h"
 #include "filereadwritelock.h"
 #include "batchtoolutils.h"
-#include "jpegsettings.h"
-#include "pngsettings.h"
 #include "dmetadata.h"
 #include "dpluginbqm.h"
 
@@ -118,7 +107,7 @@ public:
 
     explicit BatchToolObserver(BatchTool::Private* const priv)
         : DImgLoaderObserver(),
-          d(priv)
+          d                 (priv)
     {
     }
 
@@ -191,34 +180,54 @@ QString BatchTool::toolGroupToString() const
     switch (toolGroup())
     {
         case BaseTool:
+        {
             return i18nc("@title: tool group", "Base");
+        }
 
         case CustomTool:
+        {
             return i18nc("@title: tool group", "Custom");
+        }
 
         case ColorTool:
+        {
             return i18nc("@title: tool group", "Colors");
+        }
 
         case EnhanceTool:
+        {
             return i18nc("@title: tool group", "Enhance");
+        }
 
         case TransformTool:
+        {
             return i18nc("@title: tool group", "Transform");
+        }
 
         case DecorateTool:
+        {
             return i18nc("@title: tool group", "Decorate");
+        }
 
         case FiltersTool:
+        {
             return i18nc("@title: tool group", "Filters");
+        }
 
         case ConvertTool:
+        {
             return i18nc("@title: tool group", "Convert");
+        }
 
         case MetadataTool:
+        {
             return i18nc("@title: tool group", "Metadata");
+        }
 
         default:
+        {
             break;
+        }
     }
 
     return i18nc("@title: tool group", "Invalid");
@@ -267,13 +276,14 @@ void BatchTool::slotResetSettingsToDefault()
 void BatchTool::slotSettingsChanged(const BatchToolSettings& settings)
 {
     setSettings(settings);
-    emit signalSettingsChanged(d->settings);
+    Q_EMIT signalSettingsChanged(d->settings);
 }
 
 void BatchTool::setSettings(const BatchToolSettings& settings)
 {
     d->settings = settings;
-    emit signalAssignSettings2Widget();
+
+    Q_EMIT signalAssignSettings2Widget();
 }
 
 void BatchTool::setInputUrl(const QUrl& inputUrl)
@@ -427,9 +437,8 @@ void BatchTool::setOutputUrlFromInputUrl()
         suffix = fi.suffix();
     }
 
-    QString random = QUuid::createUuid().toString().mid(1, 8);
-    SafeTemporaryFile temp(path + QLatin1String("/BatchTool-XXXXXX-") +
-                           random + QLatin1String(".digikamtempfile.") + suffix);
+    SafeTemporaryFile temp(path + QLatin1String("/BatchTool-XXXXXX"
+                                                ".digikamtempfile.") + suffix);
 
     temp.setAutoRemove(false);
     temp.open();
@@ -493,12 +502,12 @@ bool BatchTool::savefromDImg() const
 
         if      (detectedFormat == DImg::JPEG)
         {
-            d->image.setAttribute(QLatin1String("quality"),     JPEGSettings::convertCompressionForLibJpeg(ioFileSettings().JPEGCompression));
+            d->image.setAttribute(QLatin1String("quality"),     DImgLoader::convertCompressionForLibJpeg(ioFileSettings().JPEGCompression));
             d->image.setAttribute(QLatin1String("subsampling"), ioFileSettings().JPEGSubSampling);
         }
         else if (detectedFormat == DImg::PNG)
         {
-            d->image.setAttribute(QLatin1String("quality"),     PNGSettings::convertCompressionForLibPng(ioFileSettings().PNGCompression));
+            d->image.setAttribute(QLatin1String("quality"),     DImgLoader::convertCompressionForLibPng(ioFileSettings().PNGCompression));
         }
         else if (detectedFormat == DImg::TIFF)
         {
@@ -517,6 +526,7 @@ bool BatchTool::savefromDImg() const
 
         d->image.prepareMetadataToSave(outputUrl().toLocalFile(), DImg::formatToMimeType(detectedFormat), resetOrientation);
         bool b = d->image.save(outputUrl().toLocalFile(), detectedFormat, d->observer);
+
         return b;
     }
 
@@ -539,8 +549,9 @@ bool BatchTool::apply()
     qCDebug(DIGIKAM_GENERAL_LOG) << "Tool:       " << toolTitle();
     qCDebug(DIGIKAM_GENERAL_LOG) << "Input url:  " << inputUrl();
     qCDebug(DIGIKAM_GENERAL_LOG) << "Output url: " << outputUrl();
-    //qCDebug(DIGIKAM_GENERAL_LOG) << "Settings:   ";
-
+/*
+    qCDebug(DIGIKAM_GENERAL_LOG) << "Settings:   ";
+*/
     BatchToolSettings prm = settings();
 
     for (BatchToolSettings::const_iterator it = prm.constBegin() ; it != prm.constEnd() ; ++it)
@@ -637,3 +648,5 @@ void BatchTool::registerSettingsWidget()
 }
 
 } // namespace Digikam
+
+#include "moc_batchtool.cpp"
