@@ -6,7 +6,7 @@
  * Date        : 2009-02-13
  * Description : tabbed queue items list.
  *
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -16,7 +16,6 @@
 
 // Qt includes
 
-#include <QTabBar>
 #include <QApplication>
 #include <QIcon>
 
@@ -605,3 +604,5 @@ void QueuePool::applySettings()
 }
 
 } // namespace Digikam
+
+#include "moc_queuepool.cpp"
