@@ -6,7 +6,7 @@
  * Date        : 2009-02-21
  * Description : a view to show Queue Settings.
  *
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -20,7 +20,6 @@
 #include <QGroupBox>
 #include <QLabel>
 #include <QRadioButton>
-#include <QScrollArea>
 #include <QCheckBox>
 #include <QTimer>
 #include <QTreeWidget>
@@ -787,3 +786,5 @@ void QueueSettingsView::slotSettingsChanged()
 }
 
 } // namespace Digikam
+
+#include "moc_queuesettingsview.cpp"
