@@ -6,7 +6,7 @@
  * Date        : 2008-11-24
  * Description : Available batch tools list.
  *
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -18,10 +18,8 @@
 
 #include <QDrag>
 #include <QHeaderView>
-#include <QMap>
 #include <QMimeData>
 #include <QPainter>
-#include <QPixmap>
 #include <QAction>
 #include <QMenu>
 #include <QIcon>
@@ -410,3 +408,5 @@ void ToolsListView::slotContextMenu()
 }
 
 } // namespace Digikam
+
+#include "moc_toolslistview.cpp"
