@@ -6,7 +6,7 @@
  * Date        : 2012-12-18
  * Description : Customized Workflow Settings list.
  *
- * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -19,10 +19,8 @@
 #include <QApplication>
 #include <QDrag>
 #include <QHeaderView>
-#include <QMap>
 #include <QMimeData>
 #include <QPainter>
-#include <QPixmap>
 #include <QMenu>
 #include <QAction>
 #include <QIcon>
@@ -50,9 +48,7 @@ WorkflowItem::WorkflowItem(WorkflowList* const parent, const QString& title)
     Workflow q = WorkflowManager::instance()->findByTitle(title);
 
     setIcon(0, QIcon::fromTheme(QLatin1String("step")));
-    setText(0, title);
-    setText(1, QString::number(q.aTools.count()));
-    setText(2, q.desc);
+    setItem(title, q.desc, q.aTools.count());
 }
 
 WorkflowItem::~WorkflowItem()
@@ -69,6 +65,24 @@ int WorkflowItem::count() const
     return text(1).toInt();
 }
 
+void WorkflowItem::setItem(const QString& title, const QString& desc, int count)
+{
+    if (!title.isEmpty())
+    {
+        setText(0, title);
+    }
+
+    if (!desc.isEmpty())
+    {
+        setText(2, desc);
+    }
+
+    if (count > 0)
+    {
+        setText(1, QString::number(count));
+    }
+}
+
 // ---------------------------------------------------------------------------
 
 WorkflowList::WorkflowList(QWidget* const parent)
@@ -303,14 +317,24 @@ void WorkflowList::slotContextMenu()
             mngr->remove(wfOld);
             mngr->insert(wfNew);
             mngr->save();
-            removeItemWidget(item, 0);
-            delete item;
 
+            if (wfOld.title != wfNew.title)
+            {
+                removeItemWidget(item, 0);
+                delete item;
+            }
+            else
+            {
+                item->setItem(QString(), wfNew.desc);
+            }
         }
     }
     else if (choice == updAction)
     {
         Q_EMIT signalUpdateQueueSettings(item->title());
+
+        Workflow q = WorkflowManager::instance()->findByTitle(item->title());
+        item->setItem(QString(), QString(), q.aTools.count());
     }
     else if (choice == delAction)
     {
@@ -349,3 +373,5 @@ void WorkflowList::slotAssignQueueSettings()
 }
 
 } // namespace Digikam
+
+#include "moc_workflowlist.cpp"
