@@ -6,7 +6,7 @@
  * Date        : 2012-12-18
  * Description : Customized Workflow Settings list.
  *
- * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -44,6 +44,9 @@ public:
 
     QString title()                                            const;
     int     count()                                            const;
+    void    setItem(const QString& title = QString(),
+                    const QString& desc = QString(),
+                    int count = 0);
 
 private:
 
