@@ -16,8 +16,6 @@
 
 // Qt includes
 
-#include <QAbstractListModel>
-#include <QItemDelegate>
 #include <QLineEdit>
 #include <QLinearGradient>
 #include <QListView>
@@ -37,7 +35,6 @@
 
 #include "digikam_debug.h"
 #include "digikam_globals.h"
-#include "ratingwidget.h"
 
 namespace Digikam
 {
@@ -331,7 +328,7 @@ void RatingComboBoxWidget::paintEvent(QPaintEvent* e)
         QPainter p(this);
 
         QPixmap pix = starPixmap();
-        int width = pix.width();
+        int width   = regPixmapWidth();
         p.drawPixmap(0, 0, pix);
 
         // draw red cross
@@ -352,7 +349,7 @@ void RatingComboBoxWidget::paintEvent(QPaintEvent* e)
             for (int i = 0 ; i < RatingMax ; ++i)
             {
                 p.drawPixmap(x, 0, pix);
-                x += pix.width();
+                x += regPixmapWidth();
             }
         }
         else
@@ -467,3 +464,5 @@ void RatingComboBox::ratingWidgetChanged(int rv)
 }
 
 } // namespace Digikam
+
+#include "moc_ratingsearchutilities.cpp"
