@@ -7,7 +7,7 @@
  * Description : User interface for searches
  *
  * SPDX-FileCopyrightText: 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -78,6 +78,9 @@ void SearchField::setup(QGridLayout* const layout, int line)
     connect(m_clearButton, SIGNAL(clicked()),
             this, SLOT(clearButtonClicked()));
 
+    connect(m_clearButton, SIGNAL(visibleChanged(bool)),
+            m_clearButton, SLOT(slotPixmapEnabled(bool)));
+
     layout->addWidget(m_clearButton, line, 7);
 }
 
@@ -191,3 +194,5 @@ void SearchField::setValidValueState(bool valueIsValid)
 }
 
 } // namespace Digikam
+
+#include "moc_searchfields.cpp"
