@@ -6,19 +6,10 @@
  * Date        : 2000-12-05
  * Description : helper class used to modify search albums in views
  *
- * Copyright (C) 2009-2010 by Johannes Wienke <languitar at semipol dot de>
- * Copyright (C) 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2010 by Johannes Wienke <languitar at semipol dot de>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -36,7 +27,6 @@
 // Local includes
 
 #include "digikam_debug.h"
-#include "album.h"
 #include "albummanager.h"
 #include "similaritydbaccess.h"
 #include "similaritydb.h"
@@ -81,7 +71,7 @@ void SearchModificationHelper::slotSearchDelete(SAlbum* searchAlbum)
 
     // Make sure that a complicated search is not deleted accidentally
 
-    int result = QMessageBox::warning(d->dialogParent, i18n("Delete Search?"),
+    int result = QMessageBox::warning(d->dialogParent, i18nc("@title:window", "Delete Search?"),
                                       i18n("Are you sure you want to "
                                            "delete the selected search "
                                            "\"%1\"?", searchAlbum->displayTitle()),
@@ -123,7 +113,7 @@ bool SearchModificationHelper::checkName(QString& name)
                               "Please enter a new name:" );
         bool ok;
         QString newTitle = QInputDialog::getText(d->dialogParent,
-                                                 i18n("Name exists"),
+                                                 i18nc("@title:window", "Name Exists"),
                                                  label,
                                                  QLineEdit::Normal,
                                                  name,
@@ -151,7 +141,7 @@ void SearchModificationHelper::slotSearchRename(SAlbum* searchAlbum)
     QString oldName(searchAlbum->title());
     bool    ok;
     QString name = QInputDialog::getText(d->dialogParent,
-                                         i18n("Rename Album (%1)", oldName),
+                                         i18nc("@title:window", "Rename Album (%1)", oldName),
                                          i18n("Enter new album name:"),
                                          QLineEdit::Normal,
                                          oldName,
@@ -426,3 +416,5 @@ void SearchModificationHelper::slotCreateFuzzySearchFromImage(const QString& pro
 }
 
 } // namespace Digikam
+
+#include "moc_searchmodificationhelper.cpp"
