@@ -6,18 +6,9 @@
  * Date        : 2008-02-26
  * Description : Upper widget in the search sidebar
  *
- * Copyright (C) 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -72,7 +63,8 @@ public:
     {
         KSharedConfig::Ptr config = KSharedConfig::openConfig();
         KConfigGroup group        = config->group(QLatin1String("KeywordSearchEdit Settings"));
-        m_autoSearch              = group.readEntry(QLatin1String("Autostart Search"), true);
+        m_autoSearch              = group.readEntry(QLatin1String("Autostart Search"), false);
+        m_i18nSearch              = i18n("(Advanced Search)");
     }
 
     void showAdvancedSearch(bool hasAdvanced)
@@ -136,19 +128,29 @@ public:
             p.setColor(QPalette::Text, p.color(QPalette::Disabled, QPalette::Text));
             setPalette(p);
 
-            setText(i18n("(Advanced Search)"));
+            setText(m_i18nSearch);
         }
         else
         {
             setPalette(QPalette());
 
-            if (text() == i18n("(Advanced Search)"))
+            if (text() == m_i18nSearch)
             {
                 setText(QString());
             }
         }
     }
 
+    QString getText() const
+    {
+        if (text() == m_i18nSearch)
+        {
+            return QString();
+        }
+
+        return text();
+    }
+
 public Q_SLOTS:
 
     void toggleAutoSearch()
@@ -162,8 +164,9 @@ public Q_SLOTS:
 
 protected:
 
-    bool m_hasAdvanced;
-    bool m_autoSearch;
+    bool    m_hasAdvanced;
+    bool    m_autoSearch;
+    QString m_i18nSearch;
 };
 
 // -------------------------------------------------------------------------
@@ -179,7 +182,8 @@ public:
         editAdvancedWidget      (nullptr),
         lowerArea               (nullptr),
         keywordEdit             (nullptr),
-        advancedEditLabel       (nullptr),
+        advancedNewSearch       (nullptr),
+        advancedEditSearch      (nullptr),
         saveNameEdit            (nullptr),
         saveButton              (nullptr),
         storedKeywordEditName   (nullptr),
@@ -201,7 +205,8 @@ public:
     QStackedLayout*     lowerArea;
 
     KeywordLineEdit*    keywordEdit;
-    QPushButton*        advancedEditLabel;
+    QPushButton*        advancedNewSearch;
+    QPushButton*        advancedEditSearch;
 
     QLineEdit*          saveNameEdit;
     QToolButton*        saveButton;
@@ -226,7 +231,8 @@ SearchTabHeader::SearchTabHeader(QWidget* const parent)
     : QWidget(parent),
       d      (new Private)
 {
-    const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
 
     QVBoxLayout* const mainLayout = new QVBoxLayout(this);
     mainLayout->setContentsMargins(QMargins());
@@ -260,11 +266,13 @@ SearchTabHeader::SearchTabHeader(QWidget* const parent)
     d->keywordEdit->setClearButtonEnabled(true);
     d->keywordEdit->setPlaceholderText(i18n("Enter keywords here..."));
 
-    d->advancedEditLabel      = new QPushButton(i18n("Advanced Search..."), this);
+    d->advancedNewSearch      = new QPushButton(i18n("New Advanced Search..."), this);
+    d->advancedEditSearch     = new QPushButton(i18n("Edit Current Search..."), this);
 
-    grid1->addWidget(searchLabel,          0, 0, 1, 1);
-    grid1->addWidget(d->keywordEdit,       0, 1, 1, 1);
-    grid1->addWidget(d->advancedEditLabel, 1, 0, 1, 2);
+    grid1->addWidget(searchLabel,           0, 0, 1, 1);
+    grid1->addWidget(d->keywordEdit,        0, 1, 1, 1);
+    grid1->addWidget(d->advancedNewSearch,  1, 0, 1, 2);
+    grid1->addWidget(d->advancedEditSearch, 2, 0, 1, 2);
     grid1->setContentsMargins(spacing, spacing, spacing, spacing);
     grid1->setSpacing(spacing);
 
@@ -303,7 +311,16 @@ SearchTabHeader::SearchTabHeader(QWidget* const parent)
 
     QVBoxLayout* const vbox1 = new QVBoxLayout;
     d->storedKeywordEditName = new DAdjustableLabel(this);
-    d->storedKeywordEditName->setElideMode(Qt::ElideRight);
+
+    if (layoutDirection() == Qt::RightToLeft)
+    {
+        d->storedKeywordEditName->setElideMode(Qt::ElideRight);
+    }
+    else
+    {
+        d->storedKeywordEditName->setElideMode(Qt::ElideLeft);
+    }
+
     d->storedKeywordEdit     = new QLineEdit(this);
 
     vbox1->addWidget(d->storedKeywordEditName);
@@ -322,7 +339,16 @@ SearchTabHeader::SearchTabHeader(QWidget* const parent)
     QVBoxLayout* const vbox2   = new QVBoxLayout;
 
     d->storedAdvancedEditName  = new DAdjustableLabel(this);
-    d->storedAdvancedEditName->setElideMode(Qt::ElideRight);
+
+    if (layoutDirection() == Qt::RightToLeft)
+    {
+        d->storedAdvancedEditName->setElideMode(Qt::ElideRight);
+    }
+    else
+    {
+        d->storedAdvancedEditName->setElideMode(Qt::ElideLeft);
+    }
+
     d->storedAdvancedEditLabel = new QPushButton(i18n("Edit..."), this);
 
     vbox2->addWidget(d->storedAdvancedEditName);
@@ -352,8 +378,11 @@ SearchTabHeader::SearchTabHeader(QWidget* const parent)
     connect(d->keywordEdit, SIGNAL(editingFinished()),
             this, SLOT(keywordChanged()));
 
-    connect(d->advancedEditLabel, SIGNAL(clicked()),
-            this, SLOT(editCurrentAdvancedSearch()));
+    connect(d->advancedNewSearch, SIGNAL(clicked()),
+            this, SLOT(newAdvancedSearch()));
+
+    connect(d->advancedEditSearch, SIGNAL(clicked()),
+            this, SLOT(slotEditCurrentSearch()));
 
     connect(d->saveNameEdit, SIGNAL(returnPressed()),
             this, SLOT(saveSearch()));
@@ -469,8 +498,6 @@ void SearchTabHeader::editSearch(SAlbum* album)
 void SearchTabHeader::newKeywordSearch()
 {
     d->keywordEdit->clear();
-    QString keywords = d->keywordEdit->text();
-    setCurrentSearch(DatabaseSearch::KeywordSearch, queryFromKeywords(keywords));
     d->keywordEdit->setFocus();
 }
 
@@ -484,12 +511,14 @@ void SearchTabHeader::newAdvancedSearch()
 
 void SearchTabHeader::keywordChanged()
 {
-    QString keywords = d->keywordEdit->text();
+    QString keywords = d->keywordEdit->getText();
+
     qCDebug(DIGIKAM_GENERAL_LOG) << "keywords changed to '" << keywords << "'";
 
     if ((d->oldKeywordContent == keywords) || (keywords.trimmed().isEmpty()))
     {
         qCDebug(DIGIKAM_GENERAL_LOG) << "same keywords as before, ignoring...";
+
         return;
     }
     else
@@ -509,7 +538,7 @@ void SearchTabHeader::keywordChangedTimer()
     }
 }
 
-void SearchTabHeader::editCurrentAdvancedSearch()
+void SearchTabHeader::slotEditCurrentSearch()
 {
     SAlbum* const album        = AlbumManager::instance()->findSAlbum(SAlbum::getTemporaryTitle(DatabaseSearch::AdvancedSearch));
     SearchWindow* const window = searchWindow();
@@ -554,7 +583,7 @@ void SearchTabHeader::saveSearch()
                                 "Please enter a new name:");
         bool ok;
         QString newTitle = QInputDialog::getText(this,
-                                                 i18n("Name exists"),
+                                                 i18nc("@title:window", "Name Exists"),
                                                  label,
                                                  QLineEdit::Normal,
                                                  name,
@@ -571,7 +600,7 @@ void SearchTabHeader::saveSearch()
 
     SAlbum* newAlbum = AlbumManager::instance()->createSAlbum(name, d->currentAlbum->searchType(),
                                                               d->currentAlbum->query());
-    emit searchShallBeSelected(QList<Album*>() << newAlbum);
+    Q_EMIT searchShallBeSelected(QList<Album*>() << newAlbum);
 }
 
 void SearchTabHeader::storedKeywordChanged()
@@ -590,7 +619,7 @@ void SearchTabHeader::storedKeywordChanged()
     if (d->currentAlbum)
     {
         AlbumManager::instance()->updateSAlbum(d->currentAlbum, queryFromKeywords(keywords));
-        emit searchShallBeSelected(QList<Album*>() << d->currentAlbum);
+        Q_EMIT searchShallBeSelected(QList<Album*>() << d->currentAlbum);
     }
 }
 
@@ -626,7 +655,7 @@ void SearchTabHeader::advancedSearchEdited(int id, const QString& query)
         if (album)
         {
             AlbumManager::instance()->updateSAlbum(album, query, album->title(), type);
-            emit searchShallBeSelected(QList<Album*>() << album);
+            Q_EMIT searchShallBeSelected(QList<Album*>() << album);
         }
     }
 }
@@ -649,7 +678,7 @@ void SearchTabHeader::setCurrentSearch(DatabaseSearch::Type type, const QString&
 
     if (selectCurrentAlbum)
     {
-        emit searchShallBeSelected(QList<Album*>() << album);
+        Q_EMIT searchShallBeSelected(QList<Album*>() << album);
     }
 }
 
@@ -675,3 +704,5 @@ QString SearchTabHeader::keywordsFromQuery(const QString& query) const
 } // namespace Digikam
 
 #include "searchtabheader.moc"
+
+#include "moc_searchtabheader.cpp"
