@@ -6,19 +6,10 @@
  * Date        : 2003-02-01
  * Description : album view configuration setup tab
  *
- * Copyright (C) 2003-2004 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2003-2004 by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -78,12 +69,15 @@ public:
         iconShowOverlaysBox         (nullptr),
         iconShowFullscreenBox       (nullptr),
         iconShowRatingBox           (nullptr),
+        iconShowPickLabelBox        (nullptr),
+        iconShowColorLabelBox       (nullptr),
         iconShowFormatBox           (nullptr),
         iconShowCoordinatesBox      (nullptr),
         previewFastPreview          (nullptr),
         previewFullView             (nullptr),
         previewRawMode              (nullptr),
         previewConvertToEightBit    (nullptr),
+        previewScaleFitToWindow     (nullptr),
         previewShowIcons            (nullptr),
         showFolderTreeViewItemsCount(nullptr),
         largeThumbsBox              (nullptr),
@@ -114,12 +108,15 @@ public:
     QCheckBox*          iconShowOverlaysBox;
     QCheckBox*          iconShowFullscreenBox;
     QCheckBox*          iconShowRatingBox;
+    QCheckBox*          iconShowPickLabelBox;
+    QCheckBox*          iconShowColorLabelBox;
     QCheckBox*          iconShowFormatBox;
     QCheckBox*          iconShowCoordinatesBox;
     QRadioButton*       previewFastPreview;
     QRadioButton*       previewFullView;
     QComboBox*          previewRawMode;
     QCheckBox*          previewConvertToEightBit;
+    QCheckBox*          previewScaleFitToWindow;
     QCheckBox*          previewShowIcons;
     QCheckBox*          showFolderTreeViewItemsCount;
     QCheckBox*          largeThumbsBox;
@@ -148,7 +145,8 @@ SetupAlbumView::SetupAlbumView(QWidget* const parent)
     setWidgetResizable(true);
 
     QWidget* const iwpanel     = new QWidget(d->tab);
-    const int spacing          = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing          = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
 
     // --------------------------------------------------------
 
@@ -196,6 +194,14 @@ SetupAlbumView::SetupAlbumView(QWidget* const parent)
     d->iconShowRatingBox->setWhatsThis(i18n("Set this option to show the digiKam rating "
                                             "below the image thumbnail."));
 
+    d->iconShowPickLabelBox    = new QCheckBox(i18n("Show digiKam &pick label"), iwpanel);
+    d->iconShowPickLabelBox->setWhatsThis(i18n("Set this option to show the digiKam pick label "
+                                            "below the image thumbnail."));
+
+    d->iconShowColorLabelBox   = new QCheckBox(i18n("Show digiKam color &label"), iwpanel);
+    d->iconShowColorLabelBox->setWhatsThis(i18n("Set this option to show the digiKam color label "
+                                            "as a border around the thumbnail."));
+
     d->iconShowOverlaysBox     = new QCheckBox(i18n("Show rotation overlay buttons"), iwpanel);
     d->iconShowOverlaysBox->setWhatsThis(i18n("Set this option to show overlay buttons over "
                                               "the image thumbnail to be able to process left or right image rotation."));
@@ -209,9 +215,10 @@ SetupAlbumView::SetupAlbumView(QWidget* const parent)
 
     QLabel* leftClickLabel     = new QLabel(i18n("Thumbnail click action:"), iwpanel);
     d->leftClickActionComboBox = new QComboBox(iwpanel);
-    d->leftClickActionComboBox->addItem(i18n("Show preview"),                  ApplicationSettings::ShowPreview);
-    d->leftClickActionComboBox->addItem(i18n("Start image editor"),            ApplicationSettings::StartEditor);
-    d->leftClickActionComboBox->addItem(i18n("Open With Default Application"), ApplicationSettings::OpenDefault);
+    d->leftClickActionComboBox->addItem(i18n("Show Preview"),                  ApplicationSettings::ShowPreview);
+    d->leftClickActionComboBox->addItem(i18n("Start Image Editor"),            ApplicationSettings::StartEditor);
+    d->leftClickActionComboBox->addItem(i18n("Show on Light Table"),           ApplicationSettings::ShowOnTable);
+    d->leftClickActionComboBox->addItem(i18n("Open with Default Application"), ApplicationSettings::OpenDefault);
     d->leftClickActionComboBox->setToolTip(i18n("Choose what should happen when you click on a thumbnail."));
 
     d->iconViewFontSelect      = new DFontSelect(i18n("Icon View font:"), iwpanel);
@@ -232,22 +239,26 @@ SetupAlbumView::SetupAlbumView(QWidget* const parent)
     grid->addWidget(d->iconShowResolutionBox,    4, 0, 1, 1);
     grid->addWidget(d->iconShowAspectRatioBox,   5, 0, 1, 1);
     grid->addWidget(d->iconShowFormatBox,        6, 0, 1, 1);
+    grid->addWidget(d->iconShowCoordinatesBox,   7, 0, 1, 1);
 
     grid->addWidget(d->iconShowTitleBox,         0, 1, 1, 1);
     grid->addWidget(d->iconShowCommentsBox,      1, 1, 1, 1);
     grid->addWidget(d->iconShowTagsBox,          2, 1, 1, 1);
     grid->addWidget(d->iconShowRatingBox,        3, 1, 1, 1);
-    grid->addWidget(d->iconShowOverlaysBox,      4, 1, 1, 1);
-    grid->addWidget(d->iconShowFullscreenBox,    5, 1, 1, 1);
-    grid->addWidget(d->iconShowCoordinatesBox,   6, 1, 1, 1);
+    grid->addWidget(d->iconShowPickLabelBox,     4, 1, 1, 1);
+    grid->addWidget(d->iconShowColorLabelBox,    5, 1, 1, 1);
+    grid->addWidget(d->iconShowOverlaysBox,      6, 1, 1, 1);
+    grid->addWidget(d->iconShowFullscreenBox,    7, 1, 1, 1);
 
-    grid->addWidget(leftClickLabel,              7, 0, 1, 1);
-    grid->addWidget(d->leftClickActionComboBox,  7, 1, 1, 1);
-    grid->addWidget(d->iconViewFontSelect,       8, 0, 1, 2);
-    grid->addWidget(d->largeThumbsBox,           9, 0, 1, 2);
+    grid->addWidget(leftClickLabel,              9, 0, 1, 1);
+    grid->addWidget(d->leftClickActionComboBox,  9, 1, 1, 1);
+    grid->addWidget(d->iconViewFontSelect,       10, 0, 1, 2);
+    grid->addWidget(d->largeThumbsBox,           11, 0, 1, 2);
+
+    grid->setRowMinimumHeight(8, 10); // vertical space
     grid->setContentsMargins(spacing, spacing, spacing, spacing);
     grid->setSpacing(spacing);
-    grid->setRowStretch(10, 10);
+    grid->setRowStretch(13, 13);
 
     d->tab->insertTab(IconView, iwpanel, i18nc("@title:tab", "Icons"));
 
@@ -313,10 +324,15 @@ SetupAlbumView::SetupAlbumView(QWidget* const parent)
                                      "Embedded preview"), PreviewSettings::RawPreviewFromEmbeddedPreview);
     d->previewRawMode->addItem(i18nc("@item Original, half-size data as RAW image preview source",
                                      "Raw data in half size"), PreviewSettings::RawPreviewFromRawHalfSize);
+    d->previewRawMode->addItem(i18nc("@item Original, full-size data as RAW image preview source",
+                                     "Raw data in full size (high quality)"), PreviewSettings::RawPreviewFromRawFullSize);
 
     d->previewConvertToEightBit   = new QCheckBox(i18n("Preview image is converted to 8 bits for a faster viewing"), pwpanel);
     d->previewConvertToEightBit->setWhatsThis(i18n("Uncheck this if you do not want to convert a 16 bits preview image to 8 bits."));
 
+    d->previewScaleFitToWindow    = new QCheckBox(i18n("Preview image is always scaled to fit to window"), pwpanel);
+    d->previewScaleFitToWindow->setWhatsThis(i18n("Uncheck this if you do not want to scale small images to fit to window."));
+
     d->previewShowIcons           = new QCheckBox(i18n("Show icons and text over preview"), pwpanel);
     d->previewShowIcons->setWhatsThis(i18n("Uncheck this if you do not want to see icons and text in the image preview."));
 
@@ -327,8 +343,9 @@ SetupAlbumView::SetupAlbumView(QWidget* const parent)
     grid3->addWidget(rawPreviewLabel,             2, 0, 1, 1);
     grid3->addWidget(d->previewRawMode,           2, 1, 1, 1);
     grid3->addWidget(d->previewConvertToEightBit, 3, 0, 1, 2);
-    grid3->addWidget(d->previewShowIcons,         4, 0, 1, 2);
-    grid3->setRowStretch(5, 10);
+    grid3->addWidget(d->previewScaleFitToWindow,  4, 0, 1, 2);
+    grid3->addWidget(d->previewShowIcons,         5, 0, 1, 2);
+    grid3->setRowStretch(6, 10);
 
     d->previewFastPreview->setChecked(true);
     d->previewRawMode->setCurrentIndex(0);
@@ -380,6 +397,16 @@ SetupAlbumView::~SetupAlbumView()
     delete d;
 }
 
+void SetupAlbumView::setActiveTab(AlbumTab tab)
+{
+    d->tab->setCurrentIndex(tab);
+}
+
+SetupAlbumView::AlbumTab SetupAlbumView::activeTab() const
+{
+    return (AlbumTab)d->tab->currentIndex();
+}
+
 void SetupAlbumView::applySettings()
 {
     ApplicationSettings* const settings = ApplicationSettings::instance();
@@ -405,9 +432,10 @@ void SetupAlbumView::applySettings()
     settings->setIconShowFullscreen(d->iconShowFullscreenBox->isChecked());
     settings->setIconShowCoordinates(d->iconShowCoordinatesBox->isChecked());
     settings->setIconShowRating(d->iconShowRatingBox->isChecked());
+    settings->setIconShowPickLabel(d->iconShowPickLabelBox->isChecked());
+    settings->setIconShowColorLabel(d->iconShowColorLabelBox->isChecked());
     settings->setIconShowImageFormat(d->iconShowFormatBox->isChecked());
     settings->setIconViewFont(d->iconViewFontSelect->font());
-
     settings->setItemLeftClickAction(d->leftClickActionComboBox->currentIndex());
 
     PreviewSettings previewSettings;
@@ -417,6 +445,7 @@ void SetupAlbumView::applySettings()
     settings->setPreviewSettings(previewSettings);
 
     settings->setPreviewShowIcons(d->previewShowIcons->isChecked());
+    settings->setScaleFitToWindow(d->previewScaleFitToWindow->isChecked());
     settings->setShowFolderTreeViewItemsCount(d->showFolderTreeViewItemsCount->isChecked());
     settings->saveSettings();
 
@@ -460,6 +489,8 @@ void SetupAlbumView::readSettings()
     d->iconShowFullscreenBox->setChecked(settings->getIconShowFullscreen());
     d->iconShowCoordinatesBox->setChecked(settings->getIconShowCoordinates());
     d->iconShowRatingBox->setChecked(settings->getIconShowRating());
+    d->iconShowPickLabelBox->setChecked(settings->getIconShowPickLabel());
+    d->iconShowColorLabelBox->setChecked(settings->getIconShowColorLabel());
     d->iconShowFormatBox->setChecked(settings->getIconShowImageFormat());
     d->iconViewFontSelect->setFont(settings->getIconViewFont());
 
@@ -480,6 +511,7 @@ void SetupAlbumView::readSettings()
     d->previewRawMode->setCurrentIndex(d->previewRawMode->findData(previewSettings.rawLoading));
 
     d->previewShowIcons->setChecked(settings->getPreviewShowIcons());
+    d->previewScaleFitToWindow->setChecked(settings->getScaleFitToWindow());
     d->previewConvertToEightBit->setChecked(previewSettings.convertToEightBit);
     d->showFolderTreeViewItemsCount->setChecked(settings->getShowFolderTreeViewItemsCount());
 
@@ -516,3 +548,5 @@ void SetupAlbumView::slotUseLargeThumbsToggled(bool b)
 }
 
 } // namespace Digikam
+
+#include "moc_setupalbumview.cpp"
