@@ -57,16 +57,21 @@ public:
                         QLatin1String("https://mirror.faigner.de/kde/files/digikam/"),
                         QLatin1String("https://kde-applicationdata.mirrors.omnilance.com/digikam/"),
                         QLatin1String("https://mirrors.ocf.berkeley.edu/kde-applicationdata/digikam/") } ),
-        mirrorIndex (0),
-        redirects   (0),
-        total       (0),
-        count       (0),
-        buttons     (nullptr),
-        progress    (nullptr),
-        faceCheck   (nullptr),
-        nameLabel   (nullptr),
-        reply       (nullptr),
-        netMngr     (nullptr)
+        mirrorIndex     (0),
+        redirects       (0),
+        total           (0),
+        count           (0),
+        buttons         (nullptr),
+        progress        (nullptr),
+        facesEngineCheck(nullptr),
+        aestheticCheck  (nullptr),
+        autoTagsCheck   (nullptr),
+        nameLabel       (nullptr),
+        infoLabel       (nullptr),
+        sizeLabel       (nullptr),
+        reply           (nullptr),
+        netMngr         (nullptr),
+        system          (qApp->applicationName())
     {
     }
 
@@ -84,61 +89,24 @@ public:
 
     QDialogButtonBox*      buttons;
     QProgressBar*          progress;
-    QCheckBox*             faceCheck;
+    QCheckBox*             facesEngineCheck;
+    QCheckBox*             aestheticCheck;
+    QCheckBox*             autoTagsCheck;
     QLabel*                nameLabel;
+    QLabel*                infoLabel;
+    QLabel*                sizeLabel;
 
     QNetworkReply*         reply;
     QNetworkAccessManager* netMngr;
+
+    SystemSettings         system;
 };
 
 FilesDownloader::FilesDownloader(QWidget* const parent)
     : QDialog(parent),
       d      (new Private)
 {
-    d->files << DownloadInfo(QLatin1String("facesengine/shape-predictor/"),
-                             QLatin1String("shapepredictor.dat"),
-                             QLatin1String("6f3d2a59dc30c7c9166983224dcf5732b25de734fff1e36ff1f3047ef90ed82b"),
-                             67740572
-                            );
-
-    d->files << DownloadInfo(QLatin1String("facesengine/dnnface/"),
-                             QLatin1String("yolov3-face.cfg"),
-                             QLatin1String("f6563bd6923fd6500d2c2d6025f32ebdba916a85e5c9798351d916909f62aaf5"),
-                             8334
-                            );
-
-    d->files << DownloadInfo(QLatin1String("facesengine/dnnface/"),
-                             QLatin1String("yolov3-wider_16000.weights"),
-                             QLatin1String("a88f3b3882e3cce1e553a81d42beef6202cb9afc3db88e7944f9ffbcc369e7df"),
-                             246305388
-                            );
-
-    d->files << DownloadInfo(QLatin1String("aestheticdetector/"),
-                             QLatin1String("weights_inceptionv3_299.pb"),
-                             QLatin1String("8923e3daff71c07533b9023ef32c69d8c058d1e0931d76d8b81241a201138538"),
-                             88007527
-                            );
-
-    if (qApp->applicationName() == QLatin1String("digikam"))
-    {
-        d->files << DownloadInfo(QLatin1String("facesengine/dnnface/"),
-                                 QLatin1String("openface_nn4.small2.v1.t7"),
-                                 QLatin1String("9b72d54aeb24a64a8135dca8e792f7cc675c99a884a6940350a6cedcf7b7ba08"),
-                                 31510785
-                                );
-
-        d->files << DownloadInfo(QLatin1String("facesengine/dnnface/"),
-                                 QLatin1String("deploy.prototxt"),
-                                 QLatin1String("f62621cac923d6f37bd669298c428bb7ee72233b5f8c3389bb893e35ebbcf795"),
-                                 28092
-                                );
-
-        d->files << DownloadInfo(QLatin1String("facesengine/dnnface/"),
-                                 QLatin1String("res10_300x300_ssd_iter_140000_fp16.caffemodel"),
-                                 QLatin1String("510ffd2471bd81e3fcc88a5beb4eae4fb445ccf8333ebc54e7302b83f4158a76"),
-                                 5351047
-                                );
-    }
+    createDownloadInfo();
 }
 
 FilesDownloader::~FilesDownloader()
@@ -149,14 +117,6 @@ FilesDownloader::~FilesDownloader()
         d->reply = nullptr;
     }
 
-    if (d->faceCheck)
-    {
-        SystemSettings system(qApp->applicationName());
-
-        system.disableFaceEngine = d->faceCheck->isChecked();
-        system.saveSettings();
-    }
-
     delete d;
 }
 
@@ -195,52 +155,34 @@ void FilesDownloader::startDownload()
 
     d->buttons                = new QDialogButtonBox(QDialogButtonBox::Help |
                                                      QDialogButtonBox::Ok |
-                                                     QDialogButtonBox::Cancel,
+                                                     QDialogButtonBox::Close,
                                                      mainWidget);
     d->buttons->button(QDialogButtonBox::Ok)->setDefault(true);
     d->buttons->button(QDialogButtonBox::Ok)->setText(i18n("Download"));
     d->buttons->button(QDialogButtonBox::Ok)->setIcon(QIcon::fromTheme(QLatin1String("edit-download")));
 
-    QString path = QDir::toNativeSeparators(getFacesEnginePath());
-    qint64 size  = 0;
+    d->infoLabel         = new QLabel(mainWidget);
+    d->sizeLabel         = new QLabel(mainWidget);
 
-    Q_FOREACH (const DownloadInfo& info, d->files)
-    {
-        if (!downloadExists(info))
-        {
-            // cppcheck-suppress useStlAlgorithm
-            size += info.size;
-            d->total++;
-        }
-    }
+    d->infoLabel->setWordWrap(true);
 
-    QString total             = ItemPropertiesTab::humanReadableBytesCount(size);
+    d->facesEngineCheck  = new QCheckBox(i18n("Use Face Detection feature"), mainWidget);
+    d->aestheticCheck    = new QCheckBox(i18n("Use Aesthetic Detection feature"), mainWidget);
+    d->autoTagsCheck     = new QCheckBox(i18n("Use Auto Tags Assignment feature"), mainWidget);
 
-    QLabel* const infoLabel   = new QLabel(i18nc("%1: folder path, %2: disk size with unit",
-                                                 "<p>For the face engine and red eye removal tool, digiKam "
-                                                 "needs some large binary files. Some of these files were "
-                                                 "not found. Click 'Download' to begin downloading the "
-                                                 "needed files. You can cancel this process, the next time "
-                                                 "digiKam is started this dialog will appear again. Face "
-                                                 "detection will not work without these files.</p>"
-                                                 "<p>The files will be downloaded to %1. Make sure there are "
-                                                 "around %2 available. <b>After the successful download you "
-                                                 "have to restart digiKam.</b></p>", path, total), mainWidget);
-
-    infoLabel->setWordWrap(true);
-
-    d->faceCheck              = new QCheckBox(i18n("Disable face engine feature and don't ask again"), mainWidget);
-
-    d->progress               = new QProgressBar(mainWidget);
+    d->progress          = new QProgressBar(mainWidget);
     d->progress->setMinimum(0);
     d->progress->setMaximum(1);
     d->progress->setValue(0);
 
-    d->nameLabel              = new QLabel(mainWidget);
+    d->nameLabel         = new QLabel(mainWidget);
 
-    vBox->addWidget(infoLabel);
-    vBox->addStretch(5);
-    vBox->addWidget(d->faceCheck);
+    vBox->addWidget(d->infoLabel);
+    vBox->addWidget(d->sizeLabel);
+    vBox->addStretch(1);
+    vBox->addWidget(d->facesEngineCheck);
+    vBox->addWidget(d->aestheticCheck);
+    vBox->addWidget(d->autoTagsCheck);
     vBox->addStretch(1);
     vBox->addWidget(d->nameLabel);
     vBox->addWidget(d->progress);
@@ -254,15 +196,33 @@ void FilesDownloader::startDownload()
     connect(d->buttons->button(QDialogButtonBox::Help), SIGNAL(clicked()),
             this, SLOT(slotHelp()));
 
-    connect(d->buttons->button(QDialogButtonBox::Cancel), SIGNAL(clicked()),
+    connect(d->buttons->button(QDialogButtonBox::Close), SIGNAL(clicked()),
             this, SLOT(reject()));
 
+    d->facesEngineCheck->setChecked(d->system.enableFaceEngine);
+    d->aestheticCheck->setChecked(d->system.enableAesthetic);
+    d->autoTagsCheck->setChecked(d->system.enableAutoTags);
+
+    connect(d->facesEngineCheck, SIGNAL(toggled(bool)),
+            this, SLOT(slotUpdateDownloadInfo()));
+
+    connect(d->aestheticCheck, SIGNAL(toggled(bool)),
+            this, SLOT(slotUpdateDownloadInfo()));
+
+    connect(d->autoTagsCheck, SIGNAL(toggled(bool)),
+            this, SLOT(slotUpdateDownloadInfo()));
+
+    slotUpdateDownloadInfo();
+
     (void)exec();
 }
 
 void FilesDownloader::slotDownload()
 {
     d->buttons->button(QDialogButtonBox::Ok)->setEnabled(false);
+    d->facesEngineCheck->setEnabled(false);
+    d->aestheticCheck->setEnabled(false);
+    d->autoTagsCheck->setEnabled(false);
 
     if (d->error.isEmpty())
     {
@@ -282,8 +242,6 @@ void FilesDownloader::slotDownload()
         QMessageBox::information(this, qApp->applicationName(),
                                  i18n("All files were downloaded successfully."));
 
-        d->faceCheck->setChecked(false);
-
         close();
     }
     else
@@ -503,6 +461,149 @@ void FilesDownloader::slotHelp()
     openOnlineDocumentation(QLatin1String("getting_started"), QLatin1String("quick_start"), QLatin1String("firstrun-downloads"));
 }
 
+void FilesDownloader::createDownloadInfo()
+{
+    d->files.clear();
+
+    if (d->system.enableFaceEngine)
+    {
+        d->files << DownloadInfo(QLatin1String("facesengine/shape-predictor/"),
+                                 QLatin1String("shapepredictor.dat"),
+                                 QLatin1String("6f3d2a59dc30c7c9166983224dcf5732b25de734fff1e36ff1f3047ef90ed82b"),
+                                 67740572
+                                );
+
+        d->files << DownloadInfo(QLatin1String("facesengine/dnnface/"),
+                                 QLatin1String("yolov3-face.cfg"),
+                                 QLatin1String("f6563bd6923fd6500d2c2d6025f32ebdba916a85e5c9798351d916909f62aaf5"),
+                                 8334
+                                );
+
+        d->files << DownloadInfo(QLatin1String("facesengine/dnnface/"),
+                                QLatin1String("yolov3-wider_16000.weights"),
+                                QLatin1String("a88f3b3882e3cce1e553a81d42beef6202cb9afc3db88e7944f9ffbcc369e7df"),
+                                246305388
+                               );
+
+        if (qApp->applicationName() == QLatin1String("digikam"))
+        {
+            d->files << DownloadInfo(QLatin1String("facesengine/dnnface/"),
+                                     QLatin1String("openface_nn4.small2.v1.t7"),
+                                     QLatin1String("9b72d54aeb24a64a8135dca8e792f7cc675c99a884a6940350a6cedcf7b7ba08"),
+                                     31510785
+                                    );
+
+            d->files << DownloadInfo(QLatin1String("facesengine/dnnface/"),
+                                     QLatin1String("deploy.prototxt"),
+                                     QLatin1String("f62621cac923d6f37bd669298c428bb7ee72233b5f8c3389bb893e35ebbcf795"),
+                                     28092
+                                    );
+
+            d->files << DownloadInfo(QLatin1String("facesengine/dnnface/"),
+                                     QLatin1String("res10_300x300_ssd_iter_140000_fp16.caffemodel"),
+                                     QLatin1String("510ffd2471bd81e3fcc88a5beb4eae4fb445ccf8333ebc54e7302b83f4158a76"),
+                                     5351047
+                                    );
+        }
+    }
+
+    if (d->system.enableAesthetic)
+    {
+        d->files << DownloadInfo(QLatin1String("aestheticdetector/"),
+                                 QLatin1String("weights_inceptionv3_299.pb"),
+                                 QLatin1String("8923e3daff71c07533b9023ef32c69d8c058d1e0931d76d8b81241a201138538"),
+                                 88007527
+                                );
+    }
+
+    if (d->system.enableAutoTags)
+    {
+        d->files << DownloadInfo(QLatin1String("autotags/"),
+                                 QLatin1String("yolov5n_batch_16_s320.onnx"),
+                                 QLatin1String("43cf201144e6918354892a2fda7ccb07b3df1abc136ddac3b5c968dffc847009"),
+                                 7616008
+                                );
+
+        d->files << DownloadInfo(QLatin1String("autotags/"),
+                                 QLatin1String("yolov5x_batch_16_s320.onnx"),
+                                 QLatin1String("e56b5024e6d29f8a35dbfbdd67bbdb69593fb67bfb275915081f9a463fcd355b"),
+                                 347010839
+                                );
+
+        d->files << DownloadInfo(QLatin1String("autotags/"),
+                                 QLatin1String("resnet50.onnx"),
+                                 QLatin1String("490e2761519cbf8a4433f880c2aa16b457730085cf9a8aab1e43d82bcadba4f1"),
+                                 102146365
+                                );
+
+        d->files << DownloadInfo(QLatin1String("autotags/"),
+                                 QLatin1String("coco.names"),
+                                 QLatin1String("634a1132eb33f8091d60f2c346ababe8b905ae08387037aed883953b7329af84"),
+                                 625
+                                );
+
+        d->files << DownloadInfo(QLatin1String("autotags/"),
+                                 QLatin1String("classification_classes_ILSVRC2012.txt"),
+                                 QLatin1String("4eb3da435cf544e4a6f390f62c84cb9c9bb68cf8b14e97f8a063452382e5efd2"),
+                                 21675
+                                );
+    }
+
+}
+
+void FilesDownloader::slotUpdateDownloadInfo()
+{
+    QString path = QDir::toNativeSeparators(getFacesEnginePath());
+
+    d->system.enableFaceEngine = d->facesEngineCheck->isChecked();
+    d->system.enableAesthetic  = d->aestheticCheck->isChecked();
+    d->system.enableAutoTags   = d->autoTagsCheck->isChecked();
+    d->system.saveSettings();
+
+    createDownloadInfo();
+
+    qint64 size = 0;
+    d->total    = 0;
+
+    Q_FOREACH (const DownloadInfo& info, d->files)
+    {
+        if (!downloadExists(info))
+        {
+            // cppcheck-suppress useStlAlgorithm
+            size += info.size;
+            d->total++;
+        }
+    }
+
+    QString sizeString = ItemPropertiesTab::humanReadableBytesCount(size);
+
+    d->infoLabel->setText(i18nc("%1: folder path",
+                                "<p>For face detection, the red-eye removal tool, the classification "
+                                "of images according to aesthetics or the automatic assignment "
+                                "of tags to images, digiKam requires some large binary files. You "
+                                "can choose which feature you want to use.</p>"
+                                "<p>Some of these files were not found. Click “Download” to begin "
+                                "downloading the files you need. You can close this dialog, you "
+                                "will be asked again the next time you start digiKam. Without "
+                                "these files the selected features will not work.</p>"
+                                "<p>The files will be downloaded to %1.</p>"
+                                "<p><b>After the successful download you have to restart digiKam.</b></p>", path));
+    if (size > 0)
+    {
+        d->sizeLabel->setText(i18nc("%1: file counter, %2: disk size with unit",
+                                    "The download requires %1 files with a size of %2.",
+                                    d->total, sizeString));
+
+        d->buttons->button(QDialogButtonBox::Ok)->setEnabled(true);
+    }
+    else
+    {
+        d->sizeLabel->setText(i18n("All files of the selected features were found."));
+
+        d->buttons->button(QDialogButtonBox::Ok)->setEnabled(false);
+    }
+}
+
 //-----------------------------------------------------------------------------
 
 DownloadInfo::DownloadInfo()
@@ -544,3 +645,5 @@ DownloadInfo& DownloadInfo::operator=(const DownloadInfo& other)
 }
 
 } // namespace Digikam
+
+#include "moc_filesdownloader.cpp"
