@@ -19,7 +19,6 @@
 #include <QGridLayout>
 #include <QLabel>
 #include <QDialogButtonBox>
-#include <QDialog>
 #include <QPushButton>
 #include <QApplication>
 #include <QStyle>
@@ -715,3 +714,5 @@ void NamespaceEditDlg::slotHelp()
 }
 
 } // namespace Digikam
+
+#include "moc_namespaceeditdlg.cpp"
