@@ -6,7 +6,7 @@
  * Date        : 2020-27-07
  * Description : system settings widget
  *
- * SPDX-FileCopyrightText: 2020 by Maik Qualmann <metzpinguin at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2023 by Maik Qualmann <metzpinguin at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -32,6 +32,7 @@
 #include "digikam_debug.h"
 #include "systemsettings.h"
 #include "filesdownloader.h"
+#include "ui_proxysettingswidget.h"
 
 namespace Digikam
 {
@@ -41,24 +42,24 @@ class Q_DECL_HIDDEN SystemSettingsWidget::Private
 
 public:
 
-    explicit Private()
-      : useHighDpiScalingCheck(nullptr),
-        useHighDpiPixmapsCheck(nullptr),
-        disableOpenCLCheck    (nullptr),
-        enableLoggingCheck    (nullptr),
-        filesDownloadButton   (nullptr),
-        filesDownloader       (nullptr)
-    {
-    }
+    Private() = default;
 
-    QCheckBox*       useHighDpiScalingCheck;
-    QCheckBox*       useHighDpiPixmapsCheck;
-    QCheckBox*       disableOpenCLCheck;
-    QCheckBox*       enableLoggingCheck;
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 
-    QPushButton*     filesDownloadButton;
+    QCheckBox*              useHighDpiScalingCheck = nullptr;
+    QCheckBox*              useHighDpiPixmapsCheck = nullptr;
 
-    FilesDownloader* filesDownloader;
+#endif
+
+    QCheckBox*              softwareOpenGLCheck    = nullptr;
+    QCheckBox*              disableOpenCLCheck     = nullptr;
+    QCheckBox*              enableLoggingCheck     = nullptr;
+
+    QPushButton*            filesDownloadButton    = nullptr;
+
+    FilesDownloader*        filesDownloader        = nullptr;
+
+    Ui::ProxySettingsWidget uiProxySettings;
 };
 
 SystemSettingsWidget::SystemSettingsWidget(QWidget* const parent)
@@ -72,13 +73,26 @@ SystemSettingsWidget::SystemSettingsWidget(QWidget* const parent)
 
     d->filesDownloader        = new FilesDownloader(this);
 
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+
     d->useHighDpiScalingCheck = new QCheckBox(i18n("Use high DPI scaling from the screen factor"), this);
     d->useHighDpiPixmapsCheck = new QCheckBox(i18n("Use pixmaps with high DPI resolution"), this);
+
+#endif
+
+    d->softwareOpenGLCheck    = new QCheckBox(i18n("Force use of software OpenGL rendering"), this);
     d->disableOpenCLCheck     = new QCheckBox(i18n("Disable hardware acceleration OpenCL"), this);
     d->enableLoggingCheck     = new QCheckBox(i18n("Enable internal debug logging"), this);
 
-    d->filesDownloadButton    = new QPushButton(i18n("Download Face Engine Data..."), this);
-    d->filesDownloadButton->setEnabled(!d->filesDownloader->checkDownloadFiles());
+    d->filesDownloadButton    = new QPushButton(i18n("Download required binary data..."), this);
+
+    // Proxy Settings
+
+    QWidget* const proxySettings = new QWidget(this);
+    d->uiProxySettings.setupUi(proxySettings);
+    proxySettings->setContentsMargins(QMargins());
+
+    // ---
 
     if (qApp->applicationName() == QLatin1String("showfoto"))
     {
@@ -91,17 +105,26 @@ SystemSettingsWidget::SystemSettingsWidget(QWidget* const parent)
     systemNote->setWordWrap(true);
     systemNote->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
 
-    layout->addWidget(d->useHighDpiScalingCheck, 0, 0, 1, 1);
-    layout->addWidget(d->useHighDpiPixmapsCheck, 1, 0, 1, 1);
-    layout->addWidget(d->disableOpenCLCheck,     2, 0, 1, 1);
-    layout->addWidget(d->enableLoggingCheck,     3, 0, 1, 1);
-    layout->addWidget(d->filesDownloadButton,    4, 0, 1, 1);
-    layout->addWidget(systemNote,                5, 0, 1, 2);
+    int row = 0;
+
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+
+    layout->addWidget(d->useHighDpiScalingCheck, row++, 0, 1, 1);
+    layout->addWidget(d->useHighDpiPixmapsCheck, row++, 0, 1, 1);
+
+#endif
+
+    layout->addWidget(d->softwareOpenGLCheck,    row++, 0, 1, 1);
+    layout->addWidget(d->disableOpenCLCheck,     row++, 0, 1, 1);
+    layout->addWidget(d->enableLoggingCheck,     row++, 0, 1, 1);
+    layout->addWidget(d->filesDownloadButton,    row++, 0, 1, 1);
+    layout->addWidget(proxySettings,             row++, 0, 1, 1);
+    layout->addWidget(systemNote,                row++, 0, 1, 2);
     layout->setContentsMargins(spacing, spacing, spacing, spacing);
-    layout->setRowStretch(6, 10);
+    layout->setRowStretch(row, 10);
 
     connect(d->filesDownloadButton, &QPushButton::pressed,
-            this, &SystemSettingsWidget::slotFaceDownload);
+            this, &SystemSettingsWidget::slotBinaryDownload);
 }
 
 SystemSettingsWidget::~SystemSettingsWidget()
@@ -113,28 +136,65 @@ void SystemSettingsWidget::readSettings()
 {
     SystemSettings system(qApp->applicationName());
 
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+
     d->useHighDpiScalingCheck->setChecked(system.useHighDpiScaling);
     d->useHighDpiPixmapsCheck->setChecked(system.useHighDpiPixmaps);
+
+#endif
+
+    d->softwareOpenGLCheck->setChecked(system.softwareOpenGL);
     d->enableLoggingCheck->setChecked(system.enableLogging);
     d->disableOpenCLCheck->setChecked(system.disableOpenCL);
+
+    // Proxy Settings
+
+    d->uiProxySettings.kcfg_proxyUrl->setText(system.proxyUrl);
+    d->uiProxySettings.kcfg_proxyPort->setValue(system.proxyPort);
+    d->uiProxySettings.kcfg_proxyUser->setText(system.proxyUser);
+    d->uiProxySettings.kcfg_proxyPass->setText(system.proxyPass);
+    d->uiProxySettings.kcfg_proxyType->setCurrentIndex(system.proxyType);
+    d->uiProxySettings.kcfg_proxyAuth->setChecked(system.proxyAuth);
 }
 
 void SystemSettingsWidget::saveSettings()
 {
     SystemSettings system(qApp->applicationName());
 
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+
     system.useHighDpiScaling = d->useHighDpiScalingCheck->isChecked();
     system.useHighDpiPixmaps = d->useHighDpiPixmapsCheck->isChecked();
+
+#endif
+
+    system.softwareOpenGL    = d->softwareOpenGLCheck->isChecked();
     system.enableLogging     = d->enableLoggingCheck->isChecked();
     system.disableOpenCL     = d->disableOpenCLCheck->isChecked();
 
+    system.proxyUrl          = d->uiProxySettings.kcfg_proxyUrl->text();
+    system.proxyPort         = d->uiProxySettings.kcfg_proxyPort->value();
+    system.proxyType         = d->uiProxySettings.kcfg_proxyType->currentIndex();
+
+    if (d->uiProxySettings.kcfg_proxyAuth->isChecked())
+    {
+        system.proxyAuth = true;
+        system.proxyUser = d->uiProxySettings.kcfg_proxyUser->text();
+        system.proxyPass = d->uiProxySettings.kcfg_proxyPass->text();
+    }
+    else
+    {
+        system.proxyAuth = false;
+    }
+
     system.saveSettings();
 }
 
-void SystemSettingsWidget::slotFaceDownload()
+void SystemSettingsWidget::slotBinaryDownload()
 {
     d->filesDownloader->startDownload();
-    d->filesDownloadButton->setEnabled(!d->filesDownloader->checkDownloadFiles());
 }
 
 } // namespace Digikam
+
+#include "moc_systemsettingswidget.cpp"
