@@ -7,7 +7,7 @@
  * Description : digiKam setup dialog.
  *
  * SPDX-FileCopyrightText: 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2003-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2003-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -41,18 +41,18 @@ public:
         CollectionsPage,
         AlbumViewPage,
         ToolTipPage,
-
-#if defined HAVE_MEDIAPLAYER && !defined HAVE_QTMULTIMEDIA
-
-        VideoPage,
-
-#endif
-
         MetadataPage,
         TemplatePage,
         EditorPage,
         ICCPage,
         LightTablePage,
+
+#ifdef HAVE_GEOLOCATION
+
+        GeolocationPage,
+
+#endif
+
         ImageQualityPage,
         CameraPage,
         PluginsPage,
@@ -88,6 +88,12 @@ public:
 
     static bool execImageQualitySorter(QWidget* const parent);
 
+#ifdef HAVE_GEOLOCATION
+
+    static bool execGeolocation(QWidget* const parent, int tab);
+
+#endif
+
     QSize sizeHint() const  override;
 
 private Q_SLOTS:
