@@ -6,19 +6,10 @@
  * Date        : 2013-08-19
  * Description : Image Quality setup page
  *
- * Copyright (C) 2013-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2013-2014 by Gowtham Ashok <gwty93 at gmail dot com>
+ * SPDX-FileCopyrightText: 2013-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013-2014 by Gowtham Ashok <gwty93 at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -43,11 +34,10 @@ class SetupImageQualitySorter : public QScrollArea
 public:
 
     explicit SetupImageQualitySorter(QWidget* const parent = nullptr);
-    ~SetupImageQualitySorter() override;
+    ~SetupImageQualitySorter()                              override;
 
     void applySettings();
-    ImageQualityContainer getImageQualityContainer();
-
+    ImageQualityContainer getImageQualityContainer() const;
 
 private:
 
