@@ -3,7 +3,7 @@
 # Script to bundle data using previously-built KF5 with digiKam installation
 # and create a Linux AppImage bundle file.
 #
-# SPDX-FileCopyrightText: 2015-2023 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2015-2024 by Gilles Caulier  <caulier dot gilles at gmail dot com>
 #
 # SPDX-License-Identifier: BSD-3-Clause
 #
@@ -138,6 +138,10 @@ cp -r /usr/share/solid                                    ./usr/share
 cp -r /usr/share/icu                                      ./usr/share
 cp -r /usr/share/mime                                     ./usr/share
 
+# See bug #480134: an up-to-date and clean freedesktop.org database is requires
+cp $ORIG_WD/data/freedesktop.org.xml                      ./usr/share/mime/packages
+rm -rf ./usr/share/mime/mime.cache
+
 # depending of OpenCV version installed, data directory is not the same.
 cp -r /usr/share/OpenCV                                   ./usr/share  || true
 cp -r /usr/share/opencv4                                  ./usr/share  || true
@@ -238,12 +242,6 @@ for FILE in $FILES ; do
     fi
 done
 
-echo -e "------------- Copy Marble data and plugins files\n"
-
-cp -r /usr/${LIBSUFFIX}/marble/plugins/ ./usr/bin/
-
-cp -r /usr/share/marble/data            ./usr/bin/
-
 echo -e "------------- Copy Git Revisions Manifest\n"
 
 touch ./usr/share/digikam/MANIFEST.txt
@@ -488,11 +486,17 @@ rm -rf usr/share/pkgconfig || true
 echo -e "------------- Strip Symbols in Binaries Files\n"
 
 if [[ $DK_DEBUG = 1 ]] ; then
-    FILES=$(find . -type f  -exec file {} \; | grep ELF | grep -Ev '(digikam|showfoto)' | cut -d':' -f1)
+
+    # Note: do not remove kService debug symbols until bug #480134 is not resolved.
+
+    FILES=$(find . -type f  -exec file {} \; | grep ELF | grep -Ev '(digikam|showfoto|libKF5Service.so.5)' | cut -d':' -f1)
 #    FILES=$(find . -type f -executable | grep -Ev '(digikam|showfoto)')
+
 else
+
     FILES=$(find . -type f  -exec file {} \; | grep ELF | cut -d':' -f1)
 #    FILES=$(find . -type f -executable)
+
 fi
 
 for FILE in $FILES ; do
