@@ -3,7 +3,7 @@
 # Script to build extra libraries using MacPorts env.
 # This script must be run as sudo
 #
-# SPDX-FileCopyrightText: 2015-2023 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2015-2024 by Gilles Caulier  <caulier dot gilles at gmail dot com>
 #
 # SPDX-License-Identifier: BSD-3-Clause
 #
@@ -105,13 +105,6 @@ cmake --build . --config RelWithDebInfo --target ext_kimageformats       -- -j$C
 # libksane support
 #cmake --build . --config RelWithDebInfo --target ext_libksane            -- -j$CPU_CORES
 
-# Geolocation support
-cmake --build . --config RelWithDebInfo --target ext_marble              -- -j$CPU_CORES
-
-# Marble install shared lib at wrong place.
-mv $INSTALL_PREFIX/Marble.app/Contents/MacOS/lib/libastro*  $INSTALL_PREFIX/lib
-mv $INSTALL_PREFIX/Marble.app/Contents/MacOS/lib/libmarble* $INSTALL_PREFIX/lib
-
 # Calendar support
 cmake --build . --config RelWithDebInfo --target ext_kcalendarcore       -- -j$CPU_CORES
 
