@@ -8,7 +8,7 @@
 #   - ImageMagick for the rune-time dll.
 #   - Msys2/Rsync CLI tools for Windows.
 #
-# SPDX-FileCopyrightText: 2015-2023 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2015-2024 by Gilles Caulier  <caulier dot gilles at gmail dot com>
 #
 # SPDX-License-Identifier: BSD-3-Clause
 #
@@ -113,9 +113,6 @@ mkdir -p $BUNDLEDIR/translations
 
 # Data files ---------------------------------------------------------------------------------
 
-echo -e "\n---------- Marble data"
-cp -r $VCPKG_INSTALL_PREFIX/data/*                                        $BUNDLEDIR/data                       2>/dev/null
-
 echo -e "\n---------- Generics data"
 cp -r $VCPKG_INSTALL_PREFIX/share/lensfun                                 $BUNDLEDIR/data                       2>/dev/null
 cp -r $VCPKG_INSTALL_PREFIX/share/digikam                                 $BUNDLEDIR/data                       2>/dev/null
@@ -123,6 +120,7 @@ cp -r $VCPKG_INSTALL_PREFIX/share/showfoto                                $BUNDL
 cp -r $VCPKG_INSTALL_PREFIX/share/solid                                   $BUNDLEDIR/data                       2>/dev/null
 cp -r $VCPKG_INSTALL_PREFIX/share/kxmlgui5                                $BUNDLEDIR/data                       2>/dev/null
 cp -r $VCPKG_INSTALL_PREFIX/share/knotifications6                         $BUNDLEDIR/data                       2>/dev/null
+cp -r $VCPKG_INSTALL_PREFIX/share/applications                            $BUNDLEDIR/data                       2>/dev/null
 cp -r $VCPKG_INSTALL_PREFIX/bin/data/k*                                   $BUNDLEDIR/data                       2>/dev/null
 cp -r $VCPKG_INSTALL_PREFIX/resources                                     $BUNDLEDIR/                           2>/dev/null
 
@@ -149,10 +147,6 @@ cp -r $VCPKG_INSTALL_PREFIX/bin/data/locale                               $BUNDL
 # digiKam translations
 cp -r $VCPKG_INSTALL_PREFIX/share/locale                                  $BUNDLEDIR/data                       2>/dev/null
 
-echo -e "\n---------- Xdg"
-cp -r $VCPKG_INSTALL_PREFIX/etc/xdg                                       $BUNDLEDIR/etc                        2>/dev/null
-cp -r $VCPKG_INSTALL_PREFIX/bin/data/xdg                                  $BUNDLEDIR/share                      2>/dev/null
-
 # See bug 471058
 echo -e "\n---------- Freedesktop"
 mkdir -p $BUNDLEDIR/share/mime/packages/                                                                        2>/dev/null
@@ -174,14 +168,10 @@ done
 echo -e "\n---------- Qt6 plugins"
 cp -r $VCPKG_INSTALL_PREFIX/Qt6/plugins                                   $BUNDLEDIR/                           2>/dev/null
 
-echo -e "\n---------- Marble plugins"
-cp -r $VCPKG_INSTALL_PREFIX/plugins/*.dll                                 $BUNDLEDIR/plugins                    2>/dev/null
-
-echo -e "\n---------- digiKam and KF6 plugins"
-cp -r $VCPKG_INSTALL_PREFIX/lib/plugins                                   $BUNDLEDIR/                           2>/dev/null
-
-echo -e "\n---------- OpenAL for QtAV"
-cp -r $VCPKG_INSTALL_PREFIX/bin/OpenAL32.dll                              $BUNDLEDIR/                           2>/dev/null
+echo -e "\n---------- OpenGl Software for Qt6"
+# Taken from https://download.qt.io/development_releases/prebuilt/llvmpipe/windows/
+# See bug #479148
+cp -r $ORIG_WD/data/opengl32sw.dll                                        $BUNDLEDIR/                           2>/dev/null
 
 echo -e "\n---------- ImageMagick"
 
@@ -222,6 +212,10 @@ for coder in $IM_CODERS_BL ; do
 
 done
 
+# See bug #476290
+rm -fr $BUNDLEDIR/plugins/imageformats/qjp2.dll
+rm -fr $BUNDLEDIR/plugins/imageformats/qjp2.pdb
+
 #################################################################################################
 # Add debug symbols for few binary files to optimize space.
 # NOTE: NSIS only support < 2Gb of file to package in the same installer. If size is bigger, a bus error exception is genenrated.
@@ -280,6 +274,7 @@ $VCPKG_INSTALL_PREFIX/bin/digikam.exe                      \
 $VCPKG_INSTALL_PREFIX/bin/showfoto.exe                     \
 $VCPKG_INSTALL_PREFIX/bin/kbuildsycoca6.exe                \
 $VCPKG_INSTALL_PREFIX/tools/Qt6/bin/QtWebEngineProcess.exe \
+$VCPKG_INSTALL_PREFIX/tools/ffmpeg/ffmpeg.exe \
 "
 
 for app in $EXE_FILES ; do
@@ -290,10 +285,7 @@ for app in $EXE_FILES ; do
 done
 
 DLL_FILES="\
-`find  $VCPKG_INSTALL_PREFIX/lib/plugins -name "*.dll" -type f | sed 's|$VCPKG_INSTALL_PREFIX/libs/plugins||'` \
 `find  $VCPKG_INSTALL_PREFIX/Qt6/plugins -name "*.dll" -type f | sed 's|$VCPKG_INSTALL_PREFIX/Qt6/plugins||'`  \
-`find  $VCPKG_INSTALL_PREFIX/plugins     -name "*.dll" -type f | sed 's|$VCPKG_INSTALL_PREFIX/plugins||'`      \
-$VCPKG_INSTALL_PREFIX/bin/OpenAL32.dll                                                                         \
 "
 
 for app in $DLL_FILES ; do
@@ -302,17 +294,31 @@ for app in $DLL_FILES ; do
 
 done
 
+FFMPEG_DLL_FILES="\
+`find  $VCPKG_INSTALL_PREFIX/tools/ffmpeg -name "*.dll" -type f | sed 's|$VCPKG_INSTALL_PREFIX/tools/ffmpeg||'` \
+`find  $VCPKG_INSTALL_PREFIX/tools/ffmpeg -name "*.DLL" -type f | sed 's|$VCPKG_INSTALL_PREFIX/tools/ffmpeg||'` \
+"
+
+for ffmpegdll in $FFMPEG_DLL_FILES ; do
+
+    cp $ffmpegdll $BUNDLEDIR/
+    CopyReccursiveDependencies "$DUMP_BIN" "$ffmpegdll" "$BUNDLEDIR/" "$VCPKG_INSTALL_PREFIX/bin"
+
+done
+
 echo -e "\n---------- Copy redistributable VSCommunity compatibility dlls"
 
+VS_DLL_VERSION=140
+
 VS_DLL_FILES="\
-$VCPKG_INSTALL_PREFIX/bin/msvcp140.dll              \
-$VCPKG_INSTALL_PREFIX/bin/msvcp140_1.dll            \
-$VCPKG_INSTALL_PREFIX/bin/msvcp140_2.dll            \
-$VCPKG_INSTALL_PREFIX/bin/msvcp140_atomic_wait.dll  \
-$VCPKG_INSTALL_PREFIX/bin/msvcp140_codecvt_ids.dll  \
-$VCPKG_INSTALL_PREFIX/bin/vcruntime140_1.dll        \
-$VCPKG_INSTALL_PREFIX/bin/vcruntime140.dll          \
-$VCPKG_INSTALL_PREFIX/bin/concrt140.dll             \
+$VCPKG_INSTALL_PREFIX/bin/msvcp${VS_DLL_VERSION}.dll              \
+$VCPKG_INSTALL_PREFIX/bin/msvcp${VS_DLL_VERSION}_1.dll            \
+$VCPKG_INSTALL_PREFIX/bin/msvcp${VS_DLL_VERSION}_2.dll            \
+$VCPKG_INSTALL_PREFIX/bin/msvcp${VS_DLL_VERSION}_atomic_wait.dll  \
+$VCPKG_INSTALL_PREFIX/bin/msvcp${VS_DLL_VERSION}_codecvt_ids.dll  \
+$VCPKG_INSTALL_PREFIX/bin/vcruntime${VS_DLL_VERSION}_1.dll        \
+$VCPKG_INSTALL_PREFIX/bin/vcruntime${VS_DLL_VERSION}.dll          \
+$VCPKG_INSTALL_PREFIX/bin/concrt${VS_DLL_VERSION}.dll             \
 "
 
 for vsdll in $VS_DLL_FILES ; do
@@ -322,6 +328,20 @@ for vsdll in $VS_DLL_FILES ; do
 
 done
 
+# Copy also the vcomp dlls for Windows 11 support
+
+# To prevent broken array parsing of paths with spaces.
+IFS=$'\n'
+
+VS_DLL_COMP="`find "/c/Program Files/Microsoft Visual Studio/" -name "vcomp${VS_DLL_VERSION}*.dll" -type f | grep 'x64/' | grep 'OpenMP' | grep -v 'onecore'`"
+
+for vscompdll in $VS_DLL_COMP ; do
+
+    echo -e "   => $vscompdll"
+    cp -r "$vscompdll" $BUNDLEDIR/ 2>/dev/null
+
+done
+
 #################################################################################################
 # Install ExifTool binary.
 
