@@ -1,12 +1,12 @@
 #!/bin/bash
 
-# SPDX-FileCopyrightText: 2013-2023 by Gilles Caulier, <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2013-2024 by Gilles Caulier, <caulier dot gilles at gmail dot com>
 #
 # Run CppCheck static analyzer on whole digiKam source code.
 # http://cppcheck.sourceforge.net/
 # Dependencies : Python::pygments module to export report as HTML.
 #
-# If '--nowebupdate' is passed as argument, static analyzer results are just created locally.
+# If '--webupdate' is passed as argument, static analyzer results are pushed on the web site.
 #
 # SPDX-License-Identifier: BSD-3-Clause
 #
@@ -49,6 +49,26 @@ done
 
 cppcheck -j$CPU_CORES \
          -DQ_OS_LINUX \
+         -DQ_OS_UNIX \
+         -DQ_PROCESSOR_X86_64 \
+         -DHAVE_GEOLOCATION \
+         -DHAVE_MEDIA_PLAYER \
+         -DHAVE_QWEBENGINE \
+         -DHAVE_QTMULTIMEDIA \
+         -DHAVE_OPENGL \
+         -DHAVE_MYSQLSUPPORT \
+         -DHAVE_INTERNALMYSQL \
+         -DHAVE_GPHOTO2 \
+         -DHAVE_PANORAMA \
+         -DHAVE_X11 \
+         -DHAVE_X265 \
+         -DHAVE_DBUS \
+         -DHAVE_LENSFUN \
+         -DHAVE_HEIF \
+         -DHAVE_EIGEN3 \
+         -DHAVE_JASPER \
+         -DHAVE_IMAGE_MAGICK \
+         -D_XMP_SUPPORT_ \
          --verbose \
          --std=c++17 \
          --library=qt.cfg \
@@ -59,29 +79,35 @@ cppcheck -j$CPU_CORES \
          --xml-version=2 \
          --platform=unix64 \
          --enable=all \
-         --max-ctu-depth=4 \
-         --report-progress \
+         --check-level=exhaustive \
          --suppress=*:*cimg*.h \
          --suppress=*:*libraw*.h \
          --suppress=*:*libpgf*.h \
          --suppress=*:*upnpsdk*.h \
-         --suppress=*:*yfauth*.h \
          --suppress=*:*o2*.h \
          --suppress=*:*lqr*.h \
          --suppress=*:*libjpeg*.h \
          --suppress=*:*dng_sdk*.h \
-         --suppress=*:*xmp_sdk*.h \
+         --suppress=*:*xmp_sdk/*.h \
+         --suppress=*:*qav*.h \
+         --suppress=missingIncludeSystem \
+         --suppress=missingInclude \
          --suppress=variableScope \
          --suppress=purgedConfiguration \
          --suppress=toomanyconfigs \
          --suppress=unreadVariable \
          --suppress=unusedVariable \
          --suppress=unusedStructMember \
+         --suppress=unusedPrivateFunction \
          --suppress=unknownMacro \
+         --suppress=unmatchedSuppression:* \
+         --suppress=unassignedVariable \
          --suppress=class_X_Y \
          --suppress=ConfigurationNotChecked \
-         --suppress=unmatchedSuppression:* \
          --suppress=useStlAlgorithm \
+         --suppress=cstyleCast \
+         --suppress=constVariablePointer \
+         --suppress=shadowFunction \
          --output-file=report.cppcheck.xml \
          $IGNORE_DIRS \
          $INCLUDE_DIRS \
@@ -92,7 +118,7 @@ cppcheck-htmlreport --file=report.cppcheck.xml \
                     --source-dir=. \
                     --title=$TITLE
 
-if [[ $1 != "--nowebupdate" ]] ; then
+if [[ $1 == "--webupdate" ]] ; then
 
     # update www.digikam.org report section.
     updateReportToWebsite "cppcheck" $REPORT_DIR $TITLE $(parseGitBranch)
