@@ -6,7 +6,9 @@
 #
 # SPDX-FileCopyrightText: 2021      by TRAN Quoc Hung <quochungtran1999 at gmail dot com>
 # SPDX-FileCopyrightText: 2021      by Surya K M      <suryakm_is20 dot rvitm@rvei dot edu dot in>
-# SPDX-FileCopyrightText: 2021-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2024      by Joerg Lohse    <joergmlpts at gmail dot com>
+
 #
 # SPDX-License-Identifier: BSD-3-Clause
 #
@@ -77,6 +79,7 @@ required_packages=("cmake"                   # To Compile Source Code
                    "libqt5printsupport5"     # Qt 5 PrintSupport module
                    "libqt5svg5"              # Qt 5 Svg module
                    "libqt5webengine5"        # Qt 5 webengine module
+                   "qtwebengine5-dev"        # Qt 5 webengine module
                    "libqt5networkauth5-dev"  # Qt 5 network authentification.
 
                    "libkf5config-dev"        # Configuration settings framework for Qt
@@ -250,8 +253,6 @@ optional_packages=("ruby"                               # For i18n extraction
                    "tesseract-ocr"                      # For CI/CD (MacOS)
                    "libeigen3-dev"                      # >= 3.2
                    "liblensfun-dev"                     # >= 0.2.8
-                   "libmarble-dev"                      # >= 0.22
-                   "marble-data"                        # >= 5.0
                    "libgomp1"                           # For Libraw compilation
                    "libavdevice-dev"                    # >= 3.3.x
                    "libavfilter-dev"                    # >= 3.3.x
@@ -292,7 +293,6 @@ optional_packages=("ruby"                               # For i18n extraction
                     #TODO add new optional packages
                     )
 
-
 for pkg in ${optional_packages[@]}; do
     sudo apt-get install -y ${pkg}
     echo "-------------------------------------------------------------------"
@@ -303,7 +303,7 @@ done
 sudo ln -sf /usr/share/java              /opt/saxon
 sudo ln -sf /usr/share/java/Saxon-HE.jar /usr/share/java/saxon9he.jar
 
-echo "Remove SNAP and install Firefox package"
+echo "Remove SNAP and install Native Firefox package"
 echo "-------------------------------------------------------------------"
 
 sudo systemctl disable snapd.service
@@ -327,7 +327,7 @@ sudo rm -rf /var/cache/snapd/
 sudo apt autoremove --purge snapd
 rm -rf ~/snap
 
-sudo cat > /etc/apt/preferences.d/firefox-no-snap << EOF
+sudo tee /etc/apt/preferences.d/firefox-no-snap << EOF
 Package: firefox*
 Pin: release o=Ubuntu*
 Pin-Priority: -1
